<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <xsl:apply-templates select="/" mode="M7"/>
      <xsl:apply-templates select="/" mode="M8"/>
      <xsl:apply-templates select="/" mode="M9"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502Lab2Lab Aanvraagbericht (OML^O21)-->


	  <!--RULE d19e3-false-d281e0-->
   <xsl:template match="/hl7v2:OML_O21" priority="18898" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:MSH is required [min 1x]. (count(hl7v2:MSH)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:MSH komt te vaak voor [max 1x]. (count(hl7v2:MSH)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT is required [min 1x]. (count(hl7v2:OML_O21.PATIENT)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.ORDER)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.ORDER is required [min 1x]. (count(hl7v2:OML_O21.ORDER)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH" priority="18897" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.1 is required [min 1x]. (count(hl7v2:MSH.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.1 komt te vaak voor [max 1x]. (count(hl7v2:MSH.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.2 is required [min 1x]. (count(hl7v2:MSH.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.2 komt te vaak voor [max 1x]. (count(hl7v2:MSH.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.3 is required [min 1x]. (count(hl7v2:MSH.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.3 komt te vaak voor [max 1x]. (count(hl7v2:MSH.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.4 komt te vaak voor [max 1x]. (count(hl7v2:MSH.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.5 is required [min 1x]. (count(hl7v2:MSH.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.5 komt te vaak voor [max 1x]. (count(hl7v2:MSH.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.6 is required [min 1x]. (count(hl7v2:MSH.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.6 komt te vaak voor [max 1x]. (count(hl7v2:MSH.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.7 is required [min 1x]. (count(hl7v2:MSH.7)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.7 komt te vaak voor [max 1x]. (count(hl7v2:MSH.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.8 komt te vaak voor [max 1x]. (count(hl7v2:MSH.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.9 is required [min 1x]. (count(hl7v2:MSH.9)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.9 komt te vaak voor [max 1x]. (count(hl7v2:MSH.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.10 is required [min 1x]. (count(hl7v2:MSH.10)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.10 komt te vaak voor [max 1x]. (count(hl7v2:MSH.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.11 is required [min 1x]. (count(hl7v2:MSH.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.11 komt te vaak voor [max 1x]. (count(hl7v2:MSH.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.12 is required [min 1x]. (count(hl7v2:MSH.12)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.12 komt te vaak voor [max 1x]. (count(hl7v2:MSH.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.13 komt te vaak voor [max 1x]. (count(hl7v2:MSH.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.14 komt te vaak voor [max 1x]. (count(hl7v2:MSH.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.15 is required [min 1x]. (count(hl7v2:MSH.15)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.15 komt te vaak voor [max 1x]. (count(hl7v2:MSH.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.16 is required [min 1x]. (count(hl7v2:MSH.16)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.16 komt te vaak voor [max 1x]. (count(hl7v2:MSH.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.17 komt te vaak voor [max 1x]. (count(hl7v2:MSH.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.18 komt te vaak voor [max 1x]. (count(hl7v2:MSH.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.19 komt te vaak voor [max 1x]. (count(hl7v2:MSH.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.20 komt te vaak voor [max 1x]. (count(hl7v2:MSH.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): element hl7v2:MSH.21 is mandatory [min 1x]. (count(hl7v2:MSH.21)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.1"
                 priority="18896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1' zijn. (string(@Item)=('1') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Field Separator' zijn. (string(@LongName)=('Field Separator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.2"
                 priority="18895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('2') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '2' zijn. (string(@Item)=('2') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Encoding Characters' zijn. (string(@LongName)=('Encoding Characters') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3"
                 priority="18894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('3') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '3' zijn. (string(@Item)=('3') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70361' zijn. (string(@Table)=('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Sending Application' zijn. (string(@LongName)=('Sending Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="18892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="18891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="18890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4"
                 priority="18888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('4') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '4' zijn. (string(@Item)=('4') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70362' zijn. (string(@Table)=('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Sending Facility' zijn. (string(@LongName)=('Sending Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="18886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="18885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="18884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5"
                 priority="18882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('5') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '5' zijn. (string(@Item)=('5') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70361' zijn. (string(@Table)=('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Receiving Application' zijn. (string(@LongName)=('Receiving Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="18880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="18879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="18878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6"
                 priority="18876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('6') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '6' zijn. (string(@Item)=('6') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70362' zijn. (string(@Table)=('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Receiving Facility' zijn. (string(@LongName)=('Receiving Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="18874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="18873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="18872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7"
                 priority="18870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('7') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '7' zijn. (string(@Item)=('7') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Date/Time Of Message' zijn. (string(@LongName)=('Date/Time Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="18868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="18867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.8"
                 priority="18865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('8') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '8' zijn. (string(@Item)=('8') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Security' zijn. (string(@LongName)=('Security') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9"
                 priority="18864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OML^O21^OML_O21'"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de element content van hl7v2:MSH.9 MOET ''OML^O21^OML_O21'' zijn. (text()='OML^O21^OML_O21' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x]. (count(hl7v2:MSG.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x]. (count(hl7v2:MSG.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x]. (count(hl7v2:MSG.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='OML^O21^OML_O21'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de element content van hl7v2:MSH.9 MOET ''OML^O21^OML_O21'' zijn. (text()='OML^O21^OML_O21' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('9') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '9' zijn. (string(@Item)=('9') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'MSG' zijn. (string(@Type)=('MSG') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Message Type' zijn. (string(@LongName)=('Message Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="18862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70076' zijn. (string(@Table)=('HL70076') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Message Code' zijn. (string(@LongName)=('Message Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="18860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70003' zijn. (string(@Table)=('HL70003') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Trigger Event' zijn. (string(@LongName)=('Trigger Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="18858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @Table MOET 'HL70354' zijn. (string(@Table)=('HL70354') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van @LongName MOET 'Message Structure' zijn. (string(@LongName)=('Message Structure') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.10"
                 priority="18856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('10') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '10' zijn. (string(@Item)=('10') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Message Control ID' zijn. (string(@LongName)=('Message Control ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11"
                 priority="18855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x]. (count(hl7v2:PT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x]. (count(hl7v2:PT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('11') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '11' zijn. (string(@Item)=('11') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'PT' zijn. (string(@Type)=('PT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Processing ID' zijn. (string(@LongName)=('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="18853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Table MOET 'HL70103' zijn. (string(@Table)=('HL70103') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @LongName MOET 'Processing ID' zijn. (string(@LongName)=('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="18851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @Table MOET 'HL70207' zijn. (string(@Table)=('HL70207') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van @LongName MOET 'Processing Mode' zijn. (string(@LongName)=('Processing Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12"
                 priority="18849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn. (text()='2.5' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x]. (count(hl7v2:VID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x]. (count(hl7v2:VID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x]. (count(hl7v2:VID.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de element content van hl7v2:MSH.12 MOET ''2.5'' zijn. (text()='2.5' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('12') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '12' zijn. (string(@Item)=('12') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('VID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'VID' zijn. (string(@Type)=('VID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Version ID' zijn. (string(@LongName)=('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="18847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Table MOET 'HL70104' zijn. (string(@Table)=('HL70104') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'Version ID' zijn. (string(@LongName)=('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="18845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'Internationalization Code' zijn. (string(@LongName)=('Internationalization Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="18843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="18842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="18841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="18839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="18838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="18837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="18835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van @LongName MOET 'International Version ID' zijn. (string(@LongName)=('International Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="18833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="18832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="18831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="18829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="18828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="18827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.13"
                 priority="18825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('13') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '13' zijn. (string(@Item)=('13') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Sequence Number' zijn. (string(@LongName)=('Sequence Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.14"
                 priority="18824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('14') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '14' zijn. (string(@Item)=('14') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Continuation Pointer' zijn. (string(@LongName)=('Continuation Pointer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.15"
                 priority="18823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('15') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '15' zijn. (string(@Item)=('15') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70155' zijn. (string(@Table)=('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Accept Acknowledgment Type' zijn. (string(@LongName)=('Accept Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.16"
                 priority="18821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('16') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '16' zijn. (string(@Item)=('16') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70155' zijn. (string(@Table)=('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Application Acknowledgment Type' zijn. (string(@LongName)=('Application Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.17"
                 priority="18819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn. (text()='NLD' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de element content van hl7v2:MSH.17 MOET ''NLD'' zijn. (text()='NLD' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('17') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '17' zijn. (string(@Item)=('17') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.18"
                 priority="18817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('692') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '692' zijn. (string(@Item)=('692') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70211' zijn. (string(@Table)=('HL70211') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Character Set' zijn. (string(@LongName)=('Character Set') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19"
                 priority="18815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('693') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '693' zijn. (string(@Item)=('693') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Principal Language Of Message' zijn. (string(@LongName)=('Principal Language Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="18813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="18812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="18811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="18809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="18808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="18807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.20"
                 priority="18805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1317') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1317' zijn. (string(@Item)=('1317') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70356' zijn. (string(@Table)=('HL70356') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Alternate Character Set Handling Scheme' zijn. (string(@LongName)=('Alternate Character Set Handling Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21"
                 priority="18803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1598') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1598' zijn. (string(@Item)=('1598') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Message Profile Identifier' zijn. (string(@LongName)=('Message Profile Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.2-2015-07-21T113635.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="18801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="18800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="18799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="18798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT" priority="18796" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.1 is required [min 1x]. (count(hl7v2:SFT.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.1 komt te vaak voor [max 1x]. (count(hl7v2:SFT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.2 is required [min 1x]. (count(hl7v2:SFT.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.2 komt te vaak voor [max 1x]. (count(hl7v2:SFT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.3 is required [min 1x]. (count(hl7v2:SFT.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.3 komt te vaak voor [max 1x]. (count(hl7v2:SFT.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.4 is required [min 1x]. (count(hl7v2:SFT.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.4 komt te vaak voor [max 1x]. (count(hl7v2:SFT.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.5 komt te vaak voor [max 1x]. (count(hl7v2:SFT.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.6 komt te vaak voor [max 1x]. (count(hl7v2:SFT.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1"
                 priority="18795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1834') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1834' zijn. (string(@Item)=('1834') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Vendor Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Vendor Organization' zijn. (string(@LongName)=('Software Vendor Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.1"
                 priority="18793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.2"
                 priority="18792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.3"
                 priority="18791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.4"
                 priority="18790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.5"
                 priority="18789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6"
                 priority="18787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.1"
                 priority="18785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.2"
                 priority="18784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.3"
                 priority="18783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.7"
                 priority="18781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8"
                 priority="18779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.1"
                 priority="18777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.2"
                 priority="18776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.3"
                 priority="18775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.9"
                 priority="18773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.10"
                 priority="18771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.2"
                 priority="18770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1835') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1835' zijn. (string(@Item)=('1835') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Certified Version or Release Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Certified Version or Release Number' zijn. (string(@LongName)=('Software Certified Version or Release Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.3"
                 priority="18769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1836') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1836' zijn. (string(@Item)=('1836') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Product Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Product Name' zijn. (string(@LongName)=('Software Product Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.4"
                 priority="18768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1837') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1837' zijn. (string(@Item)=('1837') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Binary ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Binary ID' zijn. (string(@LongName)=('Software Binary ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5"
                 priority="18767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1838') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1838' zijn. (string(@Item)=('1838') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Product Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Product Information' zijn. (string(@LongName)=('Software Product Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape"
                 priority="18766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape"
                 priority="18765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="18764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6"
                 priority="18763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1839') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Item MOET '1839' zijn. (string(@Item)=('1839') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Software Install Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van @LongName MOET 'Software Install Date' zijn. (string(@LongName)=('Software Install Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.1"
                 priority="18761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.2"
                 priority="18760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE" priority="18758" mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.1"
                 priority="18757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.2"
                 priority="18756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3"
                 priority="18754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="18753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="18752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="18751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4"
                 priority="18750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="18748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="18747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="18746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="18744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="18743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="18742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e26-false-d4148e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT"
                 priority="18740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID is required [min 1x]. (count(hl7v2:PID)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x]. (count(hl7v2:PID)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PD1 komt te vaak voor [max 1x]. (count(hl7v2:PD1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_VISIT)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_VISIT komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_VISIT)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:GT1 komt te vaak voor [max 1x]. (count(hl7v2:GT1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID"
                 priority="18739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.1 komt te vaak voor [max 1x]. (count(hl7v2:PID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.2 komt te vaak voor [max 1x]. (count(hl7v2:PID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.3 is required [min 1x]. (count(hl7v2:PID.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.5 is required [min 1x]. (count(hl7v2:PID.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.7 komt te vaak voor [max 1x]. (count(hl7v2:PID.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.8 komt te vaak voor [max 1x]. (count(hl7v2:PID.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.12 komt te vaak voor [max 1x]. (count(hl7v2:PID.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.15 komt te vaak voor [max 1x]. (count(hl7v2:PID.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.16 komt te vaak voor [max 1x]. (count(hl7v2:PID.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.17 komt te vaak voor [max 1x]. (count(hl7v2:PID.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.18 komt te vaak voor [max 1x]. (count(hl7v2:PID.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.19 komt te vaak voor [max 1x]. (count(hl7v2:PID.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.20 komt te vaak voor [max 1x]. (count(hl7v2:PID.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.23 komt te vaak voor [max 1x]. (count(hl7v2:PID.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.24 komt te vaak voor [max 1x]. (count(hl7v2:PID.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.25 komt te vaak voor [max 1x]. (count(hl7v2:PID.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.27 komt te vaak voor [max 1x]. (count(hl7v2:PID.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.28 komt te vaak voor [max 1x]. (count(hl7v2:PID.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.29 komt te vaak voor [max 1x]. (count(hl7v2:PID.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.30 komt te vaak voor [max 1x]. (count(hl7v2:PID.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.31 komt te vaak voor [max 1x]. (count(hl7v2:PID.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.33 komt te vaak voor [max 1x]. (count(hl7v2:PID.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.34 komt te vaak voor [max 1x]. (count(hl7v2:PID.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.35 komt te vaak voor [max 1x]. (count(hl7v2:PID.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.36 komt te vaak voor [max 1x]. (count(hl7v2:PID.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.37 komt te vaak voor [max 1x]. (count(hl7v2:PID.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): element hl7v2:PID.38 komt te vaak voor [max 2x]. (count(hl7v2:PID.38)&lt;=2 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="18738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('104') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '104' zijn. (string(@Item)=('104') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID - PID' zijn. (string(@LongName)=('Set ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="18737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('105') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '105' zijn. (string(@Item)=('105') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient ID' zijn. (string(@LongName)=('Patient ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="18735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="18734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="18733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="18731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="18725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="18723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="18717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="18716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="18715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="18702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="18689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('106') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '106' zijn. (string(@Item)=('106') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Identifier List' zijn. (string(@LongName)=('Patient Identifier List') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="18687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="18686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="18685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="18683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="18677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="18675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="18669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="18668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="18667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="18654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="18641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('107') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '107' zijn. (string(@Item)=('107') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Alternate Patient ID - PID' zijn. (string(@LongName)=('Alternate Patient ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="18639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="18638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="18637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="18635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="18629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="18627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="18621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="18620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="18619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="18606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="18593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('108') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '108' zijn. (string(@Item)=('108') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Name' zijn. (string(@LongName)=('Patient Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="18591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="18584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="18583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="18582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="18581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="18580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="18579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="18577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="18575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="18565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="18553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="18551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="18546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="18541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="18540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="18538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="18531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="18530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="18529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="18528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="18527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="18526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="18524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="18522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="18512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="18500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="18498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="18493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="18488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="18487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '110' zijn. (string(@Item)=('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Date/Time of Birth' zijn. (string(@LongName)=('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="18485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="18484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="18482"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '111' zijn. (string(@Item)=('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Administrative Sex' zijn. (string(@LongName)=('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="18480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('112') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '112' zijn. (string(@Item)=('112') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Alias' zijn. (string(@LongName)=('Patient Alias') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="18478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="18471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="18470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="18469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="18468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="18467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="18466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="18464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="18462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="18452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="18440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="18438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="18433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="18428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="18427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '113' zijn. (string(@Item)=('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Race' zijn. (string(@LongName)=('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="18425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="18424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="18423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="18421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="18420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="18419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="18417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('114') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '114' zijn. (string(@Item)=('114') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Address' zijn. (string(@LongName)=('Patient Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="18415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="18413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="18412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="18411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="18410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="18409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="18408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="18407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="18406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="18404"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="18402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="18401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="18400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="18399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="18397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="18395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="18390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="18385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="18383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="18382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="18380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="18378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="18377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="18375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('115') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '115' zijn. (string(@Item)=('115') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'County Code' zijn. (string(@LongName)=('County Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="18374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('116') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '116' zijn. (string(@Item)=('116') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Phone Number - Home' zijn. (string(@LongName)=('Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="18372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="18371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="18369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="18367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="18366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="18365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="18364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="18363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="18362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="18361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="18360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="18359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="18358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('117') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '117' zijn. (string(@Item)=('117') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Phone Number - Business' zijn. (string(@LongName)=('Phone Number - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="18356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="18355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="18353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="18351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="18350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="18349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="18348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="18347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="18346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="18345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="18344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="18343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="18342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="18340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="18339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="18338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="18336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="18335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="18334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="18332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '119' zijn. (string(@Item)=('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Marital Status' zijn. (string(@LongName)=('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="18330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="18329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="18328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="18326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="18325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="18324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="18322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="18320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="18319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="18318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="18316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="18315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="18314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="18312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('121') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '121' zijn. (string(@Item)=('121') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Account Number' zijn. (string(@LongName)=('Patient Account Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="18310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="18309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="18308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="18306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="18300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="18298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="18292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="18291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="18290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="18277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="18264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('122') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '122' zijn. (string(@Item)=('122') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'SSN Number - Patient' zijn. (string(@LongName)=('SSN Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="18263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x]. (count(hl7v2:DLN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x]. (count(hl7v2:DLN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x]. (count(hl7v2:DLN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('123') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '123' zijn. (string(@Item)=('123') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'DLN' zijn. (string(@Type)=('DLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Driver''s License Number - Patient' zijn. (string(@LongName)=('Driver''s License Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="18261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'License Number' zijn. (string(@LongName)=('License Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="18260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Table MOET 'HL70333' zijn. (string(@Table)=('HL70333') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Issuing State, Province, Country' zijn. (string(@LongName)=('Issuing State, Province, Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="18259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="18258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('124') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '124' zijn. (string(@Item)=('124') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Mother''s Identifier' zijn. (string(@LongName)=('Mother''s Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="18256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="18255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="18254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="18252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="18246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="18244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="18238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="18237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="18236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="18223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="18210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="18208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="18207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="18206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="18204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="18203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="18202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="18200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('126') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '126' zijn. (string(@Item)=('126') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Birth Place' zijn. (string(@LongName)=('Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="18199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('127') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '127' zijn. (string(@Item)=('127') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Multiple Birth Indicator' zijn. (string(@LongName)=('Multiple Birth Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="18197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('128') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '128' zijn. (string(@Item)=('128') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Birth Order' zijn. (string(@LongName)=('Birth Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="18196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="18194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="18193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="18192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="18190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="18189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="18188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="18186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('130') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '130' zijn. (string(@Item)=('130') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70172' zijn. (string(@Table)=('HL70172') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Veterans Military Status' zijn. (string(@LongName)=('Veterans Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="18184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="18183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="18182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="18180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="18179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="18178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="18176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="18174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="18173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="18172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="18170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="18169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="18168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="18166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('740') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '740' zijn. (string(@Item)=('740') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Death Date and Time' zijn. (string(@LongName)=('Patient Death Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="18164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="18163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="18161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('741') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '741' zijn. (string(@Item)=('741') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Death Indicator' zijn. (string(@LongName)=('Patient Death Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="18159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1535') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1535' zijn. (string(@Item)=('1535') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Identity Unknown Indicator' zijn. (string(@LongName)=('Identity Unknown Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="18157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1536') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1536' zijn. (string(@Item)=('1536') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70445' zijn. (string(@Table)=('HL70445') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Identity Reliability Code' zijn. (string(@LongName)=('Identity Reliability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="18156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1537') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1537' zijn. (string(@Item)=('1537') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Last Update Date/Time' zijn. (string(@LongName)=('Last Update Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="18154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="18153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="18151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1538') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1538' zijn. (string(@Item)=('1538') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Last Update Facility' zijn. (string(@LongName)=('Last Update Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="18149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="18148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="18147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="18145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1539') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1539' zijn. (string(@Item)=('1539') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70446' zijn. (string(@Table)=('HL70446') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Species Code' zijn. (string(@LongName)=('Species Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="18143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="18142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="18141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="18139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="18138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="18137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="18135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1540') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1540' zijn. (string(@Item)=('1540') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70447' zijn. (string(@Table)=('HL70447') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Breed Code' zijn. (string(@LongName)=('Breed Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="18133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="18132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="18131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="18129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="18128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="18127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="18125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1541') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1541' zijn. (string(@Item)=('1541') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Strain' zijn. (string(@LongName)=('Strain') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="18124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1542') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1542' zijn. (string(@Item)=('1542') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70429' zijn. (string(@Table)=('HL70429') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Production Class Code' zijn. (string(@LongName)=('Production Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="18122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="18121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="18120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="18118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="18117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="18116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="18114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1840') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Item MOET '1840' zijn. (string(@Item)=('1840') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab2Lab): de waarde van @LongName MOET 'Tribal Citizenship' zijn. (string(@LongName)=('Tribal Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="18112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="18111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="18110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="18108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="18107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="18106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="18104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="18103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="18102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1"
                 priority="18101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x]. (count(hl7v2:PD1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x]. (count(hl7v2:PD1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x]. (count(hl7v2:PD1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x]. (count(hl7v2:PD1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x]. (count(hl7v2:PD1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x]. (count(hl7v2:PD1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x]. (count(hl7v2:PD1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x]. (count(hl7v2:PD1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x]. (count(hl7v2:PD1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x]. (count(hl7v2:PD1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x]. (count(hl7v2:PD1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x]. (count(hl7v2:PD1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x]. (count(hl7v2:PD1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x]. (count(hl7v2:PD1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x]. (count(hl7v2:PD1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.1"
                 priority="18100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.2"
                 priority="18099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3"
                 priority="18098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '756' zijn. (string(@Item)=('756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Facility' zijn. (string(@LongName)=('Patient Primary Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="18096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="18095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="18094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="18093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="18092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="18090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="18088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="18087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="18086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="18084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="18082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="18080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="18079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="18078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="18076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="18074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4"
                 priority="18073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '757' zijn. (string(@Item)=('757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. (string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="18071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="18070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="18068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="18067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="18066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="18065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="18064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="18063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="18062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="18061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="18060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="18059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="18058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="18057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="18055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="18054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="18053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="18051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="18049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="18048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="18046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="18044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="18042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="18041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="18040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="18038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="18036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="18034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="18033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="18032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="18030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="18029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="18028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="18026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="18024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="18019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="18014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="18012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="18010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="18009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="18007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="18005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="18004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="18002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="18001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="17999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="17998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="17997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="17995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="17994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="17993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="17991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="17990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="17989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="17988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="17986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="17985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="17984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="17982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="17981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="17980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="17978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="17977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="17976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.5"
                 priority="17975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.6"
                 priority="17974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.7"
                 priority="17973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.8"
                 priority="17972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.9"
                 priority="17971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '761' zijn. (string(@Item)=('761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Separate Bill' zijn. (string(@LongName)=('Separate Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10"
                 priority="17969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '762' zijn. (string(@Item)=('762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Duplicate Patient' zijn. (string(@LongName)=('Duplicate Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="17967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="17966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="17965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="17963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="17957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="17955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="17949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="17948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="17947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="17934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11"
                 priority="17921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="17919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="17918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="17917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="17915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="17914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="17913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.12"
                 priority="17911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.13"
                 priority="17909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1566') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1566' zijn. (string(@Item)=('1566') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator Effective Date' zijn. (string(@LongName)=('Protection Indicator Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14"
                 priority="17908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1567') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1567' zijn. (string(@Item)=('1567') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Place of Worship' zijn. (string(@LongName)=('Place of Worship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="17906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="17905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="17904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="17903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="17902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="17900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="17898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="17897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="17896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="17894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="17892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="17890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="17889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="17888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="17886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="17884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15"
                 priority="17883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1568') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1568' zijn. (string(@Item)=('1568') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="17881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="17880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="17879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="17877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="17876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="17875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.16"
                 priority="17873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1569' zijn. (string(@Item)=('1569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70441' zijn. (string(@Table)=('HL70441') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status' zijn. (string(@LongName)=('Immunization Registry Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.17"
                 priority="17872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1570' zijn. (string(@Item)=('1570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status Effective Date' zijn. (string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.18"
                 priority="17871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1571' zijn. (string(@Item)=('1571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code Effective Date' zijn. (string(@LongName)=('Publicity Code Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.19"
                 priority="17870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1572' zijn. (string(@Item)=('1572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70140' zijn. (string(@Table)=('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Branch' zijn. (string(@LongName)=('Military Branch') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.20"
                 priority="17869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '486' zijn. (string(@Item)=('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70141' zijn. (string(@Table)=('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Rank/Grade' zijn. (string(@LongName)=('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.21"
                 priority="17868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1573' zijn. (string(@Item)=('1573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70142' zijn. (string(@Table)=('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Status' zijn. (string(@LongName)=('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE"
                 priority="17867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="17866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="17865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="17863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="17862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="17861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="17860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="17859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="17857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="17856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="17855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="17853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="17852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="17851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1"
                 priority="17849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.1 is required [min 1x]. (count(hl7v2:NK1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.1 komt te vaak voor [max 1x]. (count(hl7v2:NK1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.3 komt te vaak voor [max 1x]. (count(hl7v2:NK1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.7 komt te vaak voor [max 1x]. (count(hl7v2:NK1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.8 komt te vaak voor [max 1x]. (count(hl7v2:NK1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.9 komt te vaak voor [max 1x]. (count(hl7v2:NK1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.10 komt te vaak voor [max 1x]. (count(hl7v2:NK1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.11 komt te vaak voor [max 1x]. (count(hl7v2:NK1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.12 komt te vaak voor [max 1x]. (count(hl7v2:NK1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.14 komt te vaak voor [max 1x]. (count(hl7v2:NK1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.15 komt te vaak voor [max 1x]. (count(hl7v2:NK1.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.16 komt te vaak voor [max 1x]. (count(hl7v2:NK1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.20 komt te vaak voor [max 1x]. (count(hl7v2:NK1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.21 komt te vaak voor [max 1x]. (count(hl7v2:NK1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.22 komt te vaak voor [max 1x]. (count(hl7v2:NK1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.23 komt te vaak voor [max 1x]. (count(hl7v2:NK1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.24 komt te vaak voor [max 1x]. (count(hl7v2:NK1.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.25 komt te vaak voor [max 1x]. (count(hl7v2:NK1.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.27 komt te vaak voor [max 1x]. (count(hl7v2:NK1.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.34 komt te vaak voor [max 1x]. (count(hl7v2:NK1.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.36 komt te vaak voor [max 1x]. (count(hl7v2:NK1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.37 komt te vaak voor [max 1x]. (count(hl7v2:NK1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.38 komt te vaak voor [max 1x]. (count(hl7v2:NK1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.39 komt te vaak voor [max 1x]. (count(hl7v2:NK1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.1"
                 priority="17848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('190') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '190' zijn. (string(@Item)=('190') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NK1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Set ID - NK1' zijn. (string(@LongName)=('Set ID - NK1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2"
                 priority="17847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('191') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '191' zijn. (string(@Item)=('191') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1"
                 priority="17845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.2"
                 priority="17838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.3"
                 priority="17837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.4"
                 priority="17836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.5"
                 priority="17835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.6"
                 priority="17834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.7"
                 priority="17833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.8"
                 priority="17831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9"
                 priority="17829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10"
                 priority="17819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.11"
                 priority="17807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12"
                 priority="17805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13"
                 priority="17800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.14"
                 priority="17795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3"
                 priority="17794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('192') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '192' zijn. (string(@Item)=('192') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70063' zijn. (string(@Table)=('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Relationship' zijn. (string(@LongName)=('Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.1"
                 priority="17792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.2"
                 priority="17791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.3"
                 priority="17790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.4"
                 priority="17788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.5"
                 priority="17787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.6"
                 priority="17786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4"
                 priority="17784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('193') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '193' zijn. (string(@Item)=('193') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Address' zijn. (string(@LongName)=('Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1"
                 priority="17782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="17780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="17779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="17778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.2"
                 priority="17777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.3"
                 priority="17776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.4"
                 priority="17775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.5"
                 priority="17774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.6"
                 priority="17773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.7"
                 priority="17771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.8"
                 priority="17769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.9"
                 priority="17768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.10"
                 priority="17767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.11"
                 priority="17766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12"
                 priority="17764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="17762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="17757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13"
                 priority="17752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="17750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="17749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14"
                 priority="17747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="17745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="17744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5"
                 priority="17742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('194') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '194' zijn. (string(@Item)=('194') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Phone Number' zijn. (string(@LongName)=('Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.1"
                 priority="17740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.2"
                 priority="17739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.3"
                 priority="17737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.4"
                 priority="17735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.5"
                 priority="17734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.6"
                 priority="17733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.7"
                 priority="17732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.8"
                 priority="17731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.9"
                 priority="17730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.10"
                 priority="17729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.11"
                 priority="17728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.12"
                 priority="17727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6"
                 priority="17726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('195') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '195' zijn. (string(@Item)=('195') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Business Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Business Phone Number' zijn. (string(@LongName)=('Business Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.1"
                 priority="17724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.2"
                 priority="17723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.3"
                 priority="17721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.4"
                 priority="17719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.5"
                 priority="17718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.6"
                 priority="17717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.7"
                 priority="17716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.8"
                 priority="17715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.9"
                 priority="17714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.10"
                 priority="17713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.11"
                 priority="17712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.12"
                 priority="17711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7"
                 priority="17710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('196') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '196' zijn. (string(@Item)=('196') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70131') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70131' zijn. (string(@Table)=('HL70131') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Role' zijn. (string(@LongName)=('Contact Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.1"
                 priority="17708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.2"
                 priority="17707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.3"
                 priority="17706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.4"
                 priority="17704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.5"
                 priority="17703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.6"
                 priority="17702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.8"
                 priority="17700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('197') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '197' zijn. (string(@Item)=('197') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Start Date' zijn. (string(@LongName)=('Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.9"
                 priority="17699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('198') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '198' zijn. (string(@Item)=('198') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'End Date' zijn. (string(@LongName)=('End Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.10"
                 priority="17698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('199') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '199' zijn. (string(@Item)=('199') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Next of Kin / Associated Parties Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Next of Kin / Associated Parties Job Title' zijn. (string(@LongName)=('Next of Kin / Associated Parties Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11"
                 priority="17697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('200') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '200' zijn. (string(@Item)=('200') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'JCC' zijn. (string(@Type)=('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Next of Kin / Associated Parties Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Next of Kin / Associated Parties Job Code/Class' zijn. (string(@LongName)=('Next of Kin / Associated Parties Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.1"
                 priority="17695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70327' zijn. (string(@Table)=('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Code' zijn. (string(@LongName)=('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.2"
                 priority="17694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70328' zijn. (string(@Table)=('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Class' zijn. (string(@LongName)=('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3"
                 priority="17693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Description Text' zijn. (string(@LongName)=('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape"
                 priority="17692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="17691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="17690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12"
                 priority="17689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('201') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '201' zijn. (string(@Item)=('201') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Next of Kin / Associated Parties Employee Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Next of Kin / Associated Parties Employee Number' zijn. (string(@LongName)=('Next of Kin / Associated Parties Employee Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.1"
                 priority="17687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.2"
                 priority="17686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.3"
                 priority="17685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4"
                 priority="17683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.5"
                 priority="17677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6"
                 priority="17675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.7"
                 priority="17669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.8"
                 priority="17668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9"
                 priority="17667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10"
                 priority="17654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13"
                 priority="17641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('202') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '202' zijn. (string(@Item)=('202') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name - NK1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Organization Name - NK1' zijn. (string(@LongName)=('Organization Name - NK1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.1"
                 priority="17639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.2"
                 priority="17638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.3"
                 priority="17637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.4"
                 priority="17636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.5"
                 priority="17635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6"
                 priority="17633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.1"
                 priority="17631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.2"
                 priority="17630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.3"
                 priority="17629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.7"
                 priority="17627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8"
                 priority="17625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.1"
                 priority="17623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.2"
                 priority="17622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.3"
                 priority="17621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.9"
                 priority="17619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.10"
                 priority="17617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14"
                 priority="17616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '119' zijn. (string(@Item)=('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Marital Status' zijn. (string(@LongName)=('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.1"
                 priority="17614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.2"
                 priority="17613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.3"
                 priority="17612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.4"
                 priority="17610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.5"
                 priority="17609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.6"
                 priority="17608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.15"
                 priority="17606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '111' zijn. (string(@Item)=('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Administrative Sex' zijn. (string(@LongName)=('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16"
                 priority="17605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '110' zijn. (string(@Item)=('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Date/Time of Birth' zijn. (string(@LongName)=('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16/hl7v2:TS.1"
                 priority="17603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16/hl7v2:TS.2"
                 priority="17602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.17"
                 priority="17600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.18"
                 priority="17599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19"
                 priority="17598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.1"
                 priority="17596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.2"
                 priority="17595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.3"
                 priority="17594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.4"
                 priority="17592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.5"
                 priority="17591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.6"
                 priority="17590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20"
                 priority="17588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.1"
                 priority="17586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.2"
                 priority="17585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.3"
                 priority="17584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.4"
                 priority="17582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.5"
                 priority="17581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.6"
                 priority="17580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.21"
                 priority="17578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22"
                 priority="17577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.1"
                 priority="17575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.2"
                 priority="17574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.3"
                 priority="17573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.4"
                 priority="17571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.5"
                 priority="17570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.6"
                 priority="17569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.23"
                 priority="17567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.24"
                 priority="17565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25"
                 priority="17564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.1"
                 priority="17562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.2"
                 priority="17561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.3"
                 priority="17560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.4"
                 priority="17558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.5"
                 priority="17557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.6"
                 priority="17556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26"
                 priority="17554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1"
                 priority="17552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.2"
                 priority="17545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.3"
                 priority="17544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.4"
                 priority="17543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.5"
                 priority="17542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.6"
                 priority="17541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.7"
                 priority="17540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.8"
                 priority="17538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9"
                 priority="17536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10"
                 priority="17526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.11"
                 priority="17514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12"
                 priority="17512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13"
                 priority="17507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.14"
                 priority="17502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27"
                 priority="17501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.1"
                 priority="17499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.2"
                 priority="17498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.3"
                 priority="17497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.4"
                 priority="17495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.5"
                 priority="17494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.6"
                 priority="17493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28"
                 priority="17491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.1"
                 priority="17489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.2"
                 priority="17488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.3"
                 priority="17487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.4"
                 priority="17485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.5"
                 priority="17484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.6"
                 priority="17483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29"
                 priority="17481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('747') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '747' zijn. (string(@Item)=('747') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70222' zijn. (string(@Table)=('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Reason' zijn. (string(@LongName)=('Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.1"
                 priority="17479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.2"
                 priority="17478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.3"
                 priority="17477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.4"
                 priority="17475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.5"
                 priority="17474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.6"
                 priority="17473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30"
                 priority="17471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('748') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '748' zijn. (string(@Item)=('748') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Person''s Name' zijn. (string(@LongName)=('Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1"
                 priority="17469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.2"
                 priority="17462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.3"
                 priority="17461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.4"
                 priority="17460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.5"
                 priority="17459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.6"
                 priority="17458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.7"
                 priority="17457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.8"
                 priority="17455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9"
                 priority="17453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10"
                 priority="17443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.11"
                 priority="17431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12"
                 priority="17429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13"
                 priority="17424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.14"
                 priority="17419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31"
                 priority="17418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('749') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '749' zijn. (string(@Item)=('749') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person''s Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Person''s Telephone Number' zijn. (string(@LongName)=('Contact Person''s Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.1"
                 priority="17416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.2"
                 priority="17415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.3"
                 priority="17413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.4"
                 priority="17411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.5"
                 priority="17410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.6"
                 priority="17409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.7"
                 priority="17408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.8"
                 priority="17407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.9"
                 priority="17406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.10"
                 priority="17405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.11"
                 priority="17404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.12"
                 priority="17403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32"
                 priority="17402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('750') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '750' zijn. (string(@Item)=('750') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Person''s Address' zijn. (string(@LongName)=('Contact Person''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1"
                 priority="17400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="17398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="17397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="17396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.2"
                 priority="17395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.3"
                 priority="17394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.4"
                 priority="17393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.5"
                 priority="17392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.6"
                 priority="17391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.7"
                 priority="17389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.8"
                 priority="17387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.9"
                 priority="17386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.10"
                 priority="17385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.11"
                 priority="17384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12"
                 priority="17382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="17380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="17375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13"
                 priority="17370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="17368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="17367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14"
                 priority="17365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="17363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="17362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33"
                 priority="17360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('751') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '751' zijn. (string(@Item)=('751') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Next of Kin/Associated Party''s Identifiers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Next of Kin/Associated Party''s Identifiers' zijn. (string(@LongName)=('Next of Kin/Associated Party''s Identifiers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.1"
                 priority="17358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.2"
                 priority="17357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.3"
                 priority="17356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4"
                 priority="17354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.5"
                 priority="17348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6"
                 priority="17346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.7"
                 priority="17340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.8"
                 priority="17339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9"
                 priority="17338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10"
                 priority="17325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.34"
                 priority="17312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '752' zijn. (string(@Item)=('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70311' zijn. (string(@Table)=('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Job Status' zijn. (string(@LongName)=('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35"
                 priority="17311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '113' zijn. (string(@Item)=('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Race' zijn. (string(@LongName)=('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.1"
                 priority="17309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.2"
                 priority="17308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.3"
                 priority="17307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.4"
                 priority="17305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.5"
                 priority="17304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.6"
                 priority="17303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.36"
                 priority="17301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.37"
                 priority="17300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('754') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '754' zijn. (string(@Item)=('754') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person Social Security Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Contact Person Social Security Number' zijn. (string(@LongName)=('Contact Person Social Security Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.38"
                 priority="17299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1905') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '1905' zijn. (string(@Item)=('1905') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Next of Kin Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'Next of Kin Birth Place' zijn. (string(@LongName)=('Next of Kin Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.39"
                 priority="17298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Item MOET '146' zijn. (string(@Item)=('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e36-false-d39201e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT"
                 priority="17297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 is required [min 1x]. (count(hl7v2:PV1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 komt te vaak voor [max 1x]. (count(hl7v2:PV1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV2 komt te vaak voor [max 1x]. (count(hl7v2:PV2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1"
                 priority="17296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.1 komt te vaak voor [max 1x]. (count(hl7v2:PV1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.2 is required [min 1x]. (count(hl7v2:PV1.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.2 komt te vaak voor [max 1x]. (count(hl7v2:PV1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.3 is required [min 1x]. (count(hl7v2:PV1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.3 komt te vaak voor [max 1x]. (count(hl7v2:PV1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.4 komt te vaak voor [max 1x]. (count(hl7v2:PV1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.5 komt te vaak voor [max 1x]. (count(hl7v2:PV1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.6 komt te vaak voor [max 1x]. (count(hl7v2:PV1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.10 is required [min 1x]. (count(hl7v2:PV1.10)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.10 komt te vaak voor [max 1x]. (count(hl7v2:PV1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.11 komt te vaak voor [max 1x]. (count(hl7v2:PV1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.12 komt te vaak voor [max 1x]. (count(hl7v2:PV1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.13 komt te vaak voor [max 1x]. (count(hl7v2:PV1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.14 komt te vaak voor [max 1x]. (count(hl7v2:PV1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.16 komt te vaak voor [max 1x]. (count(hl7v2:PV1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.18 komt te vaak voor [max 1x]. (count(hl7v2:PV1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.19 komt te vaak voor [max 1x]. (count(hl7v2:PV1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.21 komt te vaak voor [max 1x]. (count(hl7v2:PV1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.22 komt te vaak voor [max 1x]. (count(hl7v2:PV1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.23 komt te vaak voor [max 1x]. (count(hl7v2:PV1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.28 komt te vaak voor [max 1x]. (count(hl7v2:PV1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.29 komt te vaak voor [max 1x]. (count(hl7v2:PV1.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.30 komt te vaak voor [max 1x]. (count(hl7v2:PV1.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.31 komt te vaak voor [max 1x]. (count(hl7v2:PV1.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.32 komt te vaak voor [max 1x]. (count(hl7v2:PV1.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.33 komt te vaak voor [max 1x]. (count(hl7v2:PV1.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.34 komt te vaak voor [max 1x]. (count(hl7v2:PV1.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.35 komt te vaak voor [max 1x]. (count(hl7v2:PV1.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.36 komt te vaak voor [max 1x]. (count(hl7v2:PV1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.37 komt te vaak voor [max 1x]. (count(hl7v2:PV1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.38 komt te vaak voor [max 1x]. (count(hl7v2:PV1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.39 is required [min 1x]. (count(hl7v2:PV1.39)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.39 komt te vaak voor [max 1x]. (count(hl7v2:PV1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.40 komt te vaak voor [max 1x]. (count(hl7v2:PV1.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.41 komt te vaak voor [max 1x]. (count(hl7v2:PV1.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.42 komt te vaak voor [max 1x]. (count(hl7v2:PV1.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.43 komt te vaak voor [max 1x]. (count(hl7v2:PV1.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.44 komt te vaak voor [max 1x]. (count(hl7v2:PV1.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.46 komt te vaak voor [max 1x]. (count(hl7v2:PV1.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.47 komt te vaak voor [max 1x]. (count(hl7v2:PV1.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.48 komt te vaak voor [max 1x]. (count(hl7v2:PV1.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.49 komt te vaak voor [max 1x]. (count(hl7v2:PV1.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.50 komt te vaak voor [max 1x]. (count(hl7v2:PV1.50)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): element hl7v2:PV1.51 komt te vaak voor [max 1x]. (count(hl7v2:PV1.51)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.1"
                 priority="17295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('131') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '131' zijn. (string(@Item)=('131') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID - PV1' zijn. (string(@LongName)=('Set ID - PV1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.2"
                 priority="17294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('132') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '132' zijn. (string(@Item)=('132') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70004' zijn. (string(@Table)=('HL70004') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Class' zijn. (string(@LongName)=('Patient Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3"
                 priority="17293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.6 is required [min 1x]. (count(hl7v2:PL.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '133' zijn. (string(@Item)=('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Assigned Patient Location' zijn. (string(@LongName)=('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="17291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="17290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="17289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="17288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="17286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="17285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="17284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="17282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="17281"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.411 RIVM ISIS-AR Type Afdeling (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.411-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="17279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="17278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="17277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="17276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="17274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="17273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="17272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="17271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="17269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_RIVM): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="17267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="17266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="17265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.4"
                 priority="17263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('134') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '134' zijn. (string(@Item)=('134') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70007' zijn. (string(@Table)=('HL70007') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admission Type' zijn. (string(@LongName)=('Admission Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5"
                 priority="17262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('135') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '135' zijn. (string(@Item)=('135') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Preadmit Number' zijn. (string(@LongName)=('Preadmit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="17260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="17259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="17258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="17256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="17250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="17248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="17242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="17241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="17240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="17227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6"
                 priority="17214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('136') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '136' zijn. (string(@Item)=('136') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Prior Patient Location' zijn. (string(@LongName)=('Prior Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="17212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="17211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="17210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="17209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="17207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="17206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="17205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="17203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="17202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="17201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="17200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="17199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="17198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="17196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="17195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="17194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="17193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="17191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="17189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="17188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="17187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7"
                 priority="17185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('137') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '137' zijn. (string(@Item)=('137') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Attending Doctor' zijn. (string(@LongName)=('Attending Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="17183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="17182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="17180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="17179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="17178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="17177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="17176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="17175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="17174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="17173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="17172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="17171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="17170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="17169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="17167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="17166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="17165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="17163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="17161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="17160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="17158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="17156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="17154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="17153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="17152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="17150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="17148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="17146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="17145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="17144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="17142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="17141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="17140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="17138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="17136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="17131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="17126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="17124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="17122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="17121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="17119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="17117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="17116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="17114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="17113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="17111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="17110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="17109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="17107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="17106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="17105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="17103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="17102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="17101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="17100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="17098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="17097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="17096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="17094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="17093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="17092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="17090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="17089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="17088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8"
                 priority="17087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('138') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '138' zijn. (string(@Item)=('138') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Referring Doctor' zijn. (string(@LongName)=('Referring Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="17085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="17084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="17082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="17081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="17080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="17079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="17078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="17077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="17076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="17075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="17074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="17073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="17072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="17071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="17069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="17068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="17067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="17065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="17063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="17062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="17060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="17058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="17056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="17055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="17054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="17052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="17050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="17048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="17047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="17046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="17044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="17043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="17042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="17040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="17038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="17033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="17028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="17026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="17024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="17023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="17021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="17019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="17018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="17016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="17015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="17013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="17012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="17011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="17009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="17008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="17007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="17005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="17004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="17003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="17002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="17000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9"
                 priority="16989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('139') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '139' zijn. (string(@Item)=('139') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Consulting Doctor' zijn. (string(@LongName)=('Consulting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="16987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="16986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="16979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="16978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="16977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="16976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="16975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="16974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="16973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="16967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="16965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="16964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="16962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="16960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="16954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="16952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="16942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="16930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="16928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="16923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="16918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="16917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="16904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.10"
                 priority="16891"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('140') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '140' zijn. (string(@Item)=('140') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70069' zijn. (string(@Table)=('HL70069') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Hospital Service' zijn. (string(@LongName)=('Hospital Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11"
                 priority="16889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('141') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '141' zijn. (string(@Item)=('141') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Temporary Location' zijn. (string(@LongName)=('Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="16887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="16886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="16885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="16884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="16878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="16877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="16876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="16875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="16874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="16873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="16866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.12"
                 priority="16860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('142') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '142' zijn. (string(@Item)=('142') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70087' zijn. (string(@Table)=('HL70087') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Preadmit Test Indicator' zijn. (string(@LongName)=('Preadmit Test Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.13"
                 priority="16859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('143') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '143' zijn. (string(@Item)=('143') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70092' zijn. (string(@Table)=('HL70092') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Re-admission Indicator' zijn. (string(@LongName)=('Re-admission Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.14"
                 priority="16858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('144') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '144' zijn. (string(@Item)=('144') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70023' zijn. (string(@Table)=('HL70023') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admit Source' zijn. (string(@LongName)=('Admit Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.15"
                 priority="16857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.16"
                 priority="16856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '146' zijn. (string(@Item)=('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17"
                 priority="16855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('147') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '147' zijn. (string(@Item)=('147') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admitting Doctor' zijn. (string(@LongName)=('Admitting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="16853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="16852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="16845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="16844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="16843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="16842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="16841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="16840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="16839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="16833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="16831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="16830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="16828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="16826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="16820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="16818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="16808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="16796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="16794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="16789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="16784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="16783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="16770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.18"
                 priority="16757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '148' zijn. (string(@Item)=('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70018' zijn. (string(@Table)=('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Patient Type' zijn. (string(@LongName)=('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19"
                 priority="16756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('149') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '149' zijn. (string(@Item)=('149') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Visit Number' zijn. (string(@LongName)=('Visit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="16754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="16753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="16752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="16750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="16748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="16747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="16746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="16744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="16742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="16740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="16739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="16738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="16736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="16735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="16734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="16732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="16731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="16730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="16728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="16727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="16726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="16724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="16723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="16722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="16721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="16719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="16718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="16717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="16715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="16714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="16713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="16711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="16710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="16709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20"
                 priority="16708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('150') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '150' zijn. (string(@Item)=('150') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'FC' zijn. (string(@Type)=('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Financial Class' zijn. (string(@LongName)=('Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="16706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Financial Class Code' zijn. (string(@LongName)=('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="16705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="16703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="16702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.21"
                 priority="16700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('151') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '151' zijn. (string(@Item)=('151') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70032' zijn. (string(@Table)=('HL70032') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Charge Price Indicator' zijn. (string(@LongName)=('Charge Price Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.22"
                 priority="16699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('152') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '152' zijn. (string(@Item)=('152') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70045' zijn. (string(@Table)=('HL70045') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Courtesy Code' zijn. (string(@LongName)=('Courtesy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.23"
                 priority="16698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('153') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '153' zijn. (string(@Item)=('153') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70046' zijn. (string(@Table)=('HL70046') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Credit Rating' zijn. (string(@LongName)=('Credit Rating') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.24"
                 priority="16697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('154') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '154' zijn. (string(@Item)=('154') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70044' zijn. (string(@Table)=('HL70044') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Code' zijn. (string(@LongName)=('Contract Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.25"
                 priority="16696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('155') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '155' zijn. (string(@Item)=('155') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Effective Date' zijn. (string(@LongName)=('Contract Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.26"
                 priority="16695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('156') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '156' zijn. (string(@Item)=('156') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Amount' zijn. (string(@LongName)=('Contract Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.27"
                 priority="16694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('157') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '157' zijn. (string(@Item)=('157') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Contract Period' zijn. (string(@LongName)=('Contract Period') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.28"
                 priority="16693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('158') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '158' zijn. (string(@Item)=('158') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70073' zijn. (string(@Table)=('HL70073') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Interest Code' zijn. (string(@LongName)=('Interest Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.29"
                 priority="16692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('159') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '159' zijn. (string(@Item)=('159') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70110' zijn. (string(@Table)=('HL70110') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Transfer to Bad Debt Code' zijn. (string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.30"
                 priority="16691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('160') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '160' zijn. (string(@Item)=('160') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Transfer to Bad Debt Date' zijn. (string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.31"
                 priority="16690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('161') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '161' zijn. (string(@Item)=('161') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70021' zijn. (string(@Table)=('HL70021') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Agency Code' zijn. (string(@LongName)=('Bad Debt Agency Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.32"
                 priority="16689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('162') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '162' zijn. (string(@Item)=('162') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Transfer Amount' zijn. (string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.33"
                 priority="16688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('163') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '163' zijn. (string(@Item)=('163') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bad Debt Recovery Amount' zijn. (string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.34"
                 priority="16687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('164') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '164' zijn. (string(@Item)=('164') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70111' zijn. (string(@Table)=('HL70111') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Delete Account Indicator' zijn. (string(@LongName)=('Delete Account Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.35"
                 priority="16686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '165' zijn. (string(@Item)=('165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Delete Account Date' zijn. (string(@LongName)=('Delete Account Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.36"
                 priority="16685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '166' zijn. (string(@Item)=('166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharge Disposition' zijn. (string(@LongName)=('Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37"
                 priority="16684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x]. (count(hl7v2:DLD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x]. (count(hl7v2:DLD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '167' zijn. (string(@Item)=('167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'DLD' zijn. (string(@Type)=('DLD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharged to Location' zijn. (string(@LongName)=('Discharged to Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="16682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Discharge Location' zijn. (string(@LongName)=('Discharge Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="16681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="16679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="16678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38"
                 priority="16676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '168' zijn. (string(@Item)=('168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70114' zijn. (string(@Table)=('HL70114') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Diet Type' zijn. (string(@LongName)=('Diet Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="16674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="16673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="16672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="16670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="16669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="16668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.39"
                 priority="16666"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('169') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '169' zijn. (string(@Item)=('169') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70115' zijn. (string(@Table)=('HL70115') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Servicing Facility' zijn. (string(@LongName)=('Servicing Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.40"
                 priority="16664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('170') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '170' zijn. (string(@Item)=('170') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70116' zijn. (string(@Table)=('HL70116') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Bed Status' zijn. (string(@LongName)=('Bed Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.41"
                 priority="16663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '171' zijn. (string(@Item)=('171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70117' zijn. (string(@Table)=('HL70117') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Account Status' zijn. (string(@LongName)=('Account Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42"
                 priority="16662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('172') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '172' zijn. (string(@Item)=('172') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Pending Location' zijn. (string(@LongName)=('Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="16660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="16659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="16658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="16657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="16651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="16650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="16649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="16648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="16647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="16646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="16639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43"
                 priority="16633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('173') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '173' zijn. (string(@Item)=('173') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Prior Temporary Location' zijn. (string(@LongName)=('Prior Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="16631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="16630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="16629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="16628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="16622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="16621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="16620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="16619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="16618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="16617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="16610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44"
                 priority="16604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('174') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '174' zijn. (string(@Item)=('174') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Admit Date/Time' zijn. (string(@LongName)=('Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="16602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="16601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45"
                 priority="16599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('175') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '175' zijn. (string(@Item)=('175') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Discharge Date/Time' zijn. (string(@LongName)=('Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="16597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="16596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.46"
                 priority="16594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('176') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '176' zijn. (string(@Item)=('176') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Current Patient Balance' zijn. (string(@LongName)=('Current Patient Balance') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.47"
                 priority="16593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('177') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '177' zijn. (string(@Item)=('177') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Charges' zijn. (string(@LongName)=('Total Charges') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.48"
                 priority="16592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('178') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '178' zijn. (string(@Item)=('178') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Adjustments' zijn. (string(@LongName)=('Total Adjustments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.49"
                 priority="16591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('179') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '179' zijn. (string(@Item)=('179') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Total Payments' zijn. (string(@LongName)=('Total Payments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50"
                 priority="16590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('180') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '180' zijn. (string(@Item)=('180') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Alternate Visit ID' zijn. (string(@LongName)=('Alternate Visit ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="16588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="16587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="16586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="16584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="16582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="16581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="16580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="16578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="16576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="16574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="16573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="16572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="16570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="16569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="16568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="16566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="16565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="16564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="16562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="16561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="16560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="16558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="16557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="16556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="16555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="16553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="16552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="16551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="16549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="16548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="16547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="16545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="16544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="16543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.51"
                 priority="16542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '1226' zijn. (string(@Item)=('1226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70326' zijn. (string(@Table)=('HL70326') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Visit Indicator' zijn. (string(@LongName)=('Visit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52"
                 priority="16541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1274') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Item MOET '1274' zijn. (string(@Item)=('1274') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab2Lab): de waarde van @LongName MOET 'Other Healthcare Provider' zijn. (string(@LongName)=('Other Healthcare Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="16539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="16538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="16531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="16530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="16529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="16528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="16527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="16526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="16525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="16519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="16517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="16516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="16514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="16512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="16506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="16504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="16494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="16482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="16480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="16475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="16470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="16469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="16456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2"
                 priority="16443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x]. (count(hl7v2:PV2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x]. (count(hl7v2:PV2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x]. (count(hl7v2:PV2.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x]. (count(hl7v2:PV2.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x]. (count(hl7v2:PV2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x]. (count(hl7v2:PV2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x]. (count(hl7v2:PV2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x]. (count(hl7v2:PV2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x]. (count(hl7v2:PV2.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x]. (count(hl7v2:PV2.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x]. (count(hl7v2:PV2.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x]. (count(hl7v2:PV2.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x]. (count(hl7v2:PV2.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x]. (count(hl7v2:PV2.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x]. (count(hl7v2:PV2.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x]. (count(hl7v2:PV2.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x]. (count(hl7v2:PV2.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x]. (count(hl7v2:PV2.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x]. (count(hl7v2:PV2.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x]. (count(hl7v2:PV2.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x]. (count(hl7v2:PV2.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x]. (count(hl7v2:PV2.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x]. (count(hl7v2:PV2.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x]. (count(hl7v2:PV2.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x]. (count(hl7v2:PV2.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x]. (count(hl7v2:PV2.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x]. (count(hl7v2:PV2.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x]. (count(hl7v2:PV2.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x]. (count(hl7v2:PV2.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x]. (count(hl7v2:PV2.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x]. (count(hl7v2:PV2.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x]. (count(hl7v2:PV2.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x]. (count(hl7v2:PV2.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x]. (count(hl7v2:PV2.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x]. (count(hl7v2:PV2.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x]. (count(hl7v2:PV2.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x]. (count(hl7v2:PV2.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x]. (count(hl7v2:PV2.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x]. (count(hl7v2:PV2.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x]. (count(hl7v2:PV2.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x]. (count(hl7v2:PV2.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1"
                 priority="16442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('181') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '181' zijn. (string(@Item)=('181') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Prior Pending Location' zijn. (string(@LongName)=('Prior Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="16440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="16439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="16438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="16437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="16431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="16430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="16429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="16428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="16427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="16426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="16419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2"
                 priority="16413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('182') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '182' zijn. (string(@Item)=('182') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70129' zijn. (string(@Table)=('HL70129') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Accommodation Code' zijn. (string(@LongName)=('Accommodation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="16411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="16410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="16409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="16407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="16406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="16405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3"
                 priority="16403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('183') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '183' zijn. (string(@Item)=('183') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admit Reason' zijn. (string(@LongName)=('Admit Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="16401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="16400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="16399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="16397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="16396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="16395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4"
                 priority="16393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('184') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '184' zijn. (string(@Item)=('184') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Transfer Reason' zijn. (string(@LongName)=('Transfer Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="16391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="16390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="16389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="16387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="16386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="16385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.5"
                 priority="16383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('185') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '185' zijn. (string(@Item)=('185') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables' zijn. (string(@LongName)=('Patient Valuables') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.6"
                 priority="16382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('186') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '186' zijn. (string(@Item)=('186') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables Location' zijn. (string(@LongName)=('Patient Valuables Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.7"
                 priority="16381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('187') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '187' zijn. (string(@Item)=('187') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70130' zijn. (string(@Table)=('HL70130') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit User Code' zijn. (string(@LongName)=('Visit User Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8"
                 priority="16380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('188') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '188' zijn. (string(@Item)=('188') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Admit Date/Time' zijn. (string(@LongName)=('Expected Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="16378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="16377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9"
                 priority="16375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('189') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '189' zijn. (string(@Item)=('189') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Date/Time' zijn. (string(@LongName)=('Expected Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="16373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="16372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.10"
                 priority="16370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('711') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '711' zijn. (string(@Item)=('711') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Estimated Length of Inpatient Stay' zijn. (string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.11"
                 priority="16369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('712') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '712' zijn. (string(@Item)=('712') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Actual Length of Inpatient Stay' zijn. (string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.12"
                 priority="16368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('713') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '713' zijn. (string(@Item)=('713') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Description' zijn. (string(@LongName)=('Visit Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13"
                 priority="16367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('714') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '714' zijn. (string(@Item)=('714') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Referral Source Code' zijn. (string(@LongName)=('Referral Source Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="16365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="16364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="16357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="16356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="16355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="16354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="16353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="16352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="16351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="16345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="16343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="16342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="16340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="16338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="16332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="16330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="16320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="16308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="16306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="16301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="16296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="16295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="16282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.14"
                 priority="16269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('715') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '715' zijn. (string(@Item)=('715') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Service Date' zijn. (string(@LongName)=('Previous Service Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.15"
                 priority="16268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('716') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '716' zijn. (string(@Item)=('716') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Employment Illness Related Indicator' zijn. (string(@LongName)=('Employment Illness Related Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.16"
                 priority="16266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('717') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '717' zijn. (string(@Item)=('717') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70213' zijn. (string(@Table)=('HL70213') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Code' zijn. (string(@LongName)=('Purge Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.17"
                 priority="16265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('718') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '718' zijn. (string(@Item)=('718') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Date' zijn. (string(@LongName)=('Purge Status Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.18"
                 priority="16264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('719') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '719' zijn. (string(@Item)=('719') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70214' zijn. (string(@Table)=('HL70214') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Special Program Code' zijn. (string(@LongName)=('Special Program Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.19"
                 priority="16263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('720') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '720' zijn. (string(@Item)=('720') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Retention Indicator' zijn. (string(@LongName)=('Retention Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.20"
                 priority="16261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('721') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '721' zijn. (string(@Item)=('721') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Number of Insurance Plans' zijn. (string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.21"
                 priority="16260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('722') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '722' zijn. (string(@Item)=('722') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Publicity Code' zijn. (string(@LongName)=('Visit Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.22"
                 priority="16259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('723') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '723' zijn. (string(@Item)=('723') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Protection Indicator' zijn. (string(@LongName)=('Visit Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23"
                 priority="16257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('724') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '724' zijn. (string(@Item)=('724') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Clinic Organization Name' zijn. (string(@LongName)=('Clinic Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="16255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="16254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="16253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="16252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="16251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="16249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="16247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="16246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="16245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="16243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="16241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="16239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="16238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="16237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="16235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="16233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.24"
                 priority="16232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('725') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '725' zijn. (string(@Item)=('725') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70216' zijn. (string(@Table)=('HL70216') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Code' zijn. (string(@LongName)=('Patient Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.25"
                 priority="16231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('726') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '726' zijn. (string(@Item)=('726') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70217' zijn. (string(@Table)=('HL70217') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Priority Code' zijn. (string(@LongName)=('Visit Priority Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.26"
                 priority="16230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('727') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '727' zijn. (string(@Item)=('727') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Treatment Date' zijn. (string(@LongName)=('Previous Treatment Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.27"
                 priority="16229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('728') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '728' zijn. (string(@Item)=('728') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Disposition' zijn. (string(@LongName)=('Expected Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.28"
                 priority="16228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('729') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '729' zijn. (string(@Item)=('729') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Signature on File Date' zijn. (string(@LongName)=('Signature on File Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.29"
                 priority="16227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('730') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '730' zijn. (string(@Item)=('730') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'First Similar Illness Date' zijn. (string(@LongName)=('First Similar Illness Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30"
                 priority="16226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('731') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '731' zijn. (string(@Item)=('731') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70218' zijn. (string(@Table)=('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Charge Adjustment Code' zijn. (string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="16224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="16223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="16222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="16220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="16219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="16218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.31"
                 priority="16216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('732') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '732' zijn. (string(@Item)=('732') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70219' zijn. (string(@Table)=('HL70219') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recurring Service Code' zijn. (string(@LongName)=('Recurring Service Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.32"
                 priority="16215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('733') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '733' zijn. (string(@Item)=('733') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Billing Media Code' zijn. (string(@LongName)=('Billing Media Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33"
                 priority="16213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('734') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '734' zijn. (string(@Item)=('734') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Surgery Date and Time' zijn. (string(@LongName)=('Expected Surgery Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="16211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="16210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.34"
                 priority="16208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('735') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '735' zijn. (string(@Item)=('735') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Partnership Code' zijn. (string(@LongName)=('Military Partnership Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.35"
                 priority="16206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('736') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '736' zijn. (string(@Item)=('736') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Non-Availability Code' zijn. (string(@LongName)=('Military Non-Availability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.36"
                 priority="16204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('737') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '737' zijn. (string(@Item)=('737') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Newborn Baby Indicator' zijn. (string(@LongName)=('Newborn Baby Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.37"
                 priority="16202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('738') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '738' zijn. (string(@Item)=('738') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Baby Detained Indicator' zijn. (string(@LongName)=('Baby Detained Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38"
                 priority="16200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1543') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1543' zijn. (string(@Item)=('1543') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70430' zijn. (string(@Table)=('HL70430') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Mode of Arrival Code' zijn. (string(@LongName)=('Mode of Arrival Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="16198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="16197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="16196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="16194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="16193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="16192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39"
                 priority="16190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1544') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1544' zijn. (string(@Item)=('1544') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70431' zijn. (string(@Table)=('HL70431') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recreational Drug Use Code' zijn. (string(@LongName)=('Recreational Drug Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="16188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="16187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="16186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="16184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="16183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="16182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40"
                 priority="16180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1545') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1545' zijn. (string(@Item)=('1545') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70432' zijn. (string(@Table)=('HL70432') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admission Level of Care Code' zijn. (string(@LongName)=('Admission Level of Care Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="16178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="16177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="16176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="16174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="16173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="16172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41"
                 priority="16170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1546') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1546' zijn. (string(@Item)=('1546') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70433' zijn. (string(@Table)=('HL70433') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Precaution Code' zijn. (string(@LongName)=('Precaution Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="16168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="16167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="16166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="16164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="16163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="16162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42"
                 priority="16160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1547') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1547' zijn. (string(@Item)=('1547') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70434' zijn. (string(@Table)=('HL70434') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Condition Code' zijn. (string(@LongName)=('Patient Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="16158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="16157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="16156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="16154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="16153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="16152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.43"
                 priority="16150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.44"
                 priority="16149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45"
                 priority="16148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1548') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1548' zijn. (string(@Item)=('1548') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="16146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="16145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="16144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="16142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="16141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="16140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.46"
                 priority="16138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1549') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1549' zijn. (string(@Item)=('1549') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Effective Date' zijn. (string(@LongName)=('Patient Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47"
                 priority="16137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1550') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1550' zijn. (string(@Item)=('1550') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected LOA Return Date/Time' zijn. (string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="16135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="16134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48"
                 priority="16132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1841') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1841' zijn. (string(@Item)=('1841') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. (string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="16130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="16129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.49"
                 priority="16127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1842') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1842' zijn. (string(@Item)=('1842') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70534' zijn. (string(@Table)=('HL70534') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Notify Clergy Code' zijn. (string(@LongName)=('Notify Clergy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e44-false-d68275e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE"
                 priority="16126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN1 is required [min 1x]. (count(hl7v2:IN1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN1 komt te vaak voor [max 1x]. (count(hl7v2:IN1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN2 komt te vaak voor [max 1x]. (count(hl7v2:IN2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN3 komt te vaak voor [max 1x]. (count(hl7v2:IN3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1"
                 priority="16125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.1 is required [min 1x]. (count(hl7v2:IN1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.1 komt te vaak voor [max 1x]. (count(hl7v2:IN1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.2 is required [min 1x]. (count(hl7v2:IN1.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.2 komt te vaak voor [max 1x]. (count(hl7v2:IN1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.3 is required [min 1x]. (count(hl7v2:IN1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.8 komt te vaak voor [max 1x]. (count(hl7v2:IN1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.12 komt te vaak voor [max 1x]. (count(hl7v2:IN1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.13 komt te vaak voor [max 1x]. (count(hl7v2:IN1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.14 komt te vaak voor [max 1x]. (count(hl7v2:IN1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.15 komt te vaak voor [max 1x]. (count(hl7v2:IN1.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.17 komt te vaak voor [max 1x]. (count(hl7v2:IN1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.18 komt te vaak voor [max 1x]. (count(hl7v2:IN1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.20 komt te vaak voor [max 1x]. (count(hl7v2:IN1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.21 komt te vaak voor [max 1x]. (count(hl7v2:IN1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.22 komt te vaak voor [max 1x]. (count(hl7v2:IN1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.23 komt te vaak voor [max 1x]. (count(hl7v2:IN1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.24 komt te vaak voor [max 1x]. (count(hl7v2:IN1.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.25 komt te vaak voor [max 1x]. (count(hl7v2:IN1.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.26 komt te vaak voor [max 1x]. (count(hl7v2:IN1.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.27 komt te vaak voor [max 1x]. (count(hl7v2:IN1.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.28 komt te vaak voor [max 1x]. (count(hl7v2:IN1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.29 komt te vaak voor [max 1x]. (count(hl7v2:IN1.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.31 komt te vaak voor [max 1x]. (count(hl7v2:IN1.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.32 komt te vaak voor [max 1x]. (count(hl7v2:IN1.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.33 komt te vaak voor [max 1x]. (count(hl7v2:IN1.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.34 komt te vaak voor [max 1x]. (count(hl7v2:IN1.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.35 komt te vaak voor [max 1x]. (count(hl7v2:IN1.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.36 komt te vaak voor [max 1x]. (count(hl7v2:IN1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.37 komt te vaak voor [max 1x]. (count(hl7v2:IN1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.38 komt te vaak voor [max 1x]. (count(hl7v2:IN1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.39 komt te vaak voor [max 1x]. (count(hl7v2:IN1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.40 komt te vaak voor [max 1x]. (count(hl7v2:IN1.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.41 komt te vaak voor [max 1x]. (count(hl7v2:IN1.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.42 komt te vaak voor [max 1x]. (count(hl7v2:IN1.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.43 komt te vaak voor [max 1x]. (count(hl7v2:IN1.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.45)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.45 komt te vaak voor [max 1x]. (count(hl7v2:IN1.45)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.46 komt te vaak voor [max 1x]. (count(hl7v2:IN1.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.47 komt te vaak voor [max 1x]. (count(hl7v2:IN1.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.48 komt te vaak voor [max 1x]. (count(hl7v2:IN1.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.50)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.50 komt te vaak voor [max 1x]. (count(hl7v2:IN1.50)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.51)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.51 komt te vaak voor [max 1x]. (count(hl7v2:IN1.51)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.52)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.52 komt te vaak voor [max 1x]. (count(hl7v2:IN1.52)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.53)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.53 komt te vaak voor [max 1x]. (count(hl7v2:IN1.53)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.1"
                 priority="16124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('426') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '426' zijn. (string(@Item)=('426') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - IN1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID - IN1' zijn. (string(@LongName)=('Set ID - IN1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2"
                 priority="16123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '368' zijn. (string(@Item)=('368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70072' zijn. (string(@Table)=('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Plan ID' zijn. (string(@LongName)=('Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.1"
                 priority="16121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.2"
                 priority="16120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.3"
                 priority="16119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.4"
                 priority="16117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.5"
                 priority="16116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.6"
                 priority="16115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3"
                 priority="16113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('428') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '428' zijn. (string(@Item)=('428') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Company ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Company ID' zijn. (string(@LongName)=('Insurance Company ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.1"
                 priority="16111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.2"
                 priority="16110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.3"
                 priority="16109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4"
                 priority="16107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="16105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="16104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="16103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.5"
                 priority="16101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6"
                 priority="16099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="16097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="16096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="16095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.7"
                 priority="16093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.8"
                 priority="16092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9"
                 priority="16091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="16089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="16088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="16087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="16085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="16084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="16083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="16081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="16080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="16079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10"
                 priority="16078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="16076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="16075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="16074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="16072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="16071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="16070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="16068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="16067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="16066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4"
                 priority="16065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('429') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '429' zijn. (string(@Item)=('429') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Company Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Company Name' zijn. (string(@LongName)=('Insurance Company Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.1"
                 priority="16063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.2"
                 priority="16062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.3"
                 priority="16061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.4"
                 priority="16060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.5"
                 priority="16059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6"
                 priority="16057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.1"
                 priority="16055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.2"
                 priority="16054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.3"
                 priority="16053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.7"
                 priority="16051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8"
                 priority="16049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.1"
                 priority="16047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.2"
                 priority="16046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.3"
                 priority="16045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.9"
                 priority="16043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.10"
                 priority="16041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5"
                 priority="16040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('430') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '430' zijn. (string(@Item)=('430') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Company Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Company Address' zijn. (string(@LongName)=('Insurance Company Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1"
                 priority="16038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="16036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="16035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="16034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.2"
                 priority="16033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.3"
                 priority="16032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.4"
                 priority="16031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.5"
                 priority="16030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.6"
                 priority="16029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.7"
                 priority="16027"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.8"
                 priority="16025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.9"
                 priority="16024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.10"
                 priority="16023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.11"
                 priority="16022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12"
                 priority="16020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="16018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="16013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13"
                 priority="16008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="16006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="16005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14"
                 priority="16003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="16001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="16000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6"
                 priority="15998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('431') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '431' zijn. (string(@Item)=('431') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Co Contact Person') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Co Contact Person' zijn. (string(@LongName)=('Insurance Co Contact Person') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1"
                 priority="15996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.2"
                 priority="15989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.3"
                 priority="15988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.4"
                 priority="15987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.5"
                 priority="15986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.6"
                 priority="15985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.7"
                 priority="15984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.8"
                 priority="15982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9"
                 priority="15980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10"
                 priority="15970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.11"
                 priority="15958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12"
                 priority="15956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13"
                 priority="15951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.14"
                 priority="15946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7"
                 priority="15945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('432') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '432' zijn. (string(@Item)=('432') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Co Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insurance Co Phone Number' zijn. (string(@LongName)=('Insurance Co Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.1"
                 priority="15943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.2"
                 priority="15942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.3"
                 priority="15940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.4"
                 priority="15938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.5"
                 priority="15937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.6"
                 priority="15936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.7"
                 priority="15935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.8"
                 priority="15934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.9"
                 priority="15933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.10"
                 priority="15932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.11"
                 priority="15931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.12"
                 priority="15930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.8"
                 priority="15929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('433') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '433' zijn. (string(@Item)=('433') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Group Number' zijn. (string(@LongName)=('Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9"
                 priority="15928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('434') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '434' zijn. (string(@Item)=('434') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Group Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Group Name' zijn. (string(@LongName)=('Group Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.1"
                 priority="15926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.2"
                 priority="15925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.3"
                 priority="15924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.4"
                 priority="15923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.5"
                 priority="15922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6"
                 priority="15920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.1"
                 priority="15918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.2"
                 priority="15917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.3"
                 priority="15916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.7"
                 priority="15914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8"
                 priority="15912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.1"
                 priority="15910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.2"
                 priority="15909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.3"
                 priority="15908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.9"
                 priority="15906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.10"
                 priority="15904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10"
                 priority="15903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('435') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '435' zijn. (string(@Item)=('435') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Group Emp ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Group Emp ID' zijn. (string(@LongName)=('Insured''s Group Emp ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.1"
                 priority="15901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.2"
                 priority="15900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.3"
                 priority="15899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4"
                 priority="15897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.5"
                 priority="15891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6"
                 priority="15889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.7"
                 priority="15883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.8"
                 priority="15882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9"
                 priority="15881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10"
                 priority="15868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11"
                 priority="15855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('436') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '436' zijn. (string(@Item)=('436') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Group Emp Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Group Emp Name' zijn. (string(@LongName)=('Insured''s Group Emp Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.1"
                 priority="15853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.2"
                 priority="15852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.3"
                 priority="15851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.4"
                 priority="15850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.5"
                 priority="15849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6"
                 priority="15847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.1"
                 priority="15845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.2"
                 priority="15844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.3"
                 priority="15843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.7"
                 priority="15841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8"
                 priority="15839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.1"
                 priority="15837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.2"
                 priority="15836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.3"
                 priority="15835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.9"
                 priority="15833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.10"
                 priority="15831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.12"
                 priority="15830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('437') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '437' zijn. (string(@Item)=('437') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Plan Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Plan Effective Date' zijn. (string(@LongName)=('Plan Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.13"
                 priority="15829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('438') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '438' zijn. (string(@Item)=('438') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Plan Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Plan Expiration Date' zijn. (string(@LongName)=('Plan Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14"
                 priority="15828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.1 komt te vaak voor [max 1x]. (count(hl7v2:AUI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.2 komt te vaak voor [max 1x]. (count(hl7v2:AUI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.3 komt te vaak voor [max 1x]. (count(hl7v2:AUI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('439') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '439' zijn. (string(@Item)=('439') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('AUI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'AUI' zijn. (string(@Type)=('AUI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Authorization Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Authorization Information' zijn. (string(@LongName)=('Authorization Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.1"
                 priority="15826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Authorization Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @LongName MOET 'Authorization Number' zijn. (string(@LongName)=('Authorization Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.2"
                 priority="15825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @LongName MOET 'Date' zijn. (string(@LongName)=('Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.3"
                 priority="15824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van @LongName MOET 'Source' zijn. (string(@LongName)=('Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.15"
                 priority="15823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('440') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '440' zijn. (string(@Item)=('440') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70086') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70086' zijn. (string(@Table)=('HL70086') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Plan Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Plan Type' zijn. (string(@LongName)=('Plan Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16"
                 priority="15822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('441') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '441' zijn. (string(@Item)=('441') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Of Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Name Of Insured' zijn. (string(@LongName)=('Name Of Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1"
                 priority="15820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.2"
                 priority="15813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.3"
                 priority="15812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.4"
                 priority="15811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.5"
                 priority="15810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.6"
                 priority="15809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.7"
                 priority="15808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.8"
                 priority="15806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9"
                 priority="15804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10"
                 priority="15794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.11"
                 priority="15782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12"
                 priority="15780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13"
                 priority="15775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.14"
                 priority="15770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17"
                 priority="15769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('442') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '442' zijn. (string(@Item)=('442') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70063' zijn. (string(@Table)=('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Relationship To Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Relationship To Patient' zijn. (string(@LongName)=('Insured''s Relationship To Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.1"
                 priority="15767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.2"
                 priority="15766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.3"
                 priority="15765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.4"
                 priority="15763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.5"
                 priority="15762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.6"
                 priority="15761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18"
                 priority="15759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('443') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '443' zijn. (string(@Item)=('443') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Date Of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Date Of Birth' zijn. (string(@LongName)=('Insured''s Date Of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18/hl7v2:TS.1"
                 priority="15757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18/hl7v2:TS.2"
                 priority="15756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19"
                 priority="15754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('444') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '444' zijn. (string(@Item)=('444') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Address' zijn. (string(@LongName)=('Insured''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1"
                 priority="15752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="15750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="15749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="15748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.2"
                 priority="15747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.3"
                 priority="15746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.4"
                 priority="15745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.5"
                 priority="15744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.6"
                 priority="15743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.7"
                 priority="15741"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.8"
                 priority="15739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.9"
                 priority="15738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.10"
                 priority="15737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.11"
                 priority="15736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12"
                 priority="15734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="15732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="15727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13"
                 priority="15722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="15720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="15719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14"
                 priority="15717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="15715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="15714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.20"
                 priority="15712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('445') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '445' zijn. (string(@Item)=('445') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70135') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70135' zijn. (string(@Table)=('HL70135') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assignment Of Benefits') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Assignment Of Benefits' zijn. (string(@LongName)=('Assignment Of Benefits') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.21"
                 priority="15711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('446') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '446' zijn. (string(@Item)=('446') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70173') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70173' zijn. (string(@Table)=('HL70173') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coordination Of Benefits') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Coordination Of Benefits' zijn. (string(@LongName)=('Coordination Of Benefits') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.22"
                 priority="15710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('447') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '447' zijn. (string(@Item)=('447') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coord Of Ben. Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Coord Of Ben. Priority' zijn. (string(@LongName)=('Coord Of Ben. Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.23"
                 priority="15709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('448') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '448' zijn. (string(@Item)=('448') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notice Of Admission Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Notice Of Admission Flag' zijn. (string(@LongName)=('Notice Of Admission Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.24"
                 priority="15707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('449') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '449' zijn. (string(@Item)=('449') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notice Of Admission Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Notice Of Admission Date' zijn. (string(@LongName)=('Notice Of Admission Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.25"
                 priority="15706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('450') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '450' zijn. (string(@Item)=('450') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Report Of Eligibility Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Report Of Eligibility Flag' zijn. (string(@LongName)=('Report Of Eligibility Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.26"
                 priority="15704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('451') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '451' zijn. (string(@Item)=('451') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Report Of Eligibility Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Report Of Eligibility Date' zijn. (string(@LongName)=('Report Of Eligibility Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.27"
                 priority="15703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('452') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '452' zijn. (string(@Item)=('452') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70093') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70093' zijn. (string(@Table)=('HL70093') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Release Information Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Release Information Code' zijn. (string(@LongName)=('Release Information Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.28"
                 priority="15702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('453') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '453' zijn. (string(@Item)=('453') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Admit Cert (PAC)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Pre-Admit Cert (PAC)' zijn. (string(@LongName)=('Pre-Admit Cert (PAC)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29"
                 priority="15701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('454') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '454' zijn. (string(@Item)=('454') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verification Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Verification Date/Time' zijn. (string(@LongName)=('Verification Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29/hl7v2:TS.1"
                 priority="15699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29/hl7v2:TS.2"
                 priority="15698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30"
                 priority="15696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('455') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '455' zijn. (string(@Item)=('455') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verification By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Verification By' zijn. (string(@LongName)=('Verification By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.1"
                 priority="15694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2"
                 priority="15693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="15691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="15690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="15689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="15688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="15687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.3"
                 priority="15686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.4"
                 priority="15685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.5"
                 priority="15684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.6"
                 priority="15683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.7"
                 priority="15682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.8"
                 priority="15681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9"
                 priority="15680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="15678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="15677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="15676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.10"
                 priority="15674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.11"
                 priority="15672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.12"
                 priority="15671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.13"
                 priority="15669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14"
                 priority="15667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="15665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="15664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="15663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.15"
                 priority="15661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16"
                 priority="15659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="15657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="15656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="15655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="15653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="15652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="15651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17"
                 priority="15649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="15647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="15642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.18"
                 priority="15637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19"
                 priority="15635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="15633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="15632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20"
                 priority="15630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="15628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="15627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.21"
                 priority="15625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22"
                 priority="15624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="15622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="15621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="15620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="15618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="15617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="15616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="15614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="15613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="15612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23"
                 priority="15611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="15609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="15608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="15607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="15605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="15604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="15603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="15601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="15600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="15599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.31"
                 priority="15598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('456') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '456' zijn. (string(@Item)=('456') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70098') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70098' zijn. (string(@Table)=('HL70098') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Type Of Agreement Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Type Of Agreement Code' zijn. (string(@LongName)=('Type Of Agreement Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.32"
                 priority="15597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('457') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '457' zijn. (string(@Item)=('457') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70022') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70022' zijn. (string(@Table)=('HL70022') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Billing Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Billing Status' zijn. (string(@LongName)=('Billing Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.33"
                 priority="15596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('458') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '458' zijn. (string(@Item)=('458') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lifetime Reserve Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Lifetime Reserve Days' zijn. (string(@LongName)=('Lifetime Reserve Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.34"
                 priority="15595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('459') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '459' zijn. (string(@Item)=('459') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delay Before L.R. Day') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Delay Before L.R. Day' zijn. (string(@LongName)=('Delay Before L.R. Day') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.35"
                 priority="15594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('460') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '460' zijn. (string(@Item)=('460') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70042') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70042' zijn. (string(@Table)=('HL70042') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Company Plan Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Company Plan Code' zijn. (string(@LongName)=('Company Plan Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.36"
                 priority="15593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('461') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '461' zijn. (string(@Item)=('461') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Policy Number' zijn. (string(@LongName)=('Policy Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37"
                 priority="15592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('462') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '462' zijn. (string(@Item)=('462') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Policy Deductible' zijn. (string(@LongName)=('Policy Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1"
                 priority="15590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.2"
                 priority="15585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.3"
                 priority="15583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.4"
                 priority="15582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5"
                 priority="15581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.6"
                 priority="15571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38"
                 priority="15569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('463') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '463' zijn. (string(@Item)=('463') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Limit - Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Policy Limit - Amount' zijn. (string(@LongName)=('Policy Limit - Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1"
                 priority="15567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.2"
                 priority="15562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.3"
                 priority="15560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.4"
                 priority="15559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5"
                 priority="15558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.6"
                 priority="15548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.39"
                 priority="15546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('464') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '464' zijn. (string(@Item)=('464') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Limit - Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Policy Limit - Days' zijn. (string(@LongName)=('Policy Limit - Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40"
                 priority="15545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('465') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '465' zijn. (string(@Item)=('465') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room Rate - Semi-Private') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Room Rate - Semi-Private' zijn. (string(@LongName)=('Room Rate - Semi-Private') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1"
                 priority="15543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.2"
                 priority="15538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.3"
                 priority="15536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.4"
                 priority="15535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5"
                 priority="15534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.6"
                 priority="15524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41"
                 priority="15522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('466') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '466' zijn. (string(@Item)=('466') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room Rate - Private') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Room Rate - Private' zijn. (string(@LongName)=('Room Rate - Private') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1"
                 priority="15520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.2"
                 priority="15515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.3"
                 priority="15513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.4"
                 priority="15512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5"
                 priority="15511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.6"
                 priority="15501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42"
                 priority="15499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('467') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '467' zijn. (string(@Item)=('467') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70066') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70066' zijn. (string(@Table)=('HL70066') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employment Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Employment Status' zijn. (string(@LongName)=('Insured''s Employment Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.1"
                 priority="15497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.2"
                 priority="15496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.3"
                 priority="15495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.4"
                 priority="15493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.5"
                 priority="15492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.6"
                 priority="15491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.43"
                 priority="15489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('468') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '468' zijn. (string(@Item)=('468') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Administrative Sex' zijn. (string(@LongName)=('Insured''s Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44"
                 priority="15488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('469') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '469' zijn. (string(@Item)=('469') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employer''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s Employer''s Address' zijn. (string(@LongName)=('Insured''s Employer''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1"
                 priority="15486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="15484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="15483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="15482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.2"
                 priority="15481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.3"
                 priority="15480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.4"
                 priority="15479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.5"
                 priority="15478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.6"
                 priority="15477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.7"
                 priority="15475"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.8"
                 priority="15473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.9"
                 priority="15472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.10"
                 priority="15471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.11"
                 priority="15470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12"
                 priority="15468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="15466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="15461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13"
                 priority="15456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="15454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="15453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14"
                 priority="15451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="15449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="15448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.45"
                 priority="15446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('470') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '470' zijn. (string(@Item)=('470') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verification Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Verification Status' zijn. (string(@LongName)=('Verification Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.46"
                 priority="15445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('471') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '471' zijn. (string(@Item)=('471') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70072' zijn. (string(@Table)=('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Prior Insurance Plan ID' zijn. (string(@LongName)=('Prior Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.47"
                 priority="15444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1227' zijn. (string(@Item)=('1227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70309') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70309' zijn. (string(@Table)=('HL70309') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coverage Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Coverage Type' zijn. (string(@LongName)=('Coverage Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.48"
                 priority="15443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49"
                 priority="15442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1230' zijn. (string(@Item)=('1230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured''s ID Number' zijn. (string(@LongName)=('Insured''s ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.1"
                 priority="15440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.2"
                 priority="15439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.3"
                 priority="15438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4"
                 priority="15436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.5"
                 priority="15430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6"
                 priority="15428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.7"
                 priority="15422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.8"
                 priority="15421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9"
                 priority="15420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10"
                 priority="15407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.50"
                 priority="15394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1854') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1854' zijn. (string(@Item)=('1854') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70535') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70535' zijn. (string(@Table)=('HL70535') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Signature Code' zijn. (string(@LongName)=('Signature Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.51"
                 priority="15393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1855') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1855' zijn. (string(@Item)=('1855') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature Code Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Signature Code Date' zijn. (string(@LongName)=('Signature Code Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.52"
                 priority="15392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1899') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1899' zijn. (string(@Item)=('1899') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured_s Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'Insured_s Birth Place' zijn. (string(@LongName)=('Insured_s Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.53"
                 priority="15391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1852') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Item MOET '1852' zijn. (string(@Item)=('1852') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2"
                 priority="15390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.2 komt te vaak voor [max 1x]. (count(hl7v2:IN2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.4 komt te vaak voor [max 1x]. (count(hl7v2:IN2.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.6 komt te vaak voor [max 1x]. (count(hl7v2:IN2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.8 komt te vaak voor [max 1x]. (count(hl7v2:IN2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.10 komt te vaak voor [max 1x]. (count(hl7v2:IN2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.11 komt te vaak voor [max 1x]. (count(hl7v2:IN2.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.12 komt te vaak voor [max 1x]. (count(hl7v2:IN2.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.13 komt te vaak voor [max 1x]. (count(hl7v2:IN2.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.14 komt te vaak voor [max 1x]. (count(hl7v2:IN2.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.15 komt te vaak voor [max 1x]. (count(hl7v2:IN2.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.16 komt te vaak voor [max 1x]. (count(hl7v2:IN2.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.17 komt te vaak voor [max 1x]. (count(hl7v2:IN2.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.18 komt te vaak voor [max 1x]. (count(hl7v2:IN2.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.19 komt te vaak voor [max 1x]. (count(hl7v2:IN2.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.20 komt te vaak voor [max 1x]. (count(hl7v2:IN2.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.21 komt te vaak voor [max 1x]. (count(hl7v2:IN2.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.23 komt te vaak voor [max 1x]. (count(hl7v2:IN2.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.27 komt te vaak voor [max 1x]. (count(hl7v2:IN2.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.30 komt te vaak voor [max 1x]. (count(hl7v2:IN2.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.31 komt te vaak voor [max 1x]. (count(hl7v2:IN2.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.34 komt te vaak voor [max 1x]. (count(hl7v2:IN2.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.35 komt te vaak voor [max 1x]. (count(hl7v2:IN2.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.36 komt te vaak voor [max 1x]. (count(hl7v2:IN2.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.37 komt te vaak voor [max 1x]. (count(hl7v2:IN2.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.38 komt te vaak voor [max 1x]. (count(hl7v2:IN2.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.39 komt te vaak voor [max 1x]. (count(hl7v2:IN2.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.41 komt te vaak voor [max 1x]. (count(hl7v2:IN2.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.44 komt te vaak voor [max 1x]. (count(hl7v2:IN2.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.45)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.45 komt te vaak voor [max 1x]. (count(hl7v2:IN2.45)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.46 komt te vaak voor [max 1x]. (count(hl7v2:IN2.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.47 komt te vaak voor [max 1x]. (count(hl7v2:IN2.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.48 komt te vaak voor [max 1x]. (count(hl7v2:IN2.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.51)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.51 komt te vaak voor [max 1x]. (count(hl7v2:IN2.51)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.55)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.55 komt te vaak voor [max 1x]. (count(hl7v2:IN2.55)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.57)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.57 komt te vaak voor [max 1x]. (count(hl7v2:IN2.57)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.58)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.58 komt te vaak voor [max 1x]. (count(hl7v2:IN2.58)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.59)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.59 komt te vaak voor [max 1x]. (count(hl7v2:IN2.59)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.60)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.60 komt te vaak voor [max 1x]. (count(hl7v2:IN2.60)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.61)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.61 komt te vaak voor [max 1x]. (count(hl7v2:IN2.61)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.62)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.62 komt te vaak voor [max 1x]. (count(hl7v2:IN2.62)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.65)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.65 komt te vaak voor [max 1x]. (count(hl7v2:IN2.65)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.66)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.66 komt te vaak voor [max 1x]. (count(hl7v2:IN2.66)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.67)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.67 komt te vaak voor [max 1x]. (count(hl7v2:IN2.67)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.68)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.68 komt te vaak voor [max 1x]. (count(hl7v2:IN2.68)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.72)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.72 komt te vaak voor [max 1x]. (count(hl7v2:IN2.72)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1"
                 priority="15389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('472') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '472' zijn. (string(@Item)=('472') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employee ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Employee ID' zijn. (string(@LongName)=('Insured''s Employee ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.1"
                 priority="15387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.2"
                 priority="15386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.3"
                 priority="15385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4"
                 priority="15383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.5"
                 priority="15377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6"
                 priority="15375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.7"
                 priority="15369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.8"
                 priority="15368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9"
                 priority="15367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10"
                 priority="15354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.2"
                 priority="15341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '473' zijn. (string(@Item)=('473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Social Security Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Social Security Number' zijn. (string(@LongName)=('Insured''s Social Security Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3"
                 priority="15340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '474' zijn. (string(@Item)=('474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employer''s Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Employer''s Name and ID' zijn. (string(@LongName)=('Insured''s Employer''s Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.1"
                 priority="15338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2"
                 priority="15337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="15335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="15334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="15333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="15332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="15331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.3"
                 priority="15330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.4"
                 priority="15329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.5"
                 priority="15328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.6"
                 priority="15327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.7"
                 priority="15326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.8"
                 priority="15325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9"
                 priority="15324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="15322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="15321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="15320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.10"
                 priority="15318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.11"
                 priority="15316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.12"
                 priority="15315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.13"
                 priority="15313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14"
                 priority="15311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="15309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="15308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="15307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.15"
                 priority="15305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16"
                 priority="15303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="15301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="15300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="15299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="15297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="15296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="15295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17"
                 priority="15293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="15291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="15286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.18"
                 priority="15281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19"
                 priority="15279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="15277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="15276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20"
                 priority="15274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="15272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="15271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.21"
                 priority="15269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22"
                 priority="15268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="15266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="15265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="15264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="15262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="15261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="15260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="15258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="15257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="15256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23"
                 priority="15255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="15253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="15252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="15251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="15249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="15248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="15247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="15245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="15244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="15243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.4"
                 priority="15242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '475' zijn. (string(@Item)=('475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70139') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70139' zijn. (string(@Table)=('HL70139') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employer Information Data') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Employer Information Data' zijn. (string(@LongName)=('Employer Information Data') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.5"
                 priority="15241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('476') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '476' zijn. (string(@Item)=('476') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70137') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70137' zijn. (string(@Table)=('HL70137') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mail Claim Party') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Mail Claim Party' zijn. (string(@LongName)=('Mail Claim Party') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.6"
                 priority="15240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('477') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '477' zijn. (string(@Item)=('477') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medicare Health Ins Card Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Medicare Health Ins Card Number' zijn. (string(@LongName)=('Medicare Health Ins Card Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7"
                 priority="15239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('478') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '478' zijn. (string(@Item)=('478') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medicaid Case Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Medicaid Case Name' zijn. (string(@LongName)=('Medicaid Case Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1"
                 priority="15237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.2"
                 priority="15230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.3"
                 priority="15229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.4"
                 priority="15228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.5"
                 priority="15227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.6"
                 priority="15226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.7"
                 priority="15225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.8"
                 priority="15223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9"
                 priority="15221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10"
                 priority="15211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.11"
                 priority="15199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12"
                 priority="15197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13"
                 priority="15192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.14"
                 priority="15187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.8"
                 priority="15186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '479' zijn. (string(@Item)=('479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medicaid Case Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Medicaid Case Number' zijn. (string(@LongName)=('Medicaid Case Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9"
                 priority="15185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '480' zijn. (string(@Item)=('480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Sponsor Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Sponsor Name' zijn. (string(@LongName)=('Military Sponsor Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1"
                 priority="15183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.2"
                 priority="15176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.3"
                 priority="15175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.4"
                 priority="15174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.5"
                 priority="15173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.6"
                 priority="15172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.7"
                 priority="15171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.8"
                 priority="15169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9"
                 priority="15167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10"
                 priority="15157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.11"
                 priority="15145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12"
                 priority="15143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13"
                 priority="15138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.14"
                 priority="15133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.10"
                 priority="15132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('481') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '481' zijn. (string(@Item)=('481') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military ID Number' zijn. (string(@LongName)=('Military ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11"
                 priority="15131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('482') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '482' zijn. (string(@Item)=('482') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70342') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70342' zijn. (string(@Table)=('HL70342') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dependent Of Military Recipient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Dependent Of Military Recipient' zijn. (string(@LongName)=('Dependent Of Military Recipient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.1"
                 priority="15129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.2"
                 priority="15128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.3"
                 priority="15127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.4"
                 priority="15125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.5"
                 priority="15124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.6"
                 priority="15123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.12"
                 priority="15121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('483') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '483' zijn. (string(@Item)=('483') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Organization' zijn. (string(@LongName)=('Military Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.13"
                 priority="15120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('484') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '484' zijn. (string(@Item)=('484') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Station') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Station' zijn. (string(@LongName)=('Military Station') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.14"
                 priority="15119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('485') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '485' zijn. (string(@Item)=('485') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70140' zijn. (string(@Table)=('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Service' zijn. (string(@LongName)=('Military Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.15"
                 priority="15118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '486' zijn. (string(@Item)=('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70141' zijn. (string(@Table)=('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Rank/Grade' zijn. (string(@LongName)=('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.16"
                 priority="15117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('487') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '487' zijn. (string(@Item)=('487') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70142' zijn. (string(@Table)=('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Status' zijn. (string(@LongName)=('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.17"
                 priority="15116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('488') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '488' zijn. (string(@Item)=('488') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Retire Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Retire Date' zijn. (string(@LongName)=('Military Retire Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.18"
                 priority="15115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('489') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '489' zijn. (string(@Item)=('489') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Non-Avail Cert On File') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Non-Avail Cert On File' zijn. (string(@LongName)=('Military Non-Avail Cert On File') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.19"
                 priority="15113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('490') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '490' zijn. (string(@Item)=('490') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Baby Coverage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Baby Coverage' zijn. (string(@LongName)=('Baby Coverage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.20"
                 priority="15111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('491') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '491' zijn. (string(@Item)=('491') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Combine Baby Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Combine Baby Bill' zijn. (string(@LongName)=('Combine Baby Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.21"
                 priority="15109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('492') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '492' zijn. (string(@Item)=('492') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Blood Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Blood Deductible' zijn. (string(@LongName)=('Blood Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22"
                 priority="15108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('493') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '493' zijn. (string(@Item)=('493') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Coverage Approval Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Special Coverage Approval Name' zijn. (string(@LongName)=('Special Coverage Approval Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1"
                 priority="15106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.2"
                 priority="15099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.3"
                 priority="15098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.4"
                 priority="15097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.5"
                 priority="15096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.6"
                 priority="15095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.7"
                 priority="15094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.8"
                 priority="15092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9"
                 priority="15090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10"
                 priority="15080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.11"
                 priority="15068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12"
                 priority="15066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13"
                 priority="15061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.14"
                 priority="15056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.23"
                 priority="15055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('494') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '494' zijn. (string(@Item)=('494') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Coverage Approval Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Special Coverage Approval Title' zijn. (string(@LongName)=('Special Coverage Approval Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.24"
                 priority="15054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('495') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '495' zijn. (string(@Item)=('495') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70143') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70143' zijn. (string(@Table)=('HL70143') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Non-Covered Insurance Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Non-Covered Insurance Code' zijn. (string(@LongName)=('Non-Covered Insurance Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25"
                 priority="15053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('496') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '496' zijn. (string(@Item)=('496') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Payor ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Payor ID' zijn. (string(@LongName)=('Payor ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.1"
                 priority="15051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.2"
                 priority="15050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.3"
                 priority="15049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4"
                 priority="15047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.5"
                 priority="15041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6"
                 priority="15039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.7"
                 priority="15033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.8"
                 priority="15032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9"
                 priority="15031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10"
                 priority="15018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26"
                 priority="15005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('497') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '497' zijn. (string(@Item)=('497') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Payor Subscriber ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Payor Subscriber ID' zijn. (string(@LongName)=('Payor Subscriber ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.1"
                 priority="15003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.2"
                 priority="15002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.3"
                 priority="15001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4"
                 priority="14999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.5"
                 priority="14993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6"
                 priority="14991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.7"
                 priority="14985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.8"
                 priority="14984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9"
                 priority="14983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10"
                 priority="14970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.27"
                 priority="14957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('498') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '498' zijn. (string(@Item)=('498') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70144') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70144' zijn. (string(@Table)=('HL70144') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Eligibility Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Eligibility Source' zijn. (string(@LongName)=('Eligibility Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28"
                 priority="14956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.1 komt te vaak voor [max 1x]. (count(hl7v2:RMC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.2 komt te vaak voor [max 1x]. (count(hl7v2:RMC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.3 komt te vaak voor [max 1x]. (count(hl7v2:RMC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.4 komt te vaak voor [max 1x]. (count(hl7v2:RMC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('499') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '499' zijn. (string(@Item)=('499') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RMC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'RMC' zijn. (string(@Type)=('RMC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room Coverage Type/Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Room Coverage Type/Amount' zijn. (string(@LongName)=('Room Coverage Type/Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.1"
                 priority="14954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70145') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Table MOET 'HL70145' zijn. (string(@Table)=('HL70145') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @LongName MOET 'Room Type' zijn. (string(@LongName)=('Room Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.2"
                 priority="14953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70146') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Table MOET 'HL70146' zijn. (string(@Table)=('HL70146') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Amount Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @LongName MOET 'Amount Type' zijn. (string(@LongName)=('Amount Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.3"
                 priority="14952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coverage Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @LongName MOET 'Coverage Amount' zijn. (string(@LongName)=('Coverage Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4"
                 priority="14951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @Type MOET 'MOP' zijn. (string(@Type)=('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van @LongName MOET 'Money or Percentage' zijn. (string(@LongName)=('Money or Percentage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.1"
                 priority="14949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Table MOET 'HL70148' zijn. (string(@Table)=('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Indicator' zijn. (string(@LongName)=('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.2"
                 priority="14947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Quantity' zijn. (string(@LongName)=('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.3"
                 priority="14946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Currency Denomination' zijn. (string(@LongName)=('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29"
                 priority="14944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.1 komt te vaak voor [max 1x]. (count(hl7v2:PTA.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.2 komt te vaak voor [max 1x]. (count(hl7v2:PTA.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.3 komt te vaak voor [max 1x]. (count(hl7v2:PTA.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.4 komt te vaak voor [max 1x]. (count(hl7v2:PTA.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('500') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '500' zijn. (string(@Item)=('500') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PTA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'PTA' zijn. (string(@Type)=('PTA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Type/Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Policy Type/Amount' zijn. (string(@LongName)=('Policy Type/Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.1"
                 priority="14942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70147') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Table MOET 'HL70147' zijn. (string(@Table)=('HL70147') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @LongName MOET 'Policy Type' zijn. (string(@LongName)=('Policy Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.2"
                 priority="14941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70193') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Table MOET 'HL70193' zijn. (string(@Table)=('HL70193') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Amount Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @LongName MOET 'Amount Class' zijn. (string(@LongName)=('Amount Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.3"
                 priority="14940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @LongName MOET 'Money or Percentage Quantity' zijn. (string(@LongName)=('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4"
                 priority="14939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @Type MOET 'MOP' zijn. (string(@Type)=('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van @LongName MOET 'Money or Percentage' zijn. (string(@LongName)=('Money or Percentage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.1"
                 priority="14937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Table MOET 'HL70148' zijn. (string(@Table)=('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Indicator' zijn. (string(@LongName)=('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.2"
                 priority="14935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Quantity' zijn. (string(@LongName)=('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.3"
                 priority="14934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Currency Denomination' zijn. (string(@LongName)=('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30"
                 priority="14932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.1 komt te vaak voor [max 1x]. (count(hl7v2:DDI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.2 komt te vaak voor [max 1x]. (count(hl7v2:DDI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.3 komt te vaak voor [max 1x]. (count(hl7v2:DDI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('501') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '501' zijn. (string(@Item)=('501') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DDI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DDI' zijn. (string(@Type)=('DDI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Daily Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Daily Deductible' zijn. (string(@LongName)=('Daily Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.1"
                 priority="14930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delay Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @LongName MOET 'Delay Days' zijn. (string(@LongName)=('Delay Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2"
                 priority="14929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @LongName MOET 'Monetary Amount' zijn. (string(@LongName)=('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2/hl7v2:MO.1"
                 priority="14927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2/hl7v2:MO.2"
                 priority="14926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.3"
                 priority="14924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van @LongName MOET 'Number of Days' zijn. (string(@LongName)=('Number of Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.31"
                 priority="14923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.32"
                 priority="14922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33"
                 priority="14921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.1"
                 priority="14919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.2"
                 priority="14918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.3"
                 priority="14917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.4"
                 priority="14915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.5"
                 priority="14914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.6"
                 priority="14913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34"
                 priority="14911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.1"
                 priority="14909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.2"
                 priority="14908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.3"
                 priority="14907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.4"
                 priority="14905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.5"
                 priority="14904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.6"
                 priority="14903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.35"
                 priority="14901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36"
                 priority="14900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.1"
                 priority="14898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.2"
                 priority="14897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.3"
                 priority="14896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.4"
                 priority="14894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.5"
                 priority="14893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.6"
                 priority="14892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.37"
                 priority="14890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.38"
                 priority="14888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39"
                 priority="14887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.1"
                 priority="14885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.2"
                 priority="14884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.3"
                 priority="14883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.4"
                 priority="14881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.5"
                 priority="14880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.6"
                 priority="14879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40"
                 priority="14877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1"
                 priority="14875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.2"
                 priority="14868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.3"
                 priority="14867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.4"
                 priority="14866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.5"
                 priority="14865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.6"
                 priority="14864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.7"
                 priority="14863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.8"
                 priority="14861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9"
                 priority="14859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10"
                 priority="14849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.11"
                 priority="14837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12"
                 priority="14835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13"
                 priority="14830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.14"
                 priority="14825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41"
                 priority="14824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.1"
                 priority="14822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.2"
                 priority="14821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.3"
                 priority="14820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.4"
                 priority="14818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.5"
                 priority="14817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.6"
                 priority="14816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42"
                 priority="14814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.1"
                 priority="14812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.2"
                 priority="14811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.3"
                 priority="14810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.4"
                 priority="14808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.5"
                 priority="14807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.6"
                 priority="14806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43"
                 priority="14804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '119' zijn. (string(@Item)=('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Marital Status' zijn. (string(@LongName)=('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.1"
                 priority="14802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.2"
                 priority="14801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.3"
                 priority="14800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.4"
                 priority="14798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.5"
                 priority="14797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.6"
                 priority="14796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.44"
                 priority="14794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('787') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '787' zijn. (string(@Item)=('787') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employment Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Employment Start Date' zijn. (string(@LongName)=('Insured''s Employment Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.45"
                 priority="14793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('783') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '783' zijn. (string(@Item)=('783') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Employment Stop Date' zijn. (string(@LongName)=('Employment Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.46"
                 priority="14792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('785') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '785' zijn. (string(@Item)=('785') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Job Title' zijn. (string(@LongName)=('Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47"
                 priority="14791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('786') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '786' zijn. (string(@Item)=('786') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'JCC' zijn. (string(@Type)=('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Job Code/Class' zijn. (string(@LongName)=('Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.1"
                 priority="14789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70327' zijn. (string(@Table)=('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Code' zijn. (string(@LongName)=('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.2"
                 priority="14788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70328' zijn. (string(@Table)=('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Class' zijn. (string(@LongName)=('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3"
                 priority="14787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Description Text' zijn. (string(@LongName)=('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape"
                 priority="14786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="14785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="14784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.48"
                 priority="14783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '752' zijn. (string(@Item)=('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70311' zijn. (string(@Table)=('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Job Status' zijn. (string(@LongName)=('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49"
                 priority="14782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('789') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '789' zijn. (string(@Item)=('789') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employer Contact Person Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Employer Contact Person Name' zijn. (string(@LongName)=('Employer Contact Person Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1"
                 priority="14780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.2"
                 priority="14773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.3"
                 priority="14772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.4"
                 priority="14771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.5"
                 priority="14770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.6"
                 priority="14769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.7"
                 priority="14768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.8"
                 priority="14766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9"
                 priority="14764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10"
                 priority="14754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.11"
                 priority="14742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12"
                 priority="14740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13"
                 priority="14735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.14"
                 priority="14730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50"
                 priority="14729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('790') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '790' zijn. (string(@Item)=('790') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employer Contact Person Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Employer Contact Person Phone Number' zijn. (string(@LongName)=('Employer Contact Person Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.1"
                 priority="14727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.2"
                 priority="14726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.3"
                 priority="14724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.4"
                 priority="14722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.5"
                 priority="14721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.6"
                 priority="14720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.7"
                 priority="14719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.8"
                 priority="14718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.9"
                 priority="14717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.10"
                 priority="14716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.11"
                 priority="14715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.12"
                 priority="14714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.51"
                 priority="14713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('791') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '791' zijn. (string(@Item)=('791') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70222' zijn. (string(@Table)=('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employer Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Employer Contact Reason' zijn. (string(@LongName)=('Employer Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52"
                 priority="14712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('792') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '792' zijn. (string(@Item)=('792') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Contact Person''s Name' zijn. (string(@LongName)=('Insured''s Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1"
                 priority="14710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.2"
                 priority="14703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.3"
                 priority="14702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.4"
                 priority="14701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.5"
                 priority="14700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.6"
                 priority="14699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.7"
                 priority="14698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.8"
                 priority="14696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9"
                 priority="14694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10"
                 priority="14684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.11"
                 priority="14672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12"
                 priority="14670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13"
                 priority="14665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.14"
                 priority="14660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53"
                 priority="14659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('793') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '793' zijn. (string(@Item)=('793') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Contact Person Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Contact Person Phone Number' zijn. (string(@LongName)=('Insured''s Contact Person Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.1"
                 priority="14657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.2"
                 priority="14656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.3"
                 priority="14654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.4"
                 priority="14652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.5"
                 priority="14651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.6"
                 priority="14650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.7"
                 priority="14649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.8"
                 priority="14648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.9"
                 priority="14647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.10"
                 priority="14646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.11"
                 priority="14645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.12"
                 priority="14644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.54"
                 priority="14643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('794') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '794' zijn. (string(@Item)=('794') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70222' zijn. (string(@Table)=('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Contact Person Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Contact Person Reason' zijn. (string(@LongName)=('Insured''s Contact Person Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.55"
                 priority="14642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('795') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '795' zijn. (string(@Item)=('795') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relationship to the Patient Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Relationship to the Patient Start Date' zijn. (string(@LongName)=('Relationship to the Patient Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.56"
                 priority="14641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('796') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '796' zijn. (string(@Item)=('796') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relationship to the Patient Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Relationship to the Patient Stop Date' zijn. (string(@LongName)=('Relationship to the Patient Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.57"
                 priority="14640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('797') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '797' zijn. (string(@Item)=('797') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70232') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70232' zijn. (string(@Table)=('HL70232') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Co. Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insurance Co. Contact Reason' zijn. (string(@LongName)=('Insurance Co. Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58"
                 priority="14639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('798') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '798' zijn. (string(@Item)=('798') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Co Contact Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insurance Co Contact Phone Number' zijn. (string(@LongName)=('Insurance Co Contact Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.1"
                 priority="14637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.2"
                 priority="14636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.3"
                 priority="14634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.4"
                 priority="14632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.5"
                 priority="14631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.6"
                 priority="14630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.7"
                 priority="14629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.8"
                 priority="14628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.9"
                 priority="14627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.10"
                 priority="14626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.11"
                 priority="14625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.12"
                 priority="14624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.59"
                 priority="14623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('799') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '799' zijn. (string(@Item)=('799') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70312') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70312' zijn. (string(@Table)=('HL70312') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Scope') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Policy Scope' zijn. (string(@LongName)=('Policy Scope') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.60"
                 priority="14622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('800') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '800' zijn. (string(@Item)=('800') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70313') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70313' zijn. (string(@Table)=('HL70313') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Policy Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Policy Source' zijn. (string(@LongName)=('Policy Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61"
                 priority="14621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('801') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '801' zijn. (string(@Item)=('801') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Member Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Patient Member Number' zijn. (string(@LongName)=('Patient Member Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.1"
                 priority="14619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.2"
                 priority="14618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.3"
                 priority="14617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4"
                 priority="14615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.5"
                 priority="14609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6"
                 priority="14607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.7"
                 priority="14601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.8"
                 priority="14600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9"
                 priority="14599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10"
                 priority="14586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62"
                 priority="14573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('802') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '802' zijn. (string(@Item)=('802') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70063' zijn. (string(@Table)=('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor''s Relationship To Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Guarantor''s Relationship To Insured' zijn. (string(@LongName)=('Guarantor''s Relationship To Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.1"
                 priority="14571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.2"
                 priority="14570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.3"
                 priority="14569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.4"
                 priority="14567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.5"
                 priority="14566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.6"
                 priority="14565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63"
                 priority="14563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('803') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '803' zijn. (string(@Item)=('803') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Phone Number - Home' zijn. (string(@LongName)=('Insured''s Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.1"
                 priority="14561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.2"
                 priority="14560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.3"
                 priority="14558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.4"
                 priority="14556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.5"
                 priority="14555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.6"
                 priority="14554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.7"
                 priority="14553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.8"
                 priority="14552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.9"
                 priority="14551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.10"
                 priority="14550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.11"
                 priority="14549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.12"
                 priority="14548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64"
                 priority="14547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('804') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '804' zijn. (string(@Item)=('804') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured''s Employer Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured''s Employer Phone Number' zijn. (string(@LongName)=('Insured''s Employer Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.1"
                 priority="14545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.2"
                 priority="14544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.3"
                 priority="14542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.4"
                 priority="14540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.5"
                 priority="14539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.6"
                 priority="14538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.7"
                 priority="14537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.8"
                 priority="14536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.9"
                 priority="14535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.10"
                 priority="14534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.11"
                 priority="14533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.12"
                 priority="14532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65"
                 priority="14531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('805') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '805' zijn. (string(@Item)=('805') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70343') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70343' zijn. (string(@Table)=('HL70343') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Handicapped Program') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Military Handicapped Program' zijn. (string(@LongName)=('Military Handicapped Program') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.1"
                 priority="14529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.2"
                 priority="14528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.3"
                 priority="14527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.4"
                 priority="14525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.5"
                 priority="14524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.6"
                 priority="14523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.66"
                 priority="14521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('806') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '806' zijn. (string(@Item)=('806') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suspend Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Suspend Flag' zijn. (string(@LongName)=('Suspend Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.67"
                 priority="14519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('807') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '807' zijn. (string(@Item)=('807') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Copay Limit Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Copay Limit Flag' zijn. (string(@LongName)=('Copay Limit Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.68"
                 priority="14517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('808') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '808' zijn. (string(@Item)=('808') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Stoploss Limit Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Stoploss Limit Flag' zijn. (string(@LongName)=('Stoploss Limit Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69"
                 priority="14515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('809') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '809' zijn. (string(@Item)=('809') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured Organization Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured Organization Name and ID' zijn. (string(@LongName)=('Insured Organization Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.1"
                 priority="14513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.2"
                 priority="14512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.3"
                 priority="14511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.4"
                 priority="14510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.5"
                 priority="14509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6"
                 priority="14507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.1"
                 priority="14505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.2"
                 priority="14504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.3"
                 priority="14503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.7"
                 priority="14501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8"
                 priority="14499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.1"
                 priority="14497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.2"
                 priority="14496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.3"
                 priority="14495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.9"
                 priority="14493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.10"
                 priority="14491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70"
                 priority="14490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('810') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '810' zijn. (string(@Item)=('810') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insured Employer Organization Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Insured Employer Organization Name and ID' zijn. (string(@LongName)=('Insured Employer Organization Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.1"
                 priority="14488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.2"
                 priority="14487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.3"
                 priority="14486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.4"
                 priority="14485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.5"
                 priority="14484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6"
                 priority="14482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.1"
                 priority="14480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.2"
                 priority="14479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.3"
                 priority="14478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.7"
                 priority="14476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8"
                 priority="14474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.1"
                 priority="14472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.2"
                 priority="14471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.3"
                 priority="14470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.9"
                 priority="14468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.10"
                 priority="14466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71"
                 priority="14465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '113' zijn. (string(@Item)=('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'Race' zijn. (string(@LongName)=('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.1"
                 priority="14463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.2"
                 priority="14462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.3"
                 priority="14461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.4"
                 priority="14459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.5"
                 priority="14458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.6"
                 priority="14457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72"
                 priority="14455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('811') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Item MOET '811' zijn. (string(@Item)=('811') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70344') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @Table MOET 'HL70344' zijn. (string(@Table)=('HL70344') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('CMS Patient_s Relationship to Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van @LongName MOET 'CMS Patient_s Relationship to Insured' zijn. (string(@LongName)=('CMS Patient_s Relationship to Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.1"
                 priority="14453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.2"
                 priority="14452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.3"
                 priority="14451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.4"
                 priority="14449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.5"
                 priority="14448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.6"
                 priority="14447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3"
                 priority="14445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.1 is required [min 1x]. (count(hl7v2:IN3.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.1 komt te vaak voor [max 1x]. (count(hl7v2:IN3.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.2 komt te vaak voor [max 1x]. (count(hl7v2:IN3.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.4 komt te vaak voor [max 1x]. (count(hl7v2:IN3.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.5 komt te vaak voor [max 1x]. (count(hl7v2:IN3.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.6 komt te vaak voor [max 1x]. (count(hl7v2:IN3.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.7 komt te vaak voor [max 1x]. (count(hl7v2:IN3.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.9 komt te vaak voor [max 1x]. (count(hl7v2:IN3.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.10 komt te vaak voor [max 1x]. (count(hl7v2:IN3.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.11 komt te vaak voor [max 1x]. (count(hl7v2:IN3.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.12 komt te vaak voor [max 1x]. (count(hl7v2:IN3.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.13 komt te vaak voor [max 1x]. (count(hl7v2:IN3.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.15 komt te vaak voor [max 1x]. (count(hl7v2:IN3.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.17 komt te vaak voor [max 1x]. (count(hl7v2:IN3.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.18 komt te vaak voor [max 1x]. (count(hl7v2:IN3.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.21 komt te vaak voor [max 1x]. (count(hl7v2:IN3.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.22 komt te vaak voor [max 1x]. (count(hl7v2:IN3.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.23 komt te vaak voor [max 1x]. (count(hl7v2:IN3.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.1"
                 priority="14444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('502') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '502' zijn. (string(@Item)=('502') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - IN3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Set ID - IN3' zijn. (string(@LongName)=('Set ID - IN3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2"
                 priority="14443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('503') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '503' zijn. (string(@Item)=('503') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Number' zijn. (string(@LongName)=('Certification Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.1"
                 priority="14441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.2"
                 priority="14440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.3"
                 priority="14439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4"
                 priority="14437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.5"
                 priority="14431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6"
                 priority="14429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.7"
                 priority="14423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.8"
                 priority="14422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9"
                 priority="14421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10"
                 priority="14408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3"
                 priority="14395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('504') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '504' zijn. (string(@Item)=('504') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certified By' zijn. (string(@LongName)=('Certified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.1"
                 priority="14393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2"
                 priority="14392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="14390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="14389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="14388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="14387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="14386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.3"
                 priority="14385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.4"
                 priority="14384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.5"
                 priority="14383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.6"
                 priority="14382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.7"
                 priority="14381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.8"
                 priority="14380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9"
                 priority="14379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="14377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="14376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="14375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.10"
                 priority="14373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.11"
                 priority="14371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.12"
                 priority="14370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.13"
                 priority="14368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14"
                 priority="14366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="14364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="14363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="14362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.15"
                 priority="14360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16"
                 priority="14358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="14356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="14355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="14354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="14352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="14351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="14350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17"
                 priority="14348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="14346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="14341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.18"
                 priority="14336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19"
                 priority="14334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="14332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="14331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20"
                 priority="14329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="14327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="14326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.21"
                 priority="14324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22"
                 priority="14323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="14321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="14320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="14319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="14317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="14316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="14315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="14313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="14312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="14311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23"
                 priority="14310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="14308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="14307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="14306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="14304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="14303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="14302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="14300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="14299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="14298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.4"
                 priority="14297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('505') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '505' zijn. (string(@Item)=('505') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Required' zijn. (string(@LongName)=('Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5"
                 priority="14295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('506') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '506' zijn. (string(@Item)=('506') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'MOP' zijn. (string(@Type)=('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Penalty') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Penalty' zijn. (string(@LongName)=('Penalty') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.1"
                 priority="14293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Table MOET 'HL70148' zijn. (string(@Table)=('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Indicator' zijn. (string(@LongName)=('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.2"
                 priority="14291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Money or Percentage Quantity' zijn. (string(@LongName)=('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.3"
                 priority="14290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van @LongName MOET 'Currency Denomination' zijn. (string(@LongName)=('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6"
                 priority="14288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('507') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '507' zijn. (string(@Item)=('507') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Date/Time' zijn. (string(@LongName)=('Certification Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6/hl7v2:TS.1"
                 priority="14286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6/hl7v2:TS.2"
                 priority="14285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7"
                 priority="14283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('508') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '508' zijn. (string(@Item)=('508') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Modify Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Modify Date/Time' zijn. (string(@LongName)=('Certification Modify Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7/hl7v2:TS.1"
                 priority="14281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7/hl7v2:TS.2"
                 priority="14280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8"
                 priority="14278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('509') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '509' zijn. (string(@Item)=('509') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Operator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Operator' zijn. (string(@LongName)=('Operator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.1"
                 priority="14276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2"
                 priority="14275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="14273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="14272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="14271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="14270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="14269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.3"
                 priority="14268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.4"
                 priority="14267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.5"
                 priority="14266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.6"
                 priority="14265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.7"
                 priority="14264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.8"
                 priority="14263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9"
                 priority="14262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="14260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="14259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="14258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.10"
                 priority="14256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.11"
                 priority="14254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.12"
                 priority="14253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.13"
                 priority="14251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14"
                 priority="14249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="14247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="14246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="14245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.15"
                 priority="14243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16"
                 priority="14241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="14239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="14238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="14237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="14235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="14234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="14233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17"
                 priority="14231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="14229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="14224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.18"
                 priority="14219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19"
                 priority="14217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="14215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="14214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20"
                 priority="14212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="14210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="14209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.21"
                 priority="14207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22"
                 priority="14206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="14204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="14203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="14202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="14200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="14199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="14198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="14196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="14195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="14194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23"
                 priority="14193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="14191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="14190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="14189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="14187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="14186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="14185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="14183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="14182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="14181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.9"
                 priority="14180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('510') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '510' zijn. (string(@Item)=('510') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Begin Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Begin Date' zijn. (string(@LongName)=('Certification Begin Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.10"
                 priority="14179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('511') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '511' zijn. (string(@Item)=('511') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification End Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification End Date' zijn. (string(@LongName)=('Certification End Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11"
                 priority="14178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): element hl7v2:DTN.1 komt te vaak voor [max 1x]. (count(hl7v2:DTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): element hl7v2:DTN.2 komt te vaak voor [max 1x]. (count(hl7v2:DTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('512') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '512' zijn. (string(@Item)=('512') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'DTN' zijn. (string(@Type)=('DTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Days' zijn. (string(@LongName)=('Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11/hl7v2:DTN.1"
                 priority="14176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70149') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van @Table MOET 'HL70149' zijn. (string(@Table)=('HL70149') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Day Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van @LongName MOET 'Day Type' zijn. (string(@LongName)=('Day Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11/hl7v2:DTN.2"
                 priority="14175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van @LongName MOET 'Number of Days' zijn. (string(@LongName)=('Number of Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12"
                 priority="14174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('513') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '513' zijn. (string(@Item)=('513') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70233') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70233' zijn. (string(@Table)=('HL70233') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Non-Concur Code/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Non-Concur Code/Description' zijn. (string(@LongName)=('Non-Concur Code/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.1"
                 priority="14172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.2"
                 priority="14171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.3"
                 priority="14170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.4"
                 priority="14168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.5"
                 priority="14167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.6"
                 priority="14166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13"
                 priority="14164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('514') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '514' zijn. (string(@Item)=('514') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Non-Concur Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Non-Concur Effective Date/Time' zijn. (string(@LongName)=('Non-Concur Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13/hl7v2:TS.1"
                 priority="14162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13/hl7v2:TS.2"
                 priority="14161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14"
                 priority="14159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('515') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '515' zijn. (string(@Item)=('515') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Physician Reviewer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Physician Reviewer' zijn. (string(@LongName)=('Physician Reviewer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.1"
                 priority="14157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2"
                 priority="14156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="14154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="14153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="14152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="14151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="14150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.3"
                 priority="14149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.4"
                 priority="14148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.5"
                 priority="14147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.6"
                 priority="14146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.7"
                 priority="14145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.8"
                 priority="14144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9"
                 priority="14143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="14141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="14140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="14139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.10"
                 priority="14137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.11"
                 priority="14135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.12"
                 priority="14134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.13"
                 priority="14132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14"
                 priority="14130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="14128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="14127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="14126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.15"
                 priority="14124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16"
                 priority="14122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="14120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="14119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="14118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="14116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="14115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="14114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17"
                 priority="14112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="14110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="14105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.18"
                 priority="14100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19"
                 priority="14098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="14096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="14095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20"
                 priority="14093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="14091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="14090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.21"
                 priority="14088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22"
                 priority="14087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="14085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="14084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="14083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="14081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="14080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="14079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="14077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="14076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="14075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23"
                 priority="14074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="14072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="14071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="14070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="14068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="14067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="14066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="14064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="14063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="14062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.15"
                 priority="14061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('516') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '516' zijn. (string(@Item)=('516') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Contact') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Contact' zijn. (string(@LongName)=('Certification Contact') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16"
                 priority="14060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('517') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '517' zijn. (string(@Item)=('517') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Contact Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Contact Phone Number' zijn. (string(@LongName)=('Certification Contact Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.1"
                 priority="14058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.2"
                 priority="14057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.3"
                 priority="14055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.4"
                 priority="14053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.5"
                 priority="14052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.6"
                 priority="14051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.7"
                 priority="14050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.8"
                 priority="14049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.9"
                 priority="14048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.10"
                 priority="14047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.11"
                 priority="14046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.12"
                 priority="14045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17"
                 priority="14044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('518') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '518' zijn. (string(@Item)=('518') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70345') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70345' zijn. (string(@Table)=('HL70345') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Appeal Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Appeal Reason' zijn. (string(@LongName)=('Appeal Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.1"
                 priority="14042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.2"
                 priority="14041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.3"
                 priority="14040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.4"
                 priority="14038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.5"
                 priority="14037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.6"
                 priority="14036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18"
                 priority="14034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('519') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '519' zijn. (string(@Item)=('519') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70346') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70346' zijn. (string(@Table)=('HL70346') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Agency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Agency' zijn. (string(@LongName)=('Certification Agency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.1"
                 priority="14032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.2"
                 priority="14031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.3"
                 priority="14030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.4"
                 priority="14028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.5"
                 priority="14027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.6"
                 priority="14026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19"
                 priority="14024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('520') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '520' zijn. (string(@Item)=('520') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Agency Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Certification Agency Phone Number' zijn. (string(@LongName)=('Certification Agency Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.1"
                 priority="14022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.2"
                 priority="14021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.3"
                 priority="14019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.4"
                 priority="14017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.5"
                 priority="14016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.6"
                 priority="14015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.7"
                 priority="14014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.8"
                 priority="14013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.9"
                 priority="14012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.10"
                 priority="14011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.11"
                 priority="14010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.12"
                 priority="14009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20"
                 priority="14008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.1 komt te vaak voor [max 1x]. (count(hl7v2:ICD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.2 komt te vaak voor [max 1x]. (count(hl7v2:ICD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.3 komt te vaak voor [max 1x]. (count(hl7v2:ICD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('521') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '521' zijn. (string(@Item)=('521') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ICD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'ICD' zijn. (string(@Type)=('ICD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Certification Requirement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Pre-Certification Requirement' zijn. (string(@LongName)=('Pre-Certification Requirement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.1"
                 priority="14006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70150') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @Table MOET 'HL70150' zijn. (string(@Table)=('HL70150') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @LongName MOET 'Certification Patient Type' zijn. (string(@LongName)=('Certification Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.2"
                 priority="14005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @LongName MOET 'Certification Required' zijn. (string(@LongName)=('Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3"
                 priority="14003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van @LongName MOET 'Date/Time Certification Required' zijn. (string(@LongName)=('Date/Time Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3/hl7v2:TS.1"
                 priority="14001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3/hl7v2:TS.2"
                 priority="14000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.21"
                 priority="13998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('522') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '522' zijn. (string(@Item)=('522') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Case Manager') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Case Manager' zijn. (string(@LongName)=('Case Manager') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.22"
                 priority="13997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('523') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '523' zijn. (string(@Item)=('523') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second Opinion Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Second Opinion Date' zijn. (string(@LongName)=('Second Opinion Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.23"
                 priority="13996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('524') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '524' zijn. (string(@Item)=('524') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70151') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70151' zijn. (string(@Table)=('HL70151') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second Opinion Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Second Opinion Status' zijn. (string(@LongName)=('Second Opinion Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.24"
                 priority="13995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('525') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '525' zijn. (string(@Item)=('525') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70152') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70152' zijn. (string(@Table)=('HL70152') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second Opinion Documentation Received') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Second Opinion Documentation Received' zijn. (string(@LongName)=('Second Opinion Documentation Received') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25"
                 priority="13994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('526') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Item MOET '526' zijn. (string(@Item)=('526') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second Opinion Physician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van @LongName MOET 'Second Opinion Physician' zijn. (string(@LongName)=('Second Opinion Physician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.1"
                 priority="13992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2"
                 priority="13991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="13989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="13988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="13987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="13986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="13985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.3"
                 priority="13984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.4"
                 priority="13983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.5"
                 priority="13982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.6"
                 priority="13981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.7"
                 priority="13980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.8"
                 priority="13979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9"
                 priority="13978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="13976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="13975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="13974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.10"
                 priority="13972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.11"
                 priority="13970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.12"
                 priority="13969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.13"
                 priority="13967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14"
                 priority="13965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="13963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="13962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="13961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.15"
                 priority="13959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16"
                 priority="13957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="13955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="13954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="13953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="13951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="13950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="13949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17"
                 priority="13947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="13945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="13940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.18"
                 priority="13935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19"
                 priority="13933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="13931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="13930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20"
                 priority="13928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="13926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="13925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.21"
                 priority="13923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22"
                 priority="13922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="13920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="13919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="13918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="13916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="13915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="13914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="13912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="13911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="13910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23"
                 priority="13909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="13907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="13906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="13905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="13903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="13902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="13901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="13899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="13898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="13897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1"
                 priority="13896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.1 is required [min 1x]. (count(hl7v2:GT1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.1 komt te vaak voor [max 1x]. (count(hl7v2:GT1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.3 is required [min 1x]. (count(hl7v2:GT1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.8 komt te vaak voor [max 1x]. (count(hl7v2:GT1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.9 komt te vaak voor [max 1x]. (count(hl7v2:GT1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.10 komt te vaak voor [max 1x]. (count(hl7v2:GT1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.11 komt te vaak voor [max 1x]. (count(hl7v2:GT1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.12 komt te vaak voor [max 1x]. (count(hl7v2:GT1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.13 komt te vaak voor [max 1x]. (count(hl7v2:GT1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.14 komt te vaak voor [max 1x]. (count(hl7v2:GT1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.15 komt te vaak voor [max 1x]. (count(hl7v2:GT1.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.20 komt te vaak voor [max 1x]. (count(hl7v2:GT1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.22 komt te vaak voor [max 1x]. (count(hl7v2:GT1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.23 komt te vaak voor [max 1x]. (count(hl7v2:GT1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.24 komt te vaak voor [max 1x]. (count(hl7v2:GT1.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.25 komt te vaak voor [max 1x]. (count(hl7v2:GT1.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.26 komt te vaak voor [max 1x]. (count(hl7v2:GT1.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.27 komt te vaak voor [max 1x]. (count(hl7v2:GT1.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.28 komt te vaak voor [max 1x]. (count(hl7v2:GT1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.30 komt te vaak voor [max 1x]. (count(hl7v2:GT1.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.31 komt te vaak voor [max 1x]. (count(hl7v2:GT1.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.32 komt te vaak voor [max 1x]. (count(hl7v2:GT1.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.33 komt te vaak voor [max 1x]. (count(hl7v2:GT1.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.36 komt te vaak voor [max 1x]. (count(hl7v2:GT1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.37 komt te vaak voor [max 1x]. (count(hl7v2:GT1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.38 komt te vaak voor [max 1x]. (count(hl7v2:GT1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.39 komt te vaak voor [max 1x]. (count(hl7v2:GT1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.40 komt te vaak voor [max 1x]. (count(hl7v2:GT1.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.41 komt te vaak voor [max 1x]. (count(hl7v2:GT1.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.43 komt te vaak voor [max 1x]. (count(hl7v2:GT1.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.47 komt te vaak voor [max 1x]. (count(hl7v2:GT1.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.48 komt te vaak voor [max 1x]. (count(hl7v2:GT1.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.49 komt te vaak voor [max 1x]. (count(hl7v2:GT1.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.50)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.50 komt te vaak voor [max 1x]. (count(hl7v2:GT1.50)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.52)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.52 komt te vaak voor [max 1x]. (count(hl7v2:GT1.52)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.53)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.53 komt te vaak voor [max 1x]. (count(hl7v2:GT1.53)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.54)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.54 komt te vaak voor [max 1x]. (count(hl7v2:GT1.54)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.56)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.56 komt te vaak voor [max 1x]. (count(hl7v2:GT1.56)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.57)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.57 komt te vaak voor [max 1x]. (count(hl7v2:GT1.57)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.1"
                 priority="13895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('405') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '405' zijn. (string(@Item)=('405') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - GT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Set ID - GT1' zijn. (string(@LongName)=('Set ID - GT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2"
                 priority="13894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('406') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '406' zijn. (string(@Item)=('406') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Number' zijn. (string(@LongName)=('Guarantor Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.1"
                 priority="13892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.2"
                 priority="13891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.3"
                 priority="13890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4"
                 priority="13888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.5"
                 priority="13882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6"
                 priority="13880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.7"
                 priority="13874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.8"
                 priority="13873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9"
                 priority="13872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10"
                 priority="13859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3"
                 priority="13846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('407') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '407' zijn. (string(@Item)=('407') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Name' zijn. (string(@LongName)=('Guarantor Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1"
                 priority="13844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.2"
                 priority="13837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.3"
                 priority="13836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.4"
                 priority="13835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.5"
                 priority="13834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.6"
                 priority="13833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.7"
                 priority="13832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.8"
                 priority="13830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9"
                 priority="13828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10"
                 priority="13818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.11"
                 priority="13806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12"
                 priority="13804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13"
                 priority="13799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.14"
                 priority="13794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4"
                 priority="13793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('408') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '408' zijn. (string(@Item)=('408') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Spouse Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Spouse Name' zijn. (string(@LongName)=('Guarantor Spouse Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1"
                 priority="13791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.2"
                 priority="13784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.3"
                 priority="13783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.4"
                 priority="13782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.5"
                 priority="13781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.6"
                 priority="13780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.7"
                 priority="13779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.8"
                 priority="13777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9"
                 priority="13775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10"
                 priority="13765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.11"
                 priority="13753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12"
                 priority="13751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13"
                 priority="13746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.14"
                 priority="13741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5"
                 priority="13740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('409') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '409' zijn. (string(@Item)=('409') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Address' zijn. (string(@LongName)=('Guarantor Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1"
                 priority="13738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="13736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="13735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="13734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.2"
                 priority="13733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.3"
                 priority="13732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.4"
                 priority="13731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.5"
                 priority="13730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.6"
                 priority="13729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.7"
                 priority="13727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.8"
                 priority="13725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.9"
                 priority="13724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.10"
                 priority="13723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.11"
                 priority="13722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12"
                 priority="13720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="13718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="13713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13"
                 priority="13708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="13706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="13705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14"
                 priority="13703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="13701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="13700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6"
                 priority="13698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('410') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '410' zijn. (string(@Item)=('410') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Ph Num - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Ph Num - Home' zijn. (string(@LongName)=('Guarantor Ph Num - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.1"
                 priority="13696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.2"
                 priority="13695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.3"
                 priority="13693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.4"
                 priority="13691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.5"
                 priority="13690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.6"
                 priority="13689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.7"
                 priority="13688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.8"
                 priority="13687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.9"
                 priority="13686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.10"
                 priority="13685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.11"
                 priority="13684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.12"
                 priority="13683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7"
                 priority="13682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('411') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '411' zijn. (string(@Item)=('411') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Ph Num - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Ph Num - Business' zijn. (string(@LongName)=('Guarantor Ph Num - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.1"
                 priority="13680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.2"
                 priority="13679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.3"
                 priority="13677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.4"
                 priority="13675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.5"
                 priority="13674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.6"
                 priority="13673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.7"
                 priority="13672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.8"
                 priority="13671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.9"
                 priority="13670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.10"
                 priority="13669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.11"
                 priority="13668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.12"
                 priority="13667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8"
                 priority="13666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('412') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '412' zijn. (string(@Item)=('412') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Date/Time Of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Date/Time Of Birth' zijn. (string(@LongName)=('Guarantor Date/Time Of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8/hl7v2:TS.1"
                 priority="13664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8/hl7v2:TS.2"
                 priority="13663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.9"
                 priority="13661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '413' zijn. (string(@Item)=('413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Administrative Sex' zijn. (string(@LongName)=('Guarantor Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.10"
                 priority="13660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('414') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '414' zijn. (string(@Item)=('414') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70068') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70068' zijn. (string(@Table)=('HL70068') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Type' zijn. (string(@LongName)=('Guarantor Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11"
                 priority="13659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('415') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '415' zijn. (string(@Item)=('415') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70063' zijn. (string(@Table)=('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Relationship' zijn. (string(@LongName)=('Guarantor Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.1"
                 priority="13657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.2"
                 priority="13656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.3"
                 priority="13655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.4"
                 priority="13653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.5"
                 priority="13652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.6"
                 priority="13651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.12"
                 priority="13649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '416' zijn. (string(@Item)=('416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor SSN') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor SSN' zijn. (string(@LongName)=('Guarantor SSN') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.13"
                 priority="13648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('417') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '417' zijn. (string(@Item)=('417') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Date - Begin') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Date - Begin' zijn. (string(@LongName)=('Guarantor Date - Begin') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.14"
                 priority="13647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('418') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '418' zijn. (string(@Item)=('418') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Date - End') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Date - End' zijn. (string(@LongName)=('Guarantor Date - End') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.15"
                 priority="13646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('419') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '419' zijn. (string(@Item)=('419') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Priority' zijn. (string(@LongName)=('Guarantor Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16"
                 priority="13645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '420' zijn. (string(@Item)=('420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employer Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employer Name' zijn. (string(@LongName)=('Guarantor Employer Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1"
                 priority="13643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.2"
                 priority="13636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.3"
                 priority="13635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.4"
                 priority="13634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.5"
                 priority="13633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.6"
                 priority="13632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.7"
                 priority="13631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.8"
                 priority="13629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9"
                 priority="13627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10"
                 priority="13617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.11"
                 priority="13605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12"
                 priority="13603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13"
                 priority="13598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.14"
                 priority="13593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17"
                 priority="13592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '421' zijn. (string(@Item)=('421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employer Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employer Address' zijn. (string(@LongName)=('Guarantor Employer Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1"
                 priority="13590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="13588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="13587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="13586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.2"
                 priority="13585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.3"
                 priority="13584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.4"
                 priority="13583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.5"
                 priority="13582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.6"
                 priority="13581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.7"
                 priority="13579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.8"
                 priority="13577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.9"
                 priority="13576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.10"
                 priority="13575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.11"
                 priority="13574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12"
                 priority="13572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="13570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="13565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13"
                 priority="13560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="13558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="13557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14"
                 priority="13555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="13553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="13552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18"
                 priority="13550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '422' zijn. (string(@Item)=('422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employer Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employer Phone Number' zijn. (string(@LongName)=('Guarantor Employer Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.1"
                 priority="13548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.2"
                 priority="13547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.3"
                 priority="13545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.4"
                 priority="13543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.5"
                 priority="13542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.6"
                 priority="13541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.7"
                 priority="13540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.8"
                 priority="13539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.9"
                 priority="13538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.10"
                 priority="13537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.11"
                 priority="13536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.12"
                 priority="13535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19"
                 priority="13534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('423') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '423' zijn. (string(@Item)=('423') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employee ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employee ID Number' zijn. (string(@LongName)=('Guarantor Employee ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.1"
                 priority="13532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.2"
                 priority="13531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.3"
                 priority="13530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4"
                 priority="13528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.5"
                 priority="13522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6"
                 priority="13520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.7"
                 priority="13514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.8"
                 priority="13513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9"
                 priority="13512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10"
                 priority="13499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.20"
                 priority="13486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '424' zijn. (string(@Item)=('424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70066') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70066' zijn. (string(@Table)=('HL70066') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employment Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employment Status' zijn. (string(@LongName)=('Guarantor Employment Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21"
                 priority="13485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '425' zijn. (string(@Item)=('425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Organization Name' zijn. (string(@LongName)=('Guarantor Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.1"
                 priority="13483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.2"
                 priority="13482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.3"
                 priority="13481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.4"
                 priority="13480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.5"
                 priority="13479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6"
                 priority="13477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="13475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="13474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="13473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.7"
                 priority="13471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8"
                 priority="13469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="13467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="13466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="13465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.9"
                 priority="13463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.10"
                 priority="13461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.22"
                 priority="13460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('773') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '773' zijn. (string(@Item)=('773') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Billing Hold Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Billing Hold Flag' zijn. (string(@LongName)=('Guarantor Billing Hold Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23"
                 priority="13458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('774') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '774' zijn. (string(@Item)=('774') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70341') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70341' zijn. (string(@Table)=('HL70341') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Credit Rating Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Credit Rating Code' zijn. (string(@LongName)=('Guarantor Credit Rating Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.1"
                 priority="13456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.2"
                 priority="13455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.3"
                 priority="13454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.4"
                 priority="13452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.5"
                 priority="13451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.6"
                 priority="13450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24"
                 priority="13448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('775') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '775' zijn. (string(@Item)=('775') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Death Date And Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Death Date And Time' zijn. (string(@LongName)=('Guarantor Death Date And Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24/hl7v2:TS.1"
                 priority="13446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24/hl7v2:TS.2"
                 priority="13445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.25"
                 priority="13443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('776') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '776' zijn. (string(@Item)=('776') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Death Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Death Flag' zijn. (string(@LongName)=('Guarantor Death Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26"
                 priority="13441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('777') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '777' zijn. (string(@Item)=('777') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70218' zijn. (string(@Table)=('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Charge Adjustment Code' zijn. (string(@LongName)=('Guarantor Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.1"
                 priority="13439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.2"
                 priority="13438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.3"
                 priority="13437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.4"
                 priority="13435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.5"
                 priority="13434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.6"
                 priority="13433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27"
                 priority="13431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('778') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '778' zijn. (string(@Item)=('778') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Household Annual Income') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Household Annual Income' zijn. (string(@LongName)=('Guarantor Household Annual Income') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1"
                 priority="13429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1/hl7v2:MO.1"
                 priority="13427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1/hl7v2:MO.2"
                 priority="13426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.2"
                 priority="13424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.3"
                 priority="13422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.4"
                 priority="13421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5"
                 priority="13420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.1"
                 priority="13418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.2"
                 priority="13417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.3"
                 priority="13416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.4"
                 priority="13414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.5"
                 priority="13413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.6"
                 priority="13412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.6"
                 priority="13410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.28"
                 priority="13408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('779') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '779' zijn. (string(@Item)=('779') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Household Size') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Household Size' zijn. (string(@LongName)=('Guarantor Household Size') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29"
                 priority="13407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('780') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '780' zijn. (string(@Item)=('780') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employer ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employer ID Number' zijn. (string(@LongName)=('Guarantor Employer ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.1"
                 priority="13405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.2"
                 priority="13404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.3"
                 priority="13403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4"
                 priority="13401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.5"
                 priority="13395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6"
                 priority="13393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.7"
                 priority="13387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.8"
                 priority="13386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9"
                 priority="13385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10"
                 priority="13372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30"
                 priority="13359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('781') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '781' zijn. (string(@Item)=('781') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Marital Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Marital Status Code' zijn. (string(@LongName)=('Guarantor Marital Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.1"
                 priority="13357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.2"
                 priority="13356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.3"
                 priority="13355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.4"
                 priority="13353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.5"
                 priority="13352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.6"
                 priority="13351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.31"
                 priority="13349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('782') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '782' zijn. (string(@Item)=('782') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Hire Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Hire Effective Date' zijn. (string(@LongName)=('Guarantor Hire Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.32"
                 priority="13348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('783') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '783' zijn. (string(@Item)=('783') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Employment Stop Date' zijn. (string(@LongName)=('Employment Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.33"
                 priority="13347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.34"
                 priority="13346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35"
                 priority="13345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.1"
                 priority="13343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.2"
                 priority="13342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.3"
                 priority="13341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.4"
                 priority="13339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.5"
                 priority="13338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.6"
                 priority="13337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36"
                 priority="13335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.1"
                 priority="13333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.2"
                 priority="13332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.3"
                 priority="13331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.4"
                 priority="13329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.5"
                 priority="13328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.6"
                 priority="13327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.37"
                 priority="13325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38"
                 priority="13324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.1"
                 priority="13322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.2"
                 priority="13321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.3"
                 priority="13320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.4"
                 priority="13318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.5"
                 priority="13317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.6"
                 priority="13316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.39"
                 priority="13314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.40"
                 priority="13312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41"
                 priority="13311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.1"
                 priority="13309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.2"
                 priority="13308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.3"
                 priority="13307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.4"
                 priority="13305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.5"
                 priority="13304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.6"
                 priority="13303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42"
                 priority="13301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1"
                 priority="13299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.2"
                 priority="13292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.3"
                 priority="13291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.4"
                 priority="13290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.5"
                 priority="13289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.6"
                 priority="13288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.7"
                 priority="13287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.8"
                 priority="13285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9"
                 priority="13283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10"
                 priority="13273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.11"
                 priority="13261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12"
                 priority="13259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13"
                 priority="13254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.14"
                 priority="13249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43"
                 priority="13248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.1"
                 priority="13246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.2"
                 priority="13245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.3"
                 priority="13244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.4"
                 priority="13242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.5"
                 priority="13241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.6"
                 priority="13240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44"
                 priority="13238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.1"
                 priority="13236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.2"
                 priority="13235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.3"
                 priority="13234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.4"
                 priority="13232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.5"
                 priority="13231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.6"
                 priority="13230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45"
                 priority="13228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('748') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '748' zijn. (string(@Item)=('748') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Contact Person''s Name' zijn. (string(@LongName)=('Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1"
                 priority="13226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.2"
                 priority="13219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.3"
                 priority="13218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.4"
                 priority="13217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.5"
                 priority="13216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.6"
                 priority="13215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.7"
                 priority="13214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.8"
                 priority="13212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9"
                 priority="13210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10"
                 priority="13200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.11"
                 priority="13188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12"
                 priority="13186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13"
                 priority="13181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.14"
                 priority="13176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46"
                 priority="13175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('749') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '749' zijn. (string(@Item)=('749') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Person''s Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Contact Person''s Telephone Number' zijn. (string(@LongName)=('Contact Person''s Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.1"
                 priority="13173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.2"
                 priority="13172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.3"
                 priority="13170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.4"
                 priority="13168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.5"
                 priority="13167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.6"
                 priority="13166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.7"
                 priority="13165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.8"
                 priority="13164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.9"
                 priority="13163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.10"
                 priority="13162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.11"
                 priority="13161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.12"
                 priority="13160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47"
                 priority="13159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('747') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '747' zijn. (string(@Item)=('747') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70222' zijn. (string(@Table)=('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Contact Reason' zijn. (string(@LongName)=('Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.1"
                 priority="13157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.2"
                 priority="13156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.3"
                 priority="13155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.4"
                 priority="13153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.5"
                 priority="13152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.6"
                 priority="13151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.48"
                 priority="13149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('784') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '784' zijn. (string(@Item)=('784') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70063' zijn. (string(@Table)=('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Contact Relationship' zijn. (string(@LongName)=('Contact Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.49"
                 priority="13148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('785') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '785' zijn. (string(@Item)=('785') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Job Title' zijn. (string(@LongName)=('Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50"
                 priority="13147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('786') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '786' zijn. (string(@Item)=('786') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'JCC' zijn. (string(@Type)=('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Job Code/Class' zijn. (string(@LongName)=('Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.1"
                 priority="13145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70327' zijn. (string(@Table)=('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Code' zijn. (string(@LongName)=('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.2"
                 priority="13144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Table MOET 'HL70328' zijn. (string(@Table)=('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Class' zijn. (string(@LongName)=('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3"
                 priority="13143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van @LongName MOET 'Job Description Text' zijn. (string(@LongName)=('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape"
                 priority="13142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="13141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="13140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51"
                 priority="13139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1299') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '1299' zijn. (string(@Item)=('1299') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Employer''s Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Employer''s Organization Name' zijn. (string(@LongName)=('Guarantor Employer''s Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.1"
                 priority="13137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.2"
                 priority="13136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.3"
                 priority="13135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.4"
                 priority="13134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.5"
                 priority="13133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6"
                 priority="13131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.1"
                 priority="13129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.2"
                 priority="13128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.3"
                 priority="13127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.7"
                 priority="13125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8"
                 priority="13123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.1"
                 priority="13121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.2"
                 priority="13120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.3"
                 priority="13119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.9"
                 priority="13117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.10"
                 priority="13115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.52"
                 priority="13114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.53"
                 priority="13113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '752' zijn. (string(@Item)=('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70311' zijn. (string(@Table)=('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Job Status' zijn. (string(@LongName)=('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54"
                 priority="13112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '1231' zijn. (string(@Item)=('1231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'FC' zijn. (string(@Type)=('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Financial Class' zijn. (string(@LongName)=('Guarantor Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.1"
                 priority="13110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Financial Class Code' zijn. (string(@LongName)=('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2"
                 priority="13109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2/hl7v2:TS.1"
                 priority="13107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2/hl7v2:TS.2"
                 priority="13106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55"
                 priority="13104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1291') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '1291' zijn. (string(@Item)=('1291') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Race' zijn. (string(@LongName)=('Guarantor Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.1"
                 priority="13102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.2"
                 priority="13101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.3"
                 priority="13100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.4"
                 priority="13098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.5"
                 priority="13097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.6"
                 priority="13096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.56"
                 priority="13094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1851') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '1851' zijn. (string(@Item)=('1851') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Guarantor Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'Guarantor Birth Place' zijn. (string(@LongName)=('Guarantor Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.57"
                 priority="13093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Item MOET '146' zijn. (string(@Item)=('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1"
                 priority="13092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.1 is required [min 1x]. (count(hl7v2:AL1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.1 komt te vaak voor [max 1x]. (count(hl7v2:AL1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.2 komt te vaak voor [max 1x]. (count(hl7v2:AL1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.3 is required [min 1x]. (count(hl7v2:AL1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.3 komt te vaak voor [max 1x]. (count(hl7v2:AL1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.4 komt te vaak voor [max 1x]. (count(hl7v2:AL1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.1"
                 priority="13091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('203') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Item MOET '203' zijn. (string(@Item)=('203') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - AL1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @LongName MOET 'Set ID - AL1' zijn. (string(@LongName)=('Set ID - AL1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2"
                 priority="13090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('204') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Item MOET '204' zijn. (string(@Item)=('204') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70127') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Table MOET 'HL70127' zijn. (string(@Table)=('HL70127') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergen Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @LongName MOET 'Allergen Type Code' zijn. (string(@LongName)=('Allergen Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.1"
                 priority="13088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.2"
                 priority="13087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.3"
                 priority="13086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.4"
                 priority="13084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.5"
                 priority="13083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.6"
                 priority="13082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3"
                 priority="13080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('205') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Item MOET '205' zijn. (string(@Item)=('205') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergen Code/Mnemonic/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @LongName MOET 'Allergen Code/Mnemonic/Description' zijn. (string(@LongName)=('Allergen Code/Mnemonic/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.1"
                 priority="13078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.2"
                 priority="13077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.3"
                 priority="13076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.4"
                 priority="13074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.5"
                 priority="13073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.6"
                 priority="13072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4"
                 priority="13070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('206') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Item MOET '206' zijn. (string(@Item)=('206') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70128') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @Table MOET 'HL70128' zijn. (string(@Table)=('HL70128') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergy Severity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van @LongName MOET 'Allergy Severity Code' zijn. (string(@LongName)=('Allergy Severity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.1"
                 priority="13068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.2"
                 priority="13067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.3"
                 priority="13066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.4"
                 priority="13064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.5"
                 priority="13063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.6"
                 priority="13062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e58-false-d142379e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER"
                 priority="13060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC is required [min 1x]. (count(hl7v2:ORC)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x]. (count(hl7v2:ORC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION_REQUEST)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION_REQUEST komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION_REQUEST)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:BLG komt te vaak voor [max 1x]. (count(hl7v2:BLG)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC"
                 priority="13059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.1 is required [min 1x]. (count(hl7v2:ORC.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.1 komt te vaak voor [max 1x]. (count(hl7v2:ORC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.2 komt te vaak voor [max 1x]. (count(hl7v2:ORC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.3 komt te vaak voor [max 1x]. (count(hl7v2:ORC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.4 komt te vaak voor [max 1x]. (count(hl7v2:ORC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.5 komt te vaak voor [max 1x]. (count(hl7v2:ORC.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.6 komt te vaak voor [max 1x]. (count(hl7v2:ORC.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.8 komt te vaak voor [max 1x]. (count(hl7v2:ORC.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.9 komt te vaak voor [max 1x]. (count(hl7v2:ORC.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.13 komt te vaak voor [max 1x]. (count(hl7v2:ORC.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.15 komt te vaak voor [max 1x]. (count(hl7v2:ORC.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.16 komt te vaak voor [max 1x]. (count(hl7v2:ORC.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.17 komt te vaak voor [max 1x]. (count(hl7v2:ORC.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.18 komt te vaak voor [max 1x]. (count(hl7v2:ORC.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.20 komt te vaak voor [max 1x]. (count(hl7v2:ORC.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.25 komt te vaak voor [max 1x]. (count(hl7v2:ORC.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.26 komt te vaak voor [max 1x]. (count(hl7v2:ORC.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.27 komt te vaak voor [max 1x]. (count(hl7v2:ORC.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.28 komt te vaak voor [max 1x]. (count(hl7v2:ORC.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.29 komt te vaak voor [max 1x]. (count(hl7v2:ORC.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): element hl7v2:ORC.30 komt te vaak voor [max 1x]. (count(hl7v2:ORC.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="13058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('215') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '215' zijn. (string(@Item)=('215') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70119' zijn. (string(@Table)=('HL70119') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Control' zijn. (string(@LongName)=('Order Control') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="13056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="13054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="13053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="13052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="13051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="13049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="13047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="13046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="13045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="13044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="13042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('218') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '218' zijn. (string(@Item)=('218') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Group Number' zijn. (string(@LongName)=('Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="13040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="13039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="13038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="13037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="13035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('219') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '219' zijn. (string(@Item)=('219') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70038' zijn. (string(@Table)=('HL70038') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Status' zijn. (string(@LongName)=('Order Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="13033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('220') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '220' zijn. (string(@Item)=('220') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70121' zijn. (string(@Table)=('HL70121') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Response Flag' zijn. (string(@LongName)=('Response Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="13031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="13029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="13027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="13026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="13024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="13023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="13022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="13020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="13019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="13018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="13016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="13014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="13013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="13012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="13011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="13009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="13008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="13006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="13004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="13003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="13001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="13000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="12999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="12998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="12997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="12996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="12995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="12993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="12991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="12989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="12988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="12987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="12986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="12985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="12984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="12983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="12982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="12980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="12979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="12977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="12975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="12974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="12973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="12971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="12970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="12969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="12967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="12966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('222') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '222' zijn. (string(@Item)=('222') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="12964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="12962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="12961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="12960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="12959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="12957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="12955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="12954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="12953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="12952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="12950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('223') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '223' zijn. (string(@Item)=('223') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Date/Time of Transaction' zijn. (string(@LongName)=('Date/Time of Transaction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="12948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="12947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="12945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('224') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '224' zijn. (string(@Item)=('224') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Entered By' zijn. (string(@LongName)=('Entered By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="12943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="12942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="12935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="12934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="12933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="12932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="12931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="12930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="12929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="12923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="12921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="12920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="12918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="12916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="12910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="12908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="12898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="12886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="12884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="12879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="12874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="12873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="12860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="12847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('225') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '225' zijn. (string(@Item)=('225') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Verified By' zijn. (string(@LongName)=('Verified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="12845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="12844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="12837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="12836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="12835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="12834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="12833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="12832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="12831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="12825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="12823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="12822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="12820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="12818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="12812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="12810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="12800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="12788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="12786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="12781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="12776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="12775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="12762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="12749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="12747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="12746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="12739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="12738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="12737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="12736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="12735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="12734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="12733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="12727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="12725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="12724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="12722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="12720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="12714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="12712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="12702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="12690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="12688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="12683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="12678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="12677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="12664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="12651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '227' zijn. (string(@Item)=('227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Enterer''s Location' zijn. (string(@LongName)=('Enterer''s Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="12649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="12648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="12647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="12646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="12644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="12643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="12642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="12640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="12639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="12638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="12637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="12636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="12635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="12633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="12632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="12631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="12630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="12628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="12626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="12625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="12624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="12622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('228') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '228' zijn. (string(@Item)=('228') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Call Back Phone Number' zijn. (string(@LongName)=('Call Back Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="12620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="12619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="12617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="12615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="12614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="12613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="12612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="12611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="12610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="12609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="12608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="12607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="12606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('229') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '229' zijn. (string(@Item)=('229') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Effective Date/Time' zijn. (string(@LongName)=('Order Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="12604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="12603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="12601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '230' zijn. (string(@Item)=('230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Control Code Reason' zijn. (string(@LongName)=('Order Control Code Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="12599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="12598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="12597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="12595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="12594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="12593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="12591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '231' zijn. (string(@Item)=('231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Entering Organization' zijn. (string(@LongName)=('Entering Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="12589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="12588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="12587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="12585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="12584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="12583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="12581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('232') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '232' zijn. (string(@Item)=('232') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Entering Device' zijn. (string(@LongName)=('Entering Device') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="12579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="12578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="12577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="12575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="12574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="12573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="12571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('233') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '233' zijn. (string(@Item)=('233') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Action By' zijn. (string(@LongName)=('Action By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="12569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="12568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="12561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="12560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="12559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="12558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="12557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="12556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="12555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="12549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="12547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="12546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="12544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="12542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="12536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="12534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="12524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="12512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="12510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="12505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="12500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="12499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="12486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="12473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1310' zijn. (string(@Item)=('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70339' zijn. (string(@Table)=('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Advanced Beneficiary Notice Code' zijn. (string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="12471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="12470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="12469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="12467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="12466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="12465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="12463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1311') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1311' zijn. (string(@Item)=('1311') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Facility Name' zijn. (string(@LongName)=('Ordering Facility Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="12461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="12460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="12459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="12458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="12457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="12455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="12453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="12452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="12451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="12449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="12447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="12445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="12444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="12443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="12441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="12439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="12438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1312') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1312' zijn. (string(@Item)=('1312') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Facility Address' zijn. (string(@LongName)=('Ordering Facility Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="12436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="12434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="12433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="12432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="12431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="12430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="12429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="12428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="12427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="12425"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="12423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="12422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="12421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="12420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="12418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="12416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="12411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="12406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="12404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="12403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="12401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="12399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="12398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="12396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1313') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1313' zijn. (string(@Item)=('1313') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Facility Phone Number' zijn. (string(@LongName)=('Ordering Facility Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="12394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="12393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="12391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="12389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="12388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="12387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="12386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="12385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="12384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="12383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="12382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="12381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="12380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1314') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1314' zijn. (string(@Item)=('1314') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Provider Address' zijn. (string(@LongName)=('Ordering Provider Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="12378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="12376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="12375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="12374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="12373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="12372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="12371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="12370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="12369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="12367"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="12365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="12364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="12363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="12362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="12360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="12358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="12353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="12348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="12346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="12345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="12343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="12341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="12340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="12338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1473' zijn. (string(@Item)=('1473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Status Modifier' zijn. (string(@LongName)=('Order Status Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="12336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="12335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="12334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="12332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="12331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="12330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="12328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="12327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="12326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="12325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1641') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1641' zijn. (string(@Item)=('1641') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70552' zijn. (string(@Table)=('HL70552') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. (string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="12323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="12322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="12321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="12319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="12318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="12317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="12315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="12314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="12313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="12312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1642') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1642' zijn. (string(@Item)=('1642') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler''s Expected Availability Date/Time' zijn. (string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="12310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="12309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="12307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('615') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '615' zijn. (string(@Item)=('615') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70177' zijn. (string(@Table)=('HL70177') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Confidentiality Code' zijn. (string(@LongName)=('Confidentiality Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="12305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="12304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="12303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="12301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="12300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="12299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="12297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="12296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="12295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="12294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1643') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1643' zijn. (string(@Item)=('1643') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70482' zijn. (string(@Table)=('HL70482') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Type' zijn. (string(@LongName)=('Order Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="12292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="12291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="12290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="12288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="12287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="12286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="12284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="12283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="12282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="12281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1644' zijn. (string(@Item)=('1644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CNE' zijn. (string(@Type)=('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70483' zijn. (string(@Table)=('HL70483') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Enterer Authorization Mode' zijn. (string(@LongName)=('Enterer Authorization Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="12279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="12278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="12277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="12275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="12274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="12273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="12271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="12270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="12269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e62-false-d161449e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR"
                 priority="12268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 is required [min 1x]. (count(hl7v2:TQ1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1"
                 priority="12267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="12266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1627') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1627' zijn. (string(@Item)=('1627') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - TQ1' zijn. (string(@LongName)=('Set ID - TQ1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="12265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1628') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1628' zijn. (string(@Item)=('1628') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="12263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="12262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="12252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x]. (count(hl7v2:RPT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x]. (count(hl7v2:RPT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x]. (count(hl7v2:RPT.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x]. (count(hl7v2:RPT.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x]. (count(hl7v2:RPT.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x]. (count(hl7v2:RPT.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x]. (count(hl7v2:RPT.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x]. (count(hl7v2:RPT.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x]. (count(hl7v2:RPT.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x]. (count(hl7v2:RPT.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x]. (count(hl7v2:RPT.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1629') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1629' zijn. (string(@Item)=('1629') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'RPT' zijn. (string(@Type)=('RPT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="12250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Repeat Pattern Code' zijn. (string(@LongName)=('Repeat Pattern Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="12248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="12247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="12246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="12244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="12243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="12242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="12240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="12239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="12238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="12237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70527' zijn. (string(@Table)=('HL70527') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Calendar Alignment' zijn. (string(@LongName)=('Calendar Alignment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="12235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range Begin Value' zijn. (string(@LongName)=('Phase Range Begin Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="12234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range End Value' zijn. (string(@LongName)=('Phase Range End Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="12233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Quantity' zijn. (string(@LongName)=('Period Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="12232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Units' zijn. (string(@LongName)=('Period Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="12231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Institution Specified Time' zijn. (string(@LongName)=('Institution Specified Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="12229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70528' zijn. (string(@Table)=('HL70528') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event' zijn. (string(@LongName)=('Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="12227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Quantity' zijn. (string(@LongName)=('Event Offset Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="12226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Units' zijn. (string(@LongName)=('Event Offset Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="12225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'GTS' zijn. (string(@Type)=('GTS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'General Timing Specification' zijn. (string(@LongName)=('General Timing Specification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="12224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1630') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1630' zijn. (string(@Item)=('1630') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TM' zijn. (string(@Type)=('TM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Explicit Time' zijn. (string(@LongName)=('Explicit Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="12223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1631') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1631' zijn. (string(@Item)=('1631') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relative Time and Units' zijn. (string(@LongName)=('Relative Time and Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="12221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="12220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="12210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1632') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1632' zijn. (string(@Item)=('1632') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Service Duration' zijn. (string(@LongName)=('Service Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="12208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="12207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="12197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1633') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1633' zijn. (string(@Item)=('1633') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Start date/time' zijn. (string(@LongName)=('Start date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="12195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="12194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="12192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1634') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1634' zijn. (string(@Item)=('1634') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'End date/time' zijn. (string(@LongName)=('End date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="12190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="12189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="12187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1635') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1635' zijn. (string(@Item)=('1635') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70485' zijn. (string(@Table)=('HL70485') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="12185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="12184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="12183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="12181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="12180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="12179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="12177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="12176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="12175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="12174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1636') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1636' zijn. (string(@Item)=('1636') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Condition text' zijn. (string(@LongName)=('Condition text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="12173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="12172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="12171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="12170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1637') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1637' zijn. (string(@Item)=('1637') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Text instruction' zijn. (string(@LongName)=('Text instruction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="12169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="12168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="12167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="12166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1638') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1638' zijn. (string(@Item)=('1638') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70427' zijn. (string(@Table)=('HL70427') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="12164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1639') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1639' zijn. (string(@Item)=('1639') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Occurrence duration' zijn. (string(@LongName)=('Occurrence duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="12162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="12161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="12151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1640') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1640' zijn. (string(@Item)=('1640') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Total occurrence''s' zijn. (string(@LongName)=('Total occurrence''s') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2"
                 priority="12150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="12149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1648') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1648' zijn. (string(@Item)=('1648') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Set ID - TQ2' zijn. (string(@LongName)=('Set ID - TQ2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="12148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1649') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1649' zijn. (string(@Item)=('1649') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70503' zijn. (string(@Table)=('HL70503') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="12146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1650') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1650' zijn. (string(@Item)=('1650') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Number' zijn. (string(@LongName)=('Related Placer Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="12144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="12143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="12142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="12141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="12139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1651') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1651' zijn. (string(@Item)=('1651') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Filler Number' zijn. (string(@LongName)=('Related Filler Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="12137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="12136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="12135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="12134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="12132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1652') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1652' zijn. (string(@Item)=('1652') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Group Number' zijn. (string(@LongName)=('Related Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="12130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="12129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="12128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="12127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="12125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1653') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1653' zijn. (string(@Item)=('1653') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70504' zijn. (string(@Table)=('HL70504') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Code' zijn. (string(@LongName)=('Sequence Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="12123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1654') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1654' zijn. (string(@Item)=('1654') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70505' zijn. (string(@Table)=('HL70505') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Entry/Exit Indicator' zijn. (string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="12121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1655') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1655' zijn. (string(@Item)=('1655') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Time Interval' zijn. (string(@LongName)=('Sequence Condition Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="12119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="12118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="12108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1656') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1656' zijn. (string(@Item)=('1656') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. (string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="12107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1657') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1657' zijn. (string(@Item)=('1657') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70506' zijn. (string(@Table)=('HL70506') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Special Service Request Relationship' zijn. (string(@LongName)=('Special Service Request Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e69-false-d165385e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST"
                 priority="12105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR is required [min 1x]. (count(hl7v2:OBR)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x]. (count(hl7v2:OBR)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TCD komt te vaak voor [max 1x]. (count(hl7v2:TCD)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:CTD komt te vaak voor [max 1x]. (count(hl7v2:CTD)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION is required [min 1x]. (count(hl7v2:OML_O21.OBSERVATION)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR"
                 priority="12104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.1 komt te vaak voor [max 1x]. (count(hl7v2:OBR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.2 komt te vaak voor [max 1x]. (count(hl7v2:OBR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.3 komt te vaak voor [max 1x]. (count(hl7v2:OBR.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 is required [min 1x]. (count(hl7v2:OBR.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 komt te vaak voor [max 1x]. (count(hl7v2:OBR.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.5 komt te vaak voor [max 1x]. (count(hl7v2:OBR.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.6 komt te vaak voor [max 1x]. (count(hl7v2:OBR.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.7 komt te vaak voor [max 1x]. (count(hl7v2:OBR.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.8 komt te vaak voor [max 1x]. (count(hl7v2:OBR.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.9 komt te vaak voor [max 1x]. (count(hl7v2:OBR.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.11 komt te vaak voor [max 1x]. (count(hl7v2:OBR.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.12 komt te vaak voor [max 1x]. (count(hl7v2:OBR.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.13 komt te vaak voor [max 1x]. (count(hl7v2:OBR.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.14 komt te vaak voor [max 1x]. (count(hl7v2:OBR.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.15 komt te vaak voor [max 1x]. (count(hl7v2:OBR.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.18 komt te vaak voor [max 1x]. (count(hl7v2:OBR.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.19 komt te vaak voor [max 1x]. (count(hl7v2:OBR.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.20 komt te vaak voor [max 1x]. (count(hl7v2:OBR.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.21 komt te vaak voor [max 1x]. (count(hl7v2:OBR.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.22 komt te vaak voor [max 1x]. (count(hl7v2:OBR.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.23 komt te vaak voor [max 1x]. (count(hl7v2:OBR.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.24 komt te vaak voor [max 1x]. (count(hl7v2:OBR.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.25 komt te vaak voor [max 1x]. (count(hl7v2:OBR.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.26 komt te vaak voor [max 1x]. (count(hl7v2:OBR.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.29 komt te vaak voor [max 1x]. (count(hl7v2:OBR.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.30 komt te vaak voor [max 1x]. (count(hl7v2:OBR.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.32 komt te vaak voor [max 1x]. (count(hl7v2:OBR.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.36 komt te vaak voor [max 1x]. (count(hl7v2:OBR.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.37 komt te vaak voor [max 1x]. (count(hl7v2:OBR.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.40 komt te vaak voor [max 1x]. (count(hl7v2:OBR.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.41 komt te vaak voor [max 1x]. (count(hl7v2:OBR.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.42 komt te vaak voor [max 1x]. (count(hl7v2:OBR.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.44 komt te vaak voor [max 1x]. (count(hl7v2:OBR.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.48 komt te vaak voor [max 1x]. (count(hl7v2:OBR.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.49 komt te vaak voor [max 1x]. (count(hl7v2:OBR.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.1"
                 priority="12103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('237') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '237' zijn. (string(@Item)=('237') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - OBR' zijn. (string(@LongName)=('Set ID - OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2"
                 priority="12102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="12100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="12099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="12098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="12097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3"
                 priority="12095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="12093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="12092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="12091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="12090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4"
                 priority="12088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="12086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="12085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="12084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="12082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="12081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="12080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.5"
                 priority="12078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('239') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '239' zijn. (string(@Item)=('239') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority _ OBR' zijn. (string(@LongName)=('Priority _ OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6"
                 priority="12076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('240') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '240' zijn. (string(@Item)=('240') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Requested Date/Time' zijn. (string(@LongName)=('Requested Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="12074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="12073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7"
                 priority="12071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('241') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '241' zijn. (string(@Item)=('241') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Date/Time' zijn. (string(@LongName)=('Observation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="12069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="12068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8"
                 priority="12066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('242') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '242' zijn. (string(@Item)=('242') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation End Date/Time' zijn. (string(@LongName)=('Observation End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="12064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="12063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9"
                 priority="12061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('243') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '243' zijn. (string(@Item)=('243') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collection Volume' zijn. (string(@LongName)=('Collection Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="12059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="12058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10"
                 priority="12048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('244') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '244' zijn. (string(@Item)=('244') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collector Identifier' zijn. (string(@LongName)=('Collector Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="12046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="12045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="12038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="12037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="12036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="12035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="12034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="12033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="12032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="12026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="12024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="12023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="12021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="12019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="12013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="12011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="12001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="11989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="11987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="11982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="11977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="11976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="11963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.11"
                 priority="11950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('245') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '245' zijn. (string(@Item)=('245') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70065' zijn. (string(@Table)=('HL70065') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Action Code' zijn. (string(@LongName)=('Specimen Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12"
                 priority="11948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('246') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '246' zijn. (string(@Item)=('246') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Danger Code' zijn. (string(@LongName)=('Danger Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="11946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="11945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="11944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="11942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="11941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="11940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.13"
                 priority="11938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('247') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '247' zijn. (string(@Item)=('247') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relevant Clinical Information' zijn. (string(@LongName)=('Relevant Clinical Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14"
                 priority="11937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '248' zijn. (string(@Item)=('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn. (string(@LongName)=('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="11935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="11934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15"
                 priority="11932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '249' zijn. (string(@Item)=('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SPS' zijn. (string(@Type)=('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Source' zijn. (string(@LongName)=('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="11930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn. (string(@LongName)=('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="11928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="11927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="11926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="11924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="11923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="11922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="11920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="11919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="11918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="11917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn. (string(@LongName)=('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="11915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="11914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="11913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="11911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="11910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="11909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="11907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="11906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="11905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="11904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="11903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="11902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="11900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn. (string(@Table)=('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn. (string(@LongName)=('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="11898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="11897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="11896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="11894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="11893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="11892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="11890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="11889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="11888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="11887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn. (string(@Table)=('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn. (string(@LongName)=('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="11885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="11884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="11883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="11881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="11880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="11879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="11877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="11876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="11875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="11874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn. (string(@LongName)=('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="11872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="11871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="11870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="11868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="11867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="11866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="11864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="11863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="11862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="11861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="11859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="11858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="11857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="11855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="11854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="11853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="11851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="11850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="11849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16"
                 priority="11848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="11846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="11845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="11843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="11842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="11841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="11840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="11839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="11838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="11837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="11836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="11835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="11834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="11833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="11832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="11830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="11829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="11828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="11826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="11824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="11823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="11821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="11819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="11817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="11816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="11815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="11813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="11811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="11809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="11808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="11807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="11805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="11804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="11803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="11801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="11789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="11787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="11782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="11777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="11776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="11763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17"
                 priority="11750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('250') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '250' zijn. (string(@Item)=('250') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Callback Phone Number' zijn. (string(@LongName)=('Order Callback Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="11748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="11747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="11745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="11743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="11742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="11741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="11740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="11739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="11738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="11737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="11736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="11735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.18"
                 priority="11734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('251') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '251' zijn. (string(@Item)=('251') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Field 1' zijn. (string(@LongName)=('Placer Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.19"
                 priority="11733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('252') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '252' zijn. (string(@Item)=('252') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Field 2' zijn. (string(@LongName)=('Placer Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.20"
                 priority="11732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('253') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '253' zijn. (string(@Item)=('253') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Field 1' zijn. (string(@LongName)=('Filler Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.21"
                 priority="11731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('254') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '254' zijn. (string(@Item)=('254') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Field 2' zijn. (string(@LongName)=('Filler Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22"
                 priority="11730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('255') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '255' zijn. (string(@Item)=('255') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. (string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="11728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="11727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23"
                 priority="11725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x]. (count(hl7v2:MOC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x]. (count(hl7v2:MOC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('256') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '256' zijn. (string(@Item)=('256') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'MOC' zijn. (string(@Type)=('MOC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Charge to Practice' zijn. (string(@LongName)=('Charge to Practice') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="11723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Monetary Amount' zijn. (string(@LongName)=('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="11721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="11720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="11718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Charge Code' zijn. (string(@LongName)=('Charge Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="11716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="11715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="11714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="11712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="11711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="11710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.24"
                 priority="11708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('257') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '257' zijn. (string(@Item)=('257') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70074' zijn. (string(@Table)=('HL70074') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Diagnostic Serv Sect ID' zijn. (string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.25"
                 priority="11706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('258') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '258' zijn. (string(@Item)=('258') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70123' zijn. (string(@Table)=('HL70123') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Status' zijn. (string(@LongName)=('Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26"
                 priority="11704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x]. (count(hl7v2:PRL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x]. (count(hl7v2:PRL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x]. (count(hl7v2:PRL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('259') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '259' zijn. (string(@Item)=('259') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'PRL' zijn. (string(@Type)=('PRL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Parent Result' zijn. (string(@LongName)=('Parent Result') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="11702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Identifier' zijn. (string(@LongName)=('Parent Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="11700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="11699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="11698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="11696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="11695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="11694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="11692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Sub-identifier' zijn. (string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="11691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Value Descriptor' zijn. (string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="11690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="11689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27"
                 priority="11687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="11685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="11683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="11682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="11680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="11679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="11678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="11676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="11675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="11674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="11672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="11670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="11669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="11668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="11667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="11665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="11664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="11662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="11660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="11659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="11657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="11656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="11655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="11654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="11653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="11651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="11649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="11647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="11645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="11644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="11643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="11642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="11641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="11640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="11639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="11638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="11636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="11635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="11633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="11631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="11630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="11629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="11627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="11626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="11625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="11623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28"
                 priority="11622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('260') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '260' zijn. (string(@Item)=('260') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Copies To' zijn. (string(@LongName)=('Result Copies To') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="11620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="11619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="11617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="11616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="11615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="11614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="11613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="11612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="11611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="11610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="11609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="11608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="11607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="11606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="11604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="11603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="11602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="11600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="11598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="11597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="11595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="11593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="11591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="11590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="11589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="11587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="11585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="11583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="11582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="11581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="11579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="11578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="11577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="11575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="11563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="11561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="11556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="11551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="11550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="11537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29"
                 priority="11524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('261') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '261' zijn. (string(@Item)=('261') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="11522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="11520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="11519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="11518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="11517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="11515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="11513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="11512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="11511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="11510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.30"
                 priority="11508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('262') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '262' zijn. (string(@Item)=('262') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70124' zijn. (string(@Table)=('HL70124') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transportation Mode' zijn. (string(@LongName)=('Transportation Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31"
                 priority="11506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('263') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '263' zijn. (string(@Item)=('263') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Reason for Study' zijn. (string(@LongName)=('Reason for Study') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="11504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="11503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="11502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="11500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="11499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="11498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32"
                 priority="11496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('264') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '264' zijn. (string(@Item)=('264') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Principal Result Interpreter' zijn. (string(@LongName)=('Principal Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="11494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="11480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="11475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="11470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="11469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="11468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="11467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="11461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="11460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="11459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="11458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33"
                 priority="11457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('265') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '265' zijn. (string(@Item)=('265') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Assistant Result Interpreter' zijn. (string(@LongName)=('Assistant Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="11455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="11441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="11436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="11431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="11430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="11429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="11428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="11422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="11421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="11420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="11419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34"
                 priority="11418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('266') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '266' zijn. (string(@Item)=('266') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Technician' zijn. (string(@LongName)=('Technician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="11416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="11402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="11397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="11392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="11391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="11390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="11389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="11383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="11382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="11381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="11380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35"
                 priority="11379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('267') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '267' zijn. (string(@Item)=('267') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transcriptionist' zijn. (string(@LongName)=('Transcriptionist') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="11377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="11363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="11358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="11353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="11352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="11351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="11350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="11344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="11343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="11342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="11341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36"
                 priority="11340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('268') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '268' zijn. (string(@Item)=('268') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Scheduled Date/Time' zijn. (string(@LongName)=('Scheduled Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="11338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="11337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.37"
                 priority="11335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1028') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1028' zijn. (string(@Item)=('1028') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Number of Sample Containers *' zijn. (string(@LongName)=('Number of Sample Containers *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38"
                 priority="11334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1029') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1029' zijn. (string(@Item)=('1029') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Logistics of Collected Sample' zijn. (string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="11332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="11331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="11330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="11328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="11327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="11326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39"
                 priority="11324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1030') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1030' zijn. (string(@Item)=('1030') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collector''s Comment *' zijn. (string(@LongName)=('Collector''s Comment *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="11322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="11321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="11320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="11318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="11317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="11316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40"
                 priority="11314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1031') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1031' zijn. (string(@Item)=('1031') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Arrangement Responsibility' zijn. (string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="11312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="11311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="11310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="11308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="11307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="11306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.41"
                 priority="11304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1032') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1032' zijn. (string(@Item)=('1032') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70224' zijn. (string(@Table)=('HL70224') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Arranged' zijn. (string(@LongName)=('Transport Arranged') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.42"
                 priority="11302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1033') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1033' zijn. (string(@Item)=('1033') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70225' zijn. (string(@Table)=('HL70225') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Escort Required' zijn. (string(@LongName)=('Escort Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43"
                 priority="11300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1034') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1034' zijn. (string(@Item)=('1034') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Planned Patient Transport Comment' zijn. (string(@LongName)=('Planned Patient Transport Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="11298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="11297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="11296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="11294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="11293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="11292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44"
                 priority="11290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '393' zijn. (string(@Item)=('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70088' zijn. (string(@Table)=('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Procedure Code' zijn. (string(@LongName)=('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="11288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="11287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="11286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="11284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="11283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="11282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45"
                 priority="11280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1316' zijn. (string(@Item)=('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70340' zijn. (string(@Table)=('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Procedure Code Modifier' zijn. (string(@LongName)=('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="11278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="11277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="11276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="11274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="11273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="11272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46"
                 priority="11270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1474' zijn. (string(@Item)=('1474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Supplemental Service Information' zijn. (string(@LongName)=('Placer Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="11268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="11267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="11266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="11264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="11263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="11262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47"
                 priority="11260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1475' zijn. (string(@Item)=('1475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Supplemental Service Information' zijn. (string(@LongName)=('Filler Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="11258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="11257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="11256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="11254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="11253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="11252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48"
                 priority="11250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1646' zijn. (string(@Item)=('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70476' zijn. (string(@Table)=('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. (string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="11248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="11247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="11246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="11244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="11243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="11242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="11240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="11239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="11238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.49"
                 priority="11237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1647' zijn. (string(@Item)=('1647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70507' zijn. (string(@Table)=('HL70507') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Handling' zijn. (string(@LongName)=('Result Handling') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD"
                 priority="11236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 is required [min 1x]. (count(hl7v2:TCD.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x]. (count(hl7v2:TCD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x]. (count(hl7v2:TCD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x]. (count(hl7v2:TCD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x]. (count(hl7v2:TCD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x]. (count(hl7v2:TCD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x]. (count(hl7v2:TCD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x]. (count(hl7v2:TCD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x]. (count(hl7v2:TCD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1"
                 priority="11235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="11233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="11232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="11231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="11229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="11228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="11227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2"
                 priority="11225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1420' zijn. (string(@Item)=('1420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Auto-Dilution Factor' zijn. (string(@LongName)=('Auto-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="11223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="11222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="11221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="11220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3"
                 priority="11219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1421' zijn. (string(@Item)=('1421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Rerun Dilution Factor' zijn. (string(@LongName)=('Rerun Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="11217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="11216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="11215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="11214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4"
                 priority="11213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1422' zijn. (string(@Item)=('1422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Pre-Dilution Factor' zijn. (string(@LongName)=('Pre-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="11211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="11210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="11209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="11208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5"
                 priority="11207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1413' zijn. (string(@Item)=('1413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. (string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="11205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="11204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="11203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="11202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.6"
                 priority="11201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1416' zijn. (string(@Item)=('1416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Automatic Repeat Allowed' zijn. (string(@LongName)=('Automatic Repeat Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.7"
                 priority="11199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1424' zijn. (string(@Item)=('1424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Reflex Allowed' zijn. (string(@LongName)=('Reflex Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8"
                 priority="11197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1425' zijn. (string(@Item)=('1425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70389' zijn. (string(@Table)=('HL70389') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Analyte Repeat Status' zijn. (string(@LongName)=('Analyte Repeat Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="11195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="11194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="11193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="11191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="11190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="11189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE"
                 priority="11187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.1"
                 priority="11186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.2"
                 priority="11185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3"
                 priority="11183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="11182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="11181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4"
                 priority="11179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="11177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="11176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="11175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="11173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="11172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="11171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD"
                 priority="11169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.1 is required [min 1x]. (count(hl7v2:CTD.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.4 komt te vaak voor [max 1x]. (count(hl7v2:CTD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.6 komt te vaak voor [max 1x]. (count(hl7v2:CTD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1"
                 priority="11168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('196') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '196' zijn. (string(@Item)=('196') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70131') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Table MOET 'HL70131' zijn. (string(@Table)=('HL70131') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Role' zijn. (string(@LongName)=('Contact Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.1"
                 priority="11166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.2"
                 priority="11165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.3"
                 priority="11164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.4"
                 priority="11162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.5"
                 priority="11161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.6"
                 priority="11160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2"
                 priority="11158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '1165' zijn. (string(@Item)=('1165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Name' zijn. (string(@LongName)=('Contact Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1"
                 priority="11156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="11154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="11153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="11152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="11151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="11150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.2"
                 priority="11149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.3"
                 priority="11148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.4"
                 priority="11147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.5"
                 priority="11146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.6"
                 priority="11145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.7"
                 priority="11144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.8"
                 priority="11142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9"
                 priority="11140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="11138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="11137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="11136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="11134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="11133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="11132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10"
                 priority="11130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="11128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="11123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.11"
                 priority="11118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12"
                 priority="11116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="11114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="11113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13"
                 priority="11111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="11109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="11108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.14"
                 priority="11106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3"
                 priority="11105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '1166' zijn. (string(@Item)=('1166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Address' zijn. (string(@LongName)=('Contact Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1"
                 priority="11103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="11101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="11100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="11099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.2"
                 priority="11098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.3"
                 priority="11097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.4"
                 priority="11096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.5"
                 priority="11095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.6"
                 priority="11094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.7"
                 priority="11092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.8"
                 priority="11090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.9"
                 priority="11089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.10"
                 priority="11088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.11"
                 priority="11087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12"
                 priority="11085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="11083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="11078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13"
                 priority="11073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="11071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="11070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14"
                 priority="11068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="11066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="11065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4"
                 priority="11063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '1167' zijn. (string(@Item)=('1167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Location' zijn. (string(@LongName)=('Contact Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.1"
                 priority="11061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.2"
                 priority="11060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.3"
                 priority="11059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4"
                 priority="11058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.1"
                 priority="11056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.2"
                 priority="11055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.3"
                 priority="11054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.5"
                 priority="11052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.6"
                 priority="11051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.7"
                 priority="11050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.8"
                 priority="11049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.9"
                 priority="11048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10"
                 priority="11047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.1"
                 priority="11045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.2"
                 priority="11044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.3"
                 priority="11043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.4"
                 priority="11042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11"
                 priority="11040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.1"
                 priority="11038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.2"
                 priority="11037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.3"
                 priority="11036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5"
                 priority="11034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '1168' zijn. (string(@Item)=('1168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Communication Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Communication Information' zijn. (string(@LongName)=('Contact Communication Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.1"
                 priority="11032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.2"
                 priority="11031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.3"
                 priority="11029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.4"
                 priority="11027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.5"
                 priority="11026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.6"
                 priority="11025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.7"
                 priority="11024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.8"
                 priority="11023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.9"
                 priority="11022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.10"
                 priority="11021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.11"
                 priority="11020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.12"
                 priority="11019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6"
                 priority="11018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('684') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '684' zijn. (string(@Item)=('684') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70185') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Table MOET 'HL70185' zijn. (string(@Table)=('HL70185') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preferred Method of Contact') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Preferred Method of Contact' zijn. (string(@LongName)=('Preferred Method of Contact') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.1"
                 priority="11016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.2"
                 priority="11015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.3"
                 priority="11014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.4"
                 priority="11012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.5"
                 priority="11011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.6"
                 priority="11010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7"
                 priority="11008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.1 komt te vaak voor [max 1x]. (count(hl7v2:PLN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.2 komt te vaak voor [max 1x]. (count(hl7v2:PLN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.3 komt te vaak voor [max 1x]. (count(hl7v2:PLN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.4 komt te vaak voor [max 1x]. (count(hl7v2:PLN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Item MOET '1171' zijn. (string(@Item)=('1171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @Type MOET 'PLN' zijn. (string(@Type)=('PLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contact Identifiers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van @LongName MOET 'Contact Identifiers' zijn. (string(@LongName)=('Contact Identifiers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.1"
                 priority="11006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.2"
                 priority="11005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70338') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @Table MOET 'HL70338' zijn. (string(@Table)=('HL70338') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Type of ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @LongName MOET 'Type of ID Number' zijn. (string(@LongName)=('Type of ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.3"
                 priority="11004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State/other Qualifying Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @LongName MOET 'State/other Qualifying Information' zijn. (string(@LongName)=('State/other Qualifying Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.4"
                 priority="11003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1"
                 priority="11002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.1 is required [min 1x]. (count(hl7v2:DG1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.1 komt te vaak voor [max 1x]. (count(hl7v2:DG1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.2 is required [min 1x]. (count(hl7v2:DG1.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.2 komt te vaak voor [max 1x]. (count(hl7v2:DG1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.3 komt te vaak voor [max 1x]. (count(hl7v2:DG1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.4 komt te vaak voor [max 1x]. (count(hl7v2:DG1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.5 komt te vaak voor [max 1x]. (count(hl7v2:DG1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.6 is required [min 1x]. (count(hl7v2:DG1.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.6 komt te vaak voor [max 1x]. (count(hl7v2:DG1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.7 komt te vaak voor [max 1x]. (count(hl7v2:DG1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.8 komt te vaak voor [max 1x]. (count(hl7v2:DG1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.9 komt te vaak voor [max 1x]. (count(hl7v2:DG1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.10 komt te vaak voor [max 1x]. (count(hl7v2:DG1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.11 komt te vaak voor [max 1x]. (count(hl7v2:DG1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.12 komt te vaak voor [max 1x]. (count(hl7v2:DG1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.13 komt te vaak voor [max 1x]. (count(hl7v2:DG1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.14 komt te vaak voor [max 1x]. (count(hl7v2:DG1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.15 komt te vaak voor [max 1x]. (count(hl7v2:DG1.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.17 komt te vaak voor [max 1x]. (count(hl7v2:DG1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.18 komt te vaak voor [max 1x]. (count(hl7v2:DG1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.19 komt te vaak voor [max 1x]. (count(hl7v2:DG1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.20 komt te vaak voor [max 1x]. (count(hl7v2:DG1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.21 komt te vaak voor [max 1x]. (count(hl7v2:DG1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.1"
                 priority="11001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('375') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '375' zijn. (string(@Item)=('375') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - DG1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Set ID - DG1' zijn. (string(@LongName)=('Set ID - DG1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.2"
                 priority="11000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('376') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '376' zijn. (string(@Item)=('376') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70053') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70053' zijn. (string(@Table)=('HL70053') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Coding Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Coding Method' zijn. (string(@LongName)=('Diagnosis Coding Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3"
                 priority="10998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('377') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '377' zijn. (string(@Item)=('377') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70051') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70051' zijn. (string(@Table)=('HL70051') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Code - DG1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Code - DG1' zijn. (string(@LongName)=('Diagnosis Code - DG1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.1"
                 priority="10996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.2"
                 priority="10995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.3"
                 priority="10994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.4"
                 priority="10992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.5"
                 priority="10991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.6"
                 priority="10990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.4"
                 priority="10988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('378') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '378' zijn. (string(@Item)=('378') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Description' zijn. (string(@LongName)=('Diagnosis Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5"
                 priority="10987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('379') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '379' zijn. (string(@Item)=('379') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Date/Time' zijn. (string(@LongName)=('Diagnosis Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5/hl7v2:TS.1"
                 priority="10985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5/hl7v2:TS.2"
                 priority="10984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.6"
                 priority="10982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('380') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '380' zijn. (string(@Item)=('380') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70052') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70052' zijn. (string(@Table)=('HL70052') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Type' zijn. (string(@LongName)=('Diagnosis Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7"
                 priority="10981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('381') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '381' zijn. (string(@Item)=('381') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70118') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70118' zijn. (string(@Table)=('HL70118') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Major Diagnostic Category') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Major Diagnostic Category' zijn. (string(@LongName)=('Major Diagnostic Category') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.1"
                 priority="10979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.2"
                 priority="10978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.3"
                 priority="10977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.4"
                 priority="10975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.5"
                 priority="10974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.6"
                 priority="10973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8"
                 priority="10971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('382') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '382' zijn. (string(@Item)=('382') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70055') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70055' zijn. (string(@Table)=('HL70055') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnostic Related Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnostic Related Group' zijn. (string(@LongName)=('Diagnostic Related Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.1"
                 priority="10969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.2"
                 priority="10968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.3"
                 priority="10967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.4"
                 priority="10965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.5"
                 priority="10964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.6"
                 priority="10963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.9"
                 priority="10961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('383') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '383' zijn. (string(@Item)=('383') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('DRG Approval Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'DRG Approval Indicator' zijn. (string(@LongName)=('DRG Approval Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.10"
                 priority="10959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('384') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '384' zijn. (string(@Item)=('384') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70056') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70056' zijn. (string(@Table)=('HL70056') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('DRG Grouper Review Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'DRG Grouper Review Code' zijn. (string(@LongName)=('DRG Grouper Review Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11"
                 priority="10958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('385') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '385' zijn. (string(@Item)=('385') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70083') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70083' zijn. (string(@Table)=('HL70083') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Outlier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Outlier Type' zijn. (string(@LongName)=('Outlier Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.1"
                 priority="10956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.2"
                 priority="10955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.3"
                 priority="10954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.4"
                 priority="10952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.5"
                 priority="10951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.6"
                 priority="10950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.12"
                 priority="10948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('386') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '386' zijn. (string(@Item)=('386') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Outlier Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Outlier Days' zijn. (string(@LongName)=('Outlier Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13"
                 priority="10947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('387') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '387' zijn. (string(@Item)=('387') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Outlier Cost') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Outlier Cost' zijn. (string(@LongName)=('Outlier Cost') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1"
                 priority="10945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1/hl7v2:MO.1"
                 priority="10943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1/hl7v2:MO.2"
                 priority="10942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.2"
                 priority="10940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.3"
                 priority="10938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.4"
                 priority="10937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5"
                 priority="10936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.1"
                 priority="10934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.2"
                 priority="10933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.3"
                 priority="10932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.4"
                 priority="10930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.5"
                 priority="10929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.6"
                 priority="10928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.6"
                 priority="10926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.14"
                 priority="10924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('388') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '388' zijn. (string(@Item)=('388') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Grouper Version And Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Grouper Version And Type' zijn. (string(@LongName)=('Grouper Version And Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.15"
                 priority="10923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('389') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '389' zijn. (string(@Item)=('389') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70359') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70359' zijn. (string(@Table)=('HL70359') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Priority' zijn. (string(@LongName)=('Diagnosis Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16"
                 priority="10921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('390') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '390' zijn. (string(@Item)=('390') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosing Clinician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosing Clinician' zijn. (string(@LongName)=('Diagnosing Clinician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.1"
                 priority="10919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2"
                 priority="10918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.3"
                 priority="10911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.4"
                 priority="10910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.5"
                 priority="10909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.6"
                 priority="10908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.7"
                 priority="10907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.8"
                 priority="10906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9"
                 priority="10905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.10"
                 priority="10899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.11"
                 priority="10897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.12"
                 priority="10896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.13"
                 priority="10894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14"
                 priority="10892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.15"
                 priority="10886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16"
                 priority="10884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17"
                 priority="10874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.18"
                 priority="10862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19"
                 priority="10860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20"
                 priority="10855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.21"
                 priority="10850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22"
                 priority="10849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23"
                 priority="10836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.17"
                 priority="10823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('766') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '766' zijn. (string(@Item)=('766') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70228') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70228' zijn. (string(@Table)=('HL70228') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Classification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Classification' zijn. (string(@LongName)=('Diagnosis Classification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.18"
                 priority="10822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('767') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '767' zijn. (string(@Item)=('767') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Confidential Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Confidential Indicator' zijn. (string(@LongName)=('Confidential Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19"
                 priority="10820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('768') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '768' zijn. (string(@Item)=('768') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Attestation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Attestation Date/Time' zijn. (string(@LongName)=('Attestation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19/hl7v2:TS.1"
                 priority="10818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19/hl7v2:TS.2"
                 priority="10817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20"
                 priority="10815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1850') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '1850' zijn. (string(@Item)=('1850') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Identifier' zijn. (string(@LongName)=('Diagnosis Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.1"
                 priority="10813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.2"
                 priority="10812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.3"
                 priority="10811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.4"
                 priority="10810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.21"
                 priority="10808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1894') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Item MOET '1894' zijn. (string(@Item)=('1894') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70206') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @Table MOET 'HL70206' zijn. (string(@Table)=('HL70206') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van @LongName MOET 'Diagnosis Action Code' zijn. (string(@LongName)=('Diagnosis Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e82-false-d197111e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE' of 'ST'' zijn. (text()='CNE' or text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de element content van hl7v2:OBX.2 MOET ''CNE' of 'ST'' zijn. (text()='CNE' or text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '55607006' codeSystem '2.16.840.1.113883.6.96' displayName='Problem (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van 'code '55607006' codeSystem '2.16.840.1.113883.6.96' displayName='Problem (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10790"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(NM_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or $validNullFlavorsFound"/>
         <xsl:otherwise>
            <xsl:message>(NM_datatype): de nulwaarde '<xsl:text/>
               <xsl:value-of select="@nullFlavor"/>
               <xsl:text/>' voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardelijst 2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07). (not(@nullFlavor) or $validNullFlavorsFound / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or $validNullFlavorsFound"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de nulwaarde '<xsl:text/>
               <xsl:value-of select="@nullFlavor"/>
               <xsl:text/>' voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardelijst 2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07). (not(@nullFlavor) or $validNullFlavorsFound / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e90-false-d201388e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '282291009' codeSystem '2.16.840.1.113883.6.96' displayName='Diagnosis interpretation (observable entity)' codeSystemName='SNM''. (@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de elementwaarde MOET een zijn van 'code '282291009' codeSystem '2.16.840.1.113883.6.96' displayName='Diagnosis interpretation (observable entity)' codeSystemName='SNM''. (@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e98-false-d205609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '29463-7' codeSystem '2.16.840.1.113883.6.1' displayName='Body weight' codeSystemName='LN''. (@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de elementwaarde MOET een zijn van 'code '29463-7' codeSystem '2.16.840.1.113883.6.1' displayName='Body weight' codeSystemName='LN''. (@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e106-false-d209859e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '8302-2' codeSystem '2.16.840.1.113883.6.1' displayName='Body height' codeSystemName='LN''. (@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de elementwaarde MOET een zijn van 'code '8302-2' codeSystem '2.16.840.1.113883.6.1' displayName='Body height' codeSystemName='LN''. (@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='cm')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'cm''. (@nullFlavor or (@code='cm') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='cm')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de elementwaarde MOET een zijn van 'code 'cm''. (@nullFlavor or (@code='cm') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e114-false-d214103e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11368-8' codeSystem '2.16.840.1.113883.6.1' displayName='Illness or injury onset date and time' codeSystemName='LN''. (@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de elementwaarde MOET een zijn van 'code '11368-8' codeSystem '2.16.840.1.113883.6.1' displayName='Illness or injury onset date and time' codeSystemName='LN''. (@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="10087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="10086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e122-false-d218404e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 is mandatory [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 is mandatory [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 is mandatory [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e131-false-d222621e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn. (text()='CNE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn. (text()='CNE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '77386006' codeSystem '2.16.840.1.113883.6.96' displayName='Pregnant (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de elementwaarde MOET een zijn van 'code '77386006' codeSystem '2.16.840.1.113883.6.96' displayName='Pregnant (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e139-false-d226850e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11996-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Pregnancies' codeSystemName='LN''. (@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de elementwaarde MOET een zijn van 'code '11996-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Pregnancies' codeSystemName='LN''. (@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e147-false-d231079e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11977-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Parity' codeSystemName='LN''. (@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de elementwaarde MOET een zijn van 'code '11977-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Parity' codeSystemName='LN''. (@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e155-false-d235308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11778-8' codeSystem '2.16.840.1.113883.6.1' displayName='Delivery date Estimated' codeSystemName='LN''. (@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de elementwaarde MOET een zijn van 'code '11778-8' codeSystem '2.16.840.1.113883.6.1' displayName='Delivery date Estimated' codeSystemName='LN''. (@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="9208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="9207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e163-false-d239609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de element content van hl7v2:OBX.2 MOET ''NM'' zijn. (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='d')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'd''. (@nullFlavor or (@code='d') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='d')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de elementwaarde MOET een zijn van 'code 'd''. (@nullFlavor or (@code='d') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e171-false-d243841e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e180-false-d248058e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '418799008' codeSystem '2.16.840.1.113883.6.96' displayName='Finding reported by subject or history provider (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de elementwaarde MOET een zijn van 'code '418799008' codeSystem '2.16.840.1.113883.6.96' displayName='Finding reported by subject or history provider (finding)' codeSystemName='SNM''. (@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e188-false-d252287e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="8504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="8503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e196-false-d256573e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de element content van hl7v2:OBX.2 MOET ''TS'' zijn. (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '71388002' codeSystem '2.16.840.1.113883.6.96' displayName='Verrichting (verrichting)' codeSystemName='SNM''. (@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de elementwaarde MOET een zijn van 'code '71388002' codeSystem '2.16.840.1.113883.6.96' displayName='Verrichting (verrichting)' codeSystemName='SNM''. (@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="8325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="8324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e204-false-d260874e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '313150002' codeSystem '2.16.840.1.113883.6.96' displayName='Synthetic surgical material (substance)' codeSystemName='SNM''. (@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de elementwaarde MOET een zijn van 'code '313150002' codeSystem '2.16.840.1.113883.6.96' displayName='Synthetic surgical material (substance)' codeSystemName='SNM''. (@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e212-false-d265092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e220-false-d269298e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:NTE komt te vaak voor [max 1x]. (count(hl7v2:NTE)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE"
                 priority="7639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.1"
                 priority="7638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.2"
                 priority="7637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3"
                 priority="7635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="7634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="7633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="7632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4"
                 priority="7631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="7629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="7628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="7627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="7625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="7624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="7623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e231-false-d273960e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '184104002' codeSystem '2.16.840.1.113883.6.96' displayName='Patient occupation (observable entity)' codeSystemName='SNM''. (@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de elementwaarde MOET een zijn van 'code '184104002' codeSystem '2.16.840.1.113883.6.96' displayName='Patient occupation (observable entity)' codeSystemName='SNM''. (@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e239-false-d278186e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e247-false-d282386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TCD komt te vaak voor [max 1x]. (count(hl7v2:TCD)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD"
                 priority="7096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 is required [min 1x]. (count(hl7v2:TCD.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x]. (count(hl7v2:TCD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x]. (count(hl7v2:TCD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x]. (count(hl7v2:TCD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x]. (count(hl7v2:TCD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x]. (count(hl7v2:TCD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x]. (count(hl7v2:TCD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x]. (count(hl7v2:TCD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x]. (count(hl7v2:TCD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1"
                 priority="7095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="7093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="7092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="7091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="7089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="7088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="7087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2"
                 priority="7085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1420' zijn. (string(@Item)=('1420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Auto-Dilution Factor' zijn. (string(@LongName)=('Auto-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="7083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="7082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="7081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="7080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3"
                 priority="7079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1421' zijn. (string(@Item)=('1421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Rerun Dilution Factor' zijn. (string(@LongName)=('Rerun Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="7077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="7076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="7075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="7074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4"
                 priority="7073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1422' zijn. (string(@Item)=('1422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Pre-Dilution Factor' zijn. (string(@LongName)=('Pre-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="7071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="7070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="7069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="7068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5"
                 priority="7067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1413' zijn. (string(@Item)=('1413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. (string(@LongName)=('Endogenous Content of Pre-Dilution Diluent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="7065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="7064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="7063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="7062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.6"
                 priority="7061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1416' zijn. (string(@Item)=('1416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Automatic Repeat Allowed' zijn. (string(@LongName)=('Automatic Repeat Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.7"
                 priority="7059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1424' zijn. (string(@Item)=('1424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Reflex Allowed' zijn. (string(@LongName)=('Reflex Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8"
                 priority="7057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Item MOET '1425' zijn. (string(@Item)=('1425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @Table MOET 'HL70389' zijn. (string(@Table)=('HL70389') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van @LongName MOET 'Analyte Repeat Status' zijn. (string(@LongName)=('Analyte Repeat Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="7055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="7054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="7053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="7051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="7050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="7049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE"
                 priority="7047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.1"
                 priority="7046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.2"
                 priority="7045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3"
                 priority="7043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="7042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="7041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="7040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4"
                 priority="7039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="7037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="7036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="7035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="7033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="7032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="7031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e259-false-d288273e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN"
                 priority="7029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SPM is required [min 1x]. (count(hl7v2:SPM)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SPM komt te vaak voor [max 1x]. (count(hl7v2:SPM)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM"
                 priority="7028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.1 komt te vaak voor [max 1x]. (count(hl7v2:SPM.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.2 is required [min 1x]. (count(hl7v2:SPM.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.2 komt te vaak voor [max 1x]. (count(hl7v2:SPM.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.4 is required [min 1x]. (count(hl7v2:SPM.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.4 komt te vaak voor [max 1x]. (count(hl7v2:SPM.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.7 komt te vaak voor [max 1x]. (count(hl7v2:SPM.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.8 komt te vaak voor [max 1x]. (count(hl7v2:SPM.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.10 komt te vaak voor [max 1x]. (count(hl7v2:SPM.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.12 komt te vaak voor [max 1x]. (count(hl7v2:SPM.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.13 komt te vaak voor [max 1x]. (count(hl7v2:SPM.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.17 komt te vaak voor [max 1x]. (count(hl7v2:SPM.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.18 komt te vaak voor [max 1x]. (count(hl7v2:SPM.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.19 komt te vaak voor [max 1x]. (count(hl7v2:SPM.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.20 komt te vaak voor [max 1x]. (count(hl7v2:SPM.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.22 komt te vaak voor [max 1x]. (count(hl7v2:SPM.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.23 komt te vaak voor [max 1x]. (count(hl7v2:SPM.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.25 komt te vaak voor [max 1x]. (count(hl7v2:SPM.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.26 komt te vaak voor [max 1x]. (count(hl7v2:SPM.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.27 komt te vaak voor [max 1x]. (count(hl7v2:SPM.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.28 komt te vaak voor [max 1x]. (count(hl7v2:SPM.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): element hl7v2:SPM.29 komt te vaak voor [max 1x]. (count(hl7v2:SPM.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="7027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1754') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1754' zijn. (string(@Item)=('1754') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Set ID _ SPM' zijn. (string(@LongName)=('Set ID _ SPM') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="7026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1755' zijn. (string(@Item)=('1755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen ID' zijn. (string(@LongName)=('Specimen ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="7024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="7022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="7021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="7020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="7019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="7017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="7015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="7014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="7013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="7012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="7010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1756' zijn. (string(@Item)=('1756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Parent IDs' zijn. (string(@LongName)=('Specimen Parent IDs') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="7008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="7006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="7005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="7004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="7003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="7001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="6999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="6998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="6997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="6996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="6994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1900') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1900' zijn. (string(@Item)=('1900') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70487' zijn. (string(@Table)=('HL70487') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Type' zijn. (string(@LongName)=('Specimen Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="6992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="6991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="6990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="6988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="6987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="6986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="6984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="6983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="6982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="6981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1757' zijn. (string(@Item)=('1757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70541' zijn. (string(@Table)=('HL70541') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Type Modifier' zijn. (string(@LongName)=('Specimen Type Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="6979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="6978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="6977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="6975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="6974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="6973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="6971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="6970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="6969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="6968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1758') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1758' zijn. (string(@Item)=('1758') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Additives' zijn. (string(@LongName)=('Specimen Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="6966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="6965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="6964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="6962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="6961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="6960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="6958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="6957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="6956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="6955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1759' zijn. (string(@Item)=('1759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70488' zijn. (string(@Table)=('HL70488') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="6953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="6952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="6951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="6949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="6948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="6947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="6945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="6944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="6943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="6942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1901') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1901' zijn. (string(@Item)=('1901') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Source Site' zijn. (string(@LongName)=('Specimen Source Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="6940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="6939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="6938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="6936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="6935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="6934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="6932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="6931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="6930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="6929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1760' zijn. (string(@Item)=('1760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70542' zijn. (string(@Table)=('HL70542') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Source Site Modifier' zijn. (string(@LongName)=('Specimen Source Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="6927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="6926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="6925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="6923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="6922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="6921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="6919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="6918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="6917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="6916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1761' zijn. (string(@Item)=('1761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70543' zijn. (string(@Table)=('HL70543') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Collection Site' zijn. (string(@LongName)=('Specimen Collection Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="6914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="6913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="6912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="6910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="6909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="6908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="6906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="6905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="6904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="6903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1762' zijn. (string(@Item)=('1762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="6901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="6900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="6899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="6897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="6896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="6895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="6893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="6892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="6891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="6890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1902') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1902' zijn. (string(@Item)=('1902') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Collection Amount' zijn. (string(@LongName)=('Specimen Collection Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="6888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="6887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="6877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1763') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1763' zijn. (string(@Item)=('1763') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Grouped Specimen Count' zijn. (string(@LongName)=('Grouped Specimen Count') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="6876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1764') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1764' zijn. (string(@Item)=('1764') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Description' zijn. (string(@LongName)=('Specimen Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="6875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1908') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1908' zijn. (string(@Item)=('1908') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70376' zijn. (string(@Table)=('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Handling Code' zijn. (string(@LongName)=('Specimen Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="6873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="6872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="6871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="6869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="6868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="6867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="6865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="6864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="6863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="6862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1903') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1903' zijn. (string(@Item)=('1903') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70489' zijn. (string(@Table)=('HL70489') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Risk Code' zijn. (string(@LongName)=('Specimen Risk Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="6860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="6859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="6858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="6856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="6855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="6854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="6852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="6851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="6850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="6849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1765') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1765' zijn. (string(@Item)=('1765') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Collection Date/Time' zijn. (string(@LongName)=('Specimen Collection Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="6847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="6842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="6837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '248' zijn. (string(@Item)=('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn. (string(@LongName)=('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="6835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="6834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="6832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1904') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1904' zijn. (string(@Item)=('1904') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Expiration Date/Time' zijn. (string(@LongName)=('Specimen Expiration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="6830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="6829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="6827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1766') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1766' zijn. (string(@Item)=('1766') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Availability' zijn. (string(@LongName)=('Specimen Availability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="6825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1767') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1767' zijn. (string(@Item)=('1767') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70490' zijn. (string(@Table)=('HL70490') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Reject Reason' zijn. (string(@LongName)=('Specimen Reject Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="6823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="6822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="6821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="6819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="6818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="6817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="6815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="6814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="6813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="6812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1768') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1768' zijn. (string(@Item)=('1768') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70491' zijn. (string(@Table)=('HL70491') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Quality' zijn. (string(@LongName)=('Specimen Quality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="6810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="6809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="6808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="6806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="6805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="6804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="6802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="6801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="6800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="6799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1769') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1769' zijn. (string(@Item)=('1769') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70492' zijn. (string(@Table)=('HL70492') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Appropriateness' zijn. (string(@LongName)=('Specimen Appropriateness') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="6797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="6796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="6795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="6793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="6792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="6791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="6789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="6788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="6787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="6786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1770') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1770' zijn. (string(@Item)=('1770') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70493' zijn. (string(@Table)=('HL70493') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Condition' zijn. (string(@LongName)=('Specimen Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="6784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="6783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="6782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="6780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="6779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="6778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="6776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="6775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="6774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="6773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1771') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1771' zijn. (string(@Item)=('1771') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Current Quantity' zijn. (string(@LongName)=('Specimen Current Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="6771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="6770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="6760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1772') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1772' zijn. (string(@Item)=('1772') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Number of Specimen Containers' zijn. (string(@LongName)=('Number of Specimen Containers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="6759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1773') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1773' zijn. (string(@Item)=('1773') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Container Type' zijn. (string(@LongName)=('Container Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="6757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="6756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="6755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="6753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="6752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="6751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="6749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="6748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="6747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="6746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1774') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1774' zijn. (string(@Item)=('1774') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70544' zijn. (string(@Table)=('HL70544') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Container Condition' zijn. (string(@LongName)=('Container Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="6744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="6743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="6742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="6740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="6739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="6738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="6736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="6735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="6734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="6733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1775') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Item MOET '1775' zijn. (string(@Item)=('1775') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @Table MOET 'HL70494' zijn. (string(@Table)=('HL70494') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab2Lab): de waarde van @LongName MOET 'Specimen Child Role' zijn. (string(@LongName)=('Specimen Child Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="6731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="6730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="6729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="6727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="6726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="6725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="6723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="6722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="6721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX"
                 priority="6720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="6719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="6718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn. (text()='CNE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de element content van hl7v2:OBX.2 MOET ''CNE'' zijn. (text()='CNE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="6716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '370133003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen substance (attribute)' codeSystemName='SNM' of code '118169006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source topography (attribute)' codeSystemName='SNM' of code '118171006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen procedure (attribute)' codeSystemName='SNM' of code '118168003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source morphology (attribute)' codeSystemName='SNM' of code '118170007' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source identity (attribute)' codeSystemName='SNM''. (@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM')"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de elementwaarde MOET een zijn van 'code '370133003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen substance (attribute)' codeSystemName='SNM' of code '118169006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source topography (attribute)' codeSystemName='SNM' of code '118171006' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen procedure (attribute)' codeSystemName='SNM' of code '118168003' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source morphology (attribute)' codeSystemName='SNM' of code '118170007' codeSystem '2.16.840.1.113883.6.96' displayName='Specimen source identity (attribute)' codeSystemName='SNM''. (@nullFlavor or (@code='370133003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen substance (attribute)' and @codeSystemName='SNM') or (@code='118169006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source topography (attribute)' and @codeSystemName='SNM') or (@code='118171006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen procedure (attribute)' and @codeSystemName='SNM') or (@code='118168003' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source morphology (attribute)' and @codeSystemName='SNM') or (@code='118170007' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Specimen source identity (attribute)' and @codeSystemName='SNM') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="6714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="6713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="6712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="6710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="6709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="6708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="6706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="6705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.1"
                 priority="6703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.2"
                 priority="6702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.3"
                 priority="6701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.4"
                 priority="6699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.5"
                 priority="6698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.6"
                 priority="6697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.7"
                 priority="6695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.8"
                 priority="6694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5/hl7v2:CNE.9"
                 priority="6693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="6692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="6690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="6689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="6688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="6686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="6685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="6684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="6682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="6681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="6680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="6679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="6677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.11 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='F'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de element content van hl7v2:OBX.11 MOET ''F'' zijn. (text()='F' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="6675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="6673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="6672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="6670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="6669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="6667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="6666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="6664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="6662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="6661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="6660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="6658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="6657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="6656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="6654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="6652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="6651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="6644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="6643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="6642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="6641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="6640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="6639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="6638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="6632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="6630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="6629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="6627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="6625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="6619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="6617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="6607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="6595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="6593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="6588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="6583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="6582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="6569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="6556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="6554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="6553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="6552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="6550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="6549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="6548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="6546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="6544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="6543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="6542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="6541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="6539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_BronmateriaalIsolaat): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.49-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="6537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="6536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX"
                 priority="6534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="6533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="6532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de element content van hl7v2:OBX.2 MOET ''ST'' zijn. (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="6530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="6528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="6527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="6526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="6524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="6523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="6522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="6520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="6519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="6518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="6516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="6515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="6514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="6512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="6511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="6510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="6508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="6507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="6506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="6505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="6503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="6501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="6499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="6498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="6496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="6495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="6493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="6492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="6490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="6488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="6487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="6486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="6484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="6483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="6482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="6480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="6478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="6477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="6470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="6469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="6468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="6467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="6466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="6465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="6464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="6458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="6456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="6455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="6453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="6451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="6445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="6443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="6433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="6421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="6419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="6414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="6409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="6408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6397"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="6395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="6382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="6380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="6379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="6378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="6376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="6375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="6374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="6372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="6370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="6369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="6368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="6367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="6365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="6363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="6362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e274-false-d304758e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER"
                 priority="6360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SAC is required [min 1x]. (count(hl7v2:SAC)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SAC komt te vaak voor [max 1x]. (count(hl7v2:SAC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC"
                 priority="6359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x]. (count(hl7v2:SAC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x]. (count(hl7v2:SAC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x]. (count(hl7v2:SAC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x]. (count(hl7v2:SAC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x]. (count(hl7v2:SAC.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x]. (count(hl7v2:SAC.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x]. (count(hl7v2:SAC.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x]. (count(hl7v2:SAC.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x]. (count(hl7v2:SAC.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x]. (count(hl7v2:SAC.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x]. (count(hl7v2:SAC.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x]. (count(hl7v2:SAC.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x]. (count(hl7v2:SAC.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x]. (count(hl7v2:SAC.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x]. (count(hl7v2:SAC.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x]. (count(hl7v2:SAC.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x]. (count(hl7v2:SAC.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x]. (count(hl7v2:SAC.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x]. (count(hl7v2:SAC.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x]. (count(hl7v2:SAC.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x]. (count(hl7v2:SAC.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x]. (count(hl7v2:SAC.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x]. (count(hl7v2:SAC.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x]. (count(hl7v2:SAC.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x]. (count(hl7v2:SAC.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x]. (count(hl7v2:SAC.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x]. (count(hl7v2:SAC.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x]. (count(hl7v2:SAC.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x]. (count(hl7v2:SAC.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x]. (count(hl7v2:SAC.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x]. (count(hl7v2:SAC.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x]. (count(hl7v2:SAC.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x]. (count(hl7v2:SAC.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x]. (count(hl7v2:SAC.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x]. (count(hl7v2:SAC.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x]. (count(hl7v2:SAC.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x]. (count(hl7v2:SAC.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x]. (count(hl7v2:SAC.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1"
                 priority="6358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1329') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1329' zijn. (string(@Item)=('1329') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'External Accession Identifier' zijn. (string(@LongName)=('External Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="6356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="6355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="6354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="6353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2"
                 priority="6351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1330') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1330' zijn. (string(@Item)=('1330') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Accession Identifier' zijn. (string(@LongName)=('Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="6349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="6348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="6347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="6346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3"
                 priority="6344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1331') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1331' zijn. (string(@Item)=('1331') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Identifier' zijn. (string(@LongName)=('Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="6342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="6341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="6340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="6339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4"
                 priority="6337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1332') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1332' zijn. (string(@Item)=('1332') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Primary (parent) Container Identifier' zijn. (string(@LongName)=('Primary (parent) Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="6335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="6334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="6333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="6332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5"
                 priority="6330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1333') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1333' zijn. (string(@Item)=('1333') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Equipment Container Identifier' zijn. (string(@LongName)=('Equipment Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="6328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="6327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="6326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="6325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6"
                 priority="6323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '249' zijn. (string(@Item)=('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SPS' zijn. (string(@Type)=('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Specimen Source' zijn. (string(@LongName)=('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="6321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn. (string(@LongName)=('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="6319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="6318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="6317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="6315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="6314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="6313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="6311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="6310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="6309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="6308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn. (string(@LongName)=('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="6306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="6305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="6304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="6302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="6301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="6300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="6298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="6297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="6296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="6295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="6294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="6293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="6291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn. (string(@Table)=('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn. (string(@LongName)=('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="6289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="6288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="6287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="6285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="6284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="6283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="6281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="6280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="6279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="6278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn. (string(@Table)=('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn. (string(@LongName)=('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="6276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="6275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="6274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="6272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="6271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="6270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="6268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="6267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="6266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="6265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn. (string(@LongName)=('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="6263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="6262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="6261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="6259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="6258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="6257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="6255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="6254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="6253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="6252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="6250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="6249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="6248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="6246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="6245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="6244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="6242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="6241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="6240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7"
                 priority="6239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1334') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1334' zijn. (string(@Item)=('1334') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Registration Date/Time' zijn. (string(@LongName)=('Registration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="6237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="6236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8"
                 priority="6234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1335') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1335' zijn. (string(@Item)=('1335') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70370' zijn. (string(@Table)=('HL70370') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Status' zijn. (string(@LongName)=('Container Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="6232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="6231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="6230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="6228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="6227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="6226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9"
                 priority="6224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1336') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1336' zijn. (string(@Item)=('1336') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70378' zijn. (string(@Table)=('HL70378') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Carrier Type' zijn. (string(@LongName)=('Carrier Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="6222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="6221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="6220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="6218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="6217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="6216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10"
                 priority="6214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1337') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1337' zijn. (string(@Item)=('1337') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Carrier Identifier' zijn. (string(@LongName)=('Carrier Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="6212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="6211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="6210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="6209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11"
                 priority="6207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1338') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1338' zijn. (string(@Item)=('1338') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NA' zijn. (string(@Type)=('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Position in Carrier' zijn. (string(@LongName)=('Position in Carrier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="6205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn. (string(@LongName)=('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="6204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn. (string(@LongName)=('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="6203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn. (string(@LongName)=('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="6202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn. (string(@LongName)=('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12"
                 priority="6201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1339') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1339' zijn. (string(@Item)=('1339') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70379' zijn. (string(@Table)=('HL70379') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Tray Type - SAC' zijn. (string(@LongName)=('Tray Type - SAC') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="6199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="6198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="6197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="6195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="6194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="6193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13"
                 priority="6191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1340') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1340' zijn. (string(@Item)=('1340') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Tray Identifier' zijn. (string(@LongName)=('Tray Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="6189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="6188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="6187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="6186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14"
                 priority="6184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1341') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1341' zijn. (string(@Item)=('1341') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NA' zijn. (string(@Type)=('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Position in Tray' zijn. (string(@LongName)=('Position in Tray') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="6182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value1' zijn. (string(@LongName)=('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="6181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value2' zijn. (string(@LongName)=('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="6180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value3' zijn. (string(@LongName)=('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="6179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van @LongName MOET 'Value4' zijn. (string(@LongName)=('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15"
                 priority="6178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1342') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1342' zijn. (string(@Item)=('1342') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Location' zijn. (string(@LongName)=('Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="6176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="6175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="6174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="6172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="6171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="6170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.16"
                 priority="6168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1343') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1343' zijn. (string(@Item)=('1343') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Height' zijn. (string(@LongName)=('Container Height') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.17"
                 priority="6167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1344') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1344' zijn. (string(@Item)=('1344') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Diameter' zijn. (string(@LongName)=('Container Diameter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.18"
                 priority="6166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1345') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1345' zijn. (string(@Item)=('1345') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Barrier Delta' zijn. (string(@LongName)=('Barrier Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.19"
                 priority="6165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1346') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1346' zijn. (string(@Item)=('1346') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Bottom Delta' zijn. (string(@LongName)=('Bottom Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20"
                 priority="6164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1347') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1347' zijn. (string(@Item)=('1347') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Height/Diameter/Delta Units' zijn. (string(@LongName)=('Container Height/Diameter/Delta Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="6162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="6161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="6160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="6158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="6157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="6156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.21"
                 priority="6154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '644' zijn. (string(@Item)=('644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Container Volume' zijn. (string(@LongName)=('Container Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.22"
                 priority="6153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1349') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1349' zijn. (string(@Item)=('1349') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Available Specimen Volume' zijn. (string(@LongName)=('Available Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.23"
                 priority="6152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1350') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1350' zijn. (string(@Item)=('1350') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Initial Specimen Volume' zijn. (string(@LongName)=('Initial Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24"
                 priority="6151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1351') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1351' zijn. (string(@Item)=('1351') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Volume Units' zijn. (string(@LongName)=('Volume Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="6149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="6148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="6147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="6145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="6144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="6143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25"
                 priority="6141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1352') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1352' zijn. (string(@Item)=('1352') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70380' zijn. (string(@Table)=('HL70380') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Separator Type' zijn. (string(@LongName)=('Separator Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="6139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="6138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="6137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="6135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="6134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="6133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26"
                 priority="6131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1353') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1353' zijn. (string(@Item)=('1353') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70381' zijn. (string(@Table)=('HL70381') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Cap Type' zijn. (string(@LongName)=('Cap Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="6129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="6128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="6127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="6125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="6124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="6123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27"
                 priority="6121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '647' zijn. (string(@Item)=('647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Additive' zijn. (string(@LongName)=('Additive') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="6119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="6118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="6117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="6115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="6114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="6113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="6111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="6110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="6109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28"
                 priority="6108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1355') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1355' zijn. (string(@Item)=('1355') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Specimen Component' zijn. (string(@LongName)=('Specimen Component') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="6106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="6105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="6104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="6102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="6101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="6100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29"
                 priority="6098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1356') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1356' zijn. (string(@Item)=('1356') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Dilution Factor' zijn. (string(@LongName)=('Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="6096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="6095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="6094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="6093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30"
                 priority="6092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1357') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1357' zijn. (string(@Item)=('1357') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70373' zijn. (string(@Table)=('HL70373') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Treatment' zijn. (string(@LongName)=('Treatment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="6090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="6089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="6088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="6086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="6085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="6084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31"
                 priority="6082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1358') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1358' zijn. (string(@Item)=('1358') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'SN' zijn. (string(@Type)=('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Temperature' zijn. (string(@LongName)=('Temperature') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="6080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Comparator' zijn. (string(@LongName)=('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="6079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num1' zijn. (string(@LongName)=('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="6078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Separator/Suffix' zijn. (string(@LongName)=('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="6077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van @LongName MOET 'Num2' zijn. (string(@LongName)=('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.32"
                 priority="6076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1359') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1359' zijn. (string(@Item)=('1359') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index' zijn. (string(@LongName)=('Hemolysis Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33"
                 priority="6075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1360') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1360' zijn. (string(@Item)=('1360') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Hemolysis Index Units' zijn. (string(@LongName)=('Hemolysis Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="6073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="6072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="6071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="6069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="6068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="6067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.34"
                 priority="6065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1361') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1361' zijn. (string(@Item)=('1361') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index' zijn. (string(@LongName)=('Lipemia Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35"
                 priority="6064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1362') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1362' zijn. (string(@Item)=('1362') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Lipemia Index Units' zijn. (string(@LongName)=('Lipemia Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="6062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="6061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="6060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="6058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="6057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="6056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.36"
                 priority="6054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1363') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1363' zijn. (string(@Item)=('1363') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Icterus Index' zijn. (string(@LongName)=('Icterus Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37"
                 priority="6053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1364') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1364' zijn. (string(@Item)=('1364') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Icterus Index Units' zijn. (string(@LongName)=('Icterus Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="6051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="6050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="6049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="6047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="6046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="6045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.38"
                 priority="6043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1365') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1365' zijn. (string(@Item)=('1365') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index' zijn. (string(@LongName)=('Fibrin Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39"
                 priority="6042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1366') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1366' zijn. (string(@Item)=('1366') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Fibrin Index Units' zijn. (string(@LongName)=('Fibrin Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="6040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="6039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="6038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="6036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="6035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="6034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40"
                 priority="6032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1367') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1367' zijn. (string(@Item)=('1367') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70374' zijn. (string(@Table)=('HL70374') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'System Induced Contaminants' zijn. (string(@LongName)=('System Induced Contaminants') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="6030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="6029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="6028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="6026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="6025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="6024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41"
                 priority="6022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1368' zijn. (string(@Item)=('1368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70382' zijn. (string(@Table)=('HL70382') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Drug Interference' zijn. (string(@LongName)=('Drug Interference') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="6020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="6019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="6018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="6016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="6015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="6014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42"
                 priority="6012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1369') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1369' zijn. (string(@Item)=('1369') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70375' zijn. (string(@Table)=('HL70375') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Artificial Blood' zijn. (string(@LongName)=('Artificial Blood') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="6010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="6009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="6008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="6006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="6005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="6004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43"
                 priority="6002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1370') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1370' zijn. (string(@Item)=('1370') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70376' zijn. (string(@Table)=('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Special Handling Code' zijn. (string(@LongName)=('Special Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="6000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="5999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="5998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="5996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="5995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="5994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="5992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="5991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="5990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44"
                 priority="5989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1371') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Item MOET '1371' zijn. (string(@Item)=('1371') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @Table MOET 'HL70377' zijn. (string(@Table)=('HL70377') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van @LongName MOET 'Other Environmental Factors' zijn. (string(@LongName)=('Other Environmental Factors') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="5987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="5986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="5985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="5983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="5982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="5981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX"
                 priority="5979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.8 komt te vaak voor [max 1x]. (count(hl7v2:OBX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.1"
                 priority="5978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.2"
                 priority="5977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3"
                 priority="5975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="5973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="5972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="5971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="5969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="5968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="5967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.4"
                 priority="5965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.5"
                 priority="5964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6"
                 priority="5963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="5961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="5960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="5959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="5957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="5956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="5955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.7"
                 priority="5953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.8"
                 priority="5952"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.9"
                 priority="5950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.10"
                 priority="5949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.11"
                 priority="5947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12"
                 priority="5945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="5943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="5942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.13"
                 priority="5940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14"
                 priority="5939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="5937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="5936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15"
                 priority="5934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="5932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="5931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="5930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="5928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="5927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="5926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16"
                 priority="5924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="5922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="5921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="5914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="5913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="5912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="5911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="5910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="5909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="5908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="5902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="5900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="5899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="5897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="5895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="5889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="5887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="5877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="5865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="5863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="5858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="5853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="5852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="5839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17"
                 priority="5826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="5824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="5823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="5822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="5820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="5819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="5818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18"
                 priority="5816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="5814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="5813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="5812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="5811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19"
                 priority="5809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="5807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="5806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e282-false-d318507e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT"
                 priority="5804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_PRIOR)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_PRIOR komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_PRIOR)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_VISIT_PRIOR)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_VISIT_PRIOR komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_VISIT_PRIOR)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.ORDER_PRIOR)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.ORDER_PRIOR is required [min 1x]. (count(hl7v2:OML_O21.ORDER_PRIOR)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e292-false-d318530e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR"
                 priority="5803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID is required [min 1x]. (count(hl7v2:PID)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x]. (count(hl7v2:PID)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PD1 komt te vaak voor [max 1x]. (count(hl7v2:PD1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID"
                 priority="5802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.1 komt te vaak voor [max 1x]. (count(hl7v2:PID.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.2 komt te vaak voor [max 1x]. (count(hl7v2:PID.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.3 is required [min 1x]. (count(hl7v2:PID.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.5 is required [min 1x]. (count(hl7v2:PID.5)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.7 komt te vaak voor [max 1x]. (count(hl7v2:PID.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.8 komt te vaak voor [max 1x]. (count(hl7v2:PID.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.12 komt te vaak voor [max 1x]. (count(hl7v2:PID.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.15 komt te vaak voor [max 1x]. (count(hl7v2:PID.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.16 komt te vaak voor [max 1x]. (count(hl7v2:PID.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.17 komt te vaak voor [max 1x]. (count(hl7v2:PID.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.18 komt te vaak voor [max 1x]. (count(hl7v2:PID.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.19 komt te vaak voor [max 1x]. (count(hl7v2:PID.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.20 komt te vaak voor [max 1x]. (count(hl7v2:PID.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.23 komt te vaak voor [max 1x]. (count(hl7v2:PID.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.24 komt te vaak voor [max 1x]. (count(hl7v2:PID.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.25 komt te vaak voor [max 1x]. (count(hl7v2:PID.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.27 komt te vaak voor [max 1x]. (count(hl7v2:PID.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.28 komt te vaak voor [max 1x]. (count(hl7v2:PID.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.29 komt te vaak voor [max 1x]. (count(hl7v2:PID.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.30 komt te vaak voor [max 1x]. (count(hl7v2:PID.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.31 komt te vaak voor [max 1x]. (count(hl7v2:PID.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.33 komt te vaak voor [max 1x]. (count(hl7v2:PID.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.34 komt te vaak voor [max 1x]. (count(hl7v2:PID.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.35 komt te vaak voor [max 1x]. (count(hl7v2:PID.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.36 komt te vaak voor [max 1x]. (count(hl7v2:PID.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.37 komt te vaak voor [max 1x]. (count(hl7v2:PID.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38)&lt;=2"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): element hl7v2:PID.38 komt te vaak voor [max 2x]. (count(hl7v2:PID.38)&lt;=2 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.1"
                 priority="5801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('104') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '104' zijn. (string(@Item)=('104') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Set ID - PID' zijn. (string(@LongName)=('Set ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2"
                 priority="5800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('105') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '105' zijn. (string(@Item)=('105') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient ID' zijn. (string(@LongName)=('Patient ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="5798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="5797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="5796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="5794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="5788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="5786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="5780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="5779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="5778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="5765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3"
                 priority="5752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('106') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '106' zijn. (string(@Item)=('106') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Identifier List' zijn. (string(@LongName)=('Patient Identifier List') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="5750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="5749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="5748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="5746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="5740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="5738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="5732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="5731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="5730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="5717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4"
                 priority="5704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('107') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '107' zijn. (string(@Item)=('107') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Alternate Patient ID - PID' zijn. (string(@LongName)=('Alternate Patient ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="5702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="5701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="5700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="5698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="5692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="5690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="5684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="5683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="5682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="5669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5"
                 priority="5656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('108') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '108' zijn. (string(@Item)=('108') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Name' zijn. (string(@LongName)=('Patient Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="5654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="5647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="5646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="5645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="5644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="5643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="5642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="5640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="5638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="5628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="5616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="5614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="5609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="5604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6"
                 priority="5603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '109' zijn. (string(@Item)=('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Mother''s Maiden Name' zijn. (string(@LongName)=('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="5601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="5594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="5593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="5592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="5591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="5590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="5589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="5587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="5585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="5575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="5563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="5561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="5556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="5551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7"
                 priority="5550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '110' zijn. (string(@Item)=('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Date/Time of Birth' zijn. (string(@LongName)=('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="5548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="5547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.8"
                 priority="5545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '111' zijn. (string(@Item)=('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70001' zijn. (string(@Table)=('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Administrative Sex' zijn. (string(@LongName)=('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9"
                 priority="5544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('112') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '112' zijn. (string(@Item)=('112') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XPN' zijn. (string(@Type)=('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Alias' zijn. (string(@LongName)=('Patient Alias') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="5542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="5535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="5534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="5533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="5532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="5531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="5530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="5528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="5526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="5516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="5504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="5502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="5497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="5492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10"
                 priority="5491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '113' zijn. (string(@Item)=('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70005' zijn. (string(@Table)=('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Race' zijn. (string(@LongName)=('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="5489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="5488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="5487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="5485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="5484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="5483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11"
                 priority="5481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('114') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '114' zijn. (string(@Item)=('114') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Address' zijn. (string(@LongName)=('Patient Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="5479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="5474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="5473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="5472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="5471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="5470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="5468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="5466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="5465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="5464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="5463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="5461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="5449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="5444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.12"
                 priority="5439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('115') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '115' zijn. (string(@Item)=('115') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'County Code' zijn. (string(@LongName)=('County Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13"
                 priority="5438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('116') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '116' zijn. (string(@Item)=('116') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Phone Number - Home' zijn. (string(@LongName)=('Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="5436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="5435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="5433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="5431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="5430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="5429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="5428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="5427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="5426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="5425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="5424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="5423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14"
                 priority="5422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('117') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '117' zijn. (string(@Item)=('117') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Phone Number - Business' zijn. (string(@LongName)=('Phone Number - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="5420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="5419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="5417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="5415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="5414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="5413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="5412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="5411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="5410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="5409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="5408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="5407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15"
                 priority="5406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '118' zijn. (string(@Item)=('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70296' zijn. (string(@Table)=('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Primary Language' zijn. (string(@LongName)=('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="5404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="5403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="5402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="5400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="5399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="5398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16"
                 priority="5396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '119' zijn. (string(@Item)=('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70002' zijn. (string(@Table)=('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Marital Status' zijn. (string(@LongName)=('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="5394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="5393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="5392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="5390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="5389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="5388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17"
                 priority="5386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '120' zijn. (string(@Item)=('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70006' zijn. (string(@Table)=('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Religion' zijn. (string(@LongName)=('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="5384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="5383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="5382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="5380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="5379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="5378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18"
                 priority="5376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('121') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '121' zijn. (string(@Item)=('121') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Account Number' zijn. (string(@LongName)=('Patient Account Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="5374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="5373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="5372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="5370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="5364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="5362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="5356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="5355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="5354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="5341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.19"
                 priority="5328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('122') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '122' zijn. (string(@Item)=('122') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'SSN Number - Patient' zijn. (string(@LongName)=('SSN Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20"
                 priority="5327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x]. (count(hl7v2:DLN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x]. (count(hl7v2:DLN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x]. (count(hl7v2:DLN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('123') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '123' zijn. (string(@Item)=('123') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'DLN' zijn. (string(@Type)=('DLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Driver''s License Number - Patient' zijn. (string(@LongName)=('Driver''s License Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="5325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'License Number' zijn. (string(@LongName)=('License Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="5324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Table MOET 'HL70333' zijn. (string(@Table)=('HL70333') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Issuing State, Province, Country' zijn. (string(@LongName)=('Issuing State, Province, Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="5323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21"
                 priority="5322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('124') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '124' zijn. (string(@Item)=('124') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Mother''s Identifier' zijn. (string(@LongName)=('Mother''s Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="5320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="5319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="5318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="5316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="5310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="5308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="5302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="5301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="5300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="5287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22"
                 priority="5274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '125' zijn. (string(@Item)=('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70189' zijn. (string(@Table)=('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Ethnic Group' zijn. (string(@LongName)=('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="5272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="5271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="5270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="5268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="5267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="5266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.23"
                 priority="5264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('126') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '126' zijn. (string(@Item)=('126') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Birth Place' zijn. (string(@LongName)=('Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.24"
                 priority="5263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('127') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '127' zijn. (string(@Item)=('127') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Multiple Birth Indicator' zijn. (string(@LongName)=('Multiple Birth Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.25"
                 priority="5261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('128') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '128' zijn. (string(@Item)=('128') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Birth Order' zijn. (string(@LongName)=('Birth Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26"
                 priority="5260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '129' zijn. (string(@Item)=('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Citizenship' zijn. (string(@LongName)=('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="5258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="5257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="5256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="5254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="5253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="5252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27"
                 priority="5250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('130') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '130' zijn. (string(@Item)=('130') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70172' zijn. (string(@Table)=('HL70172') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Veterans Military Status' zijn. (string(@LongName)=('Veterans Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="5248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="5247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="5246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="5244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="5243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="5242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28"
                 priority="5240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '739' zijn. (string(@Item)=('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70212' zijn. (string(@Table)=('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Nationality' zijn. (string(@LongName)=('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="5238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="5237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="5236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="5234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="5233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="5232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29"
                 priority="5230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('740') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '740' zijn. (string(@Item)=('740') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Death Date and Time' zijn. (string(@LongName)=('Patient Death Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="5228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="5227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.30"
                 priority="5225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('741') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '741' zijn. (string(@Item)=('741') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Patient Death Indicator' zijn. (string(@LongName)=('Patient Death Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.31"
                 priority="5223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1535') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1535' zijn. (string(@Item)=('1535') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Identity Unknown Indicator' zijn. (string(@LongName)=('Identity Unknown Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.32"
                 priority="5221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1536') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1536' zijn. (string(@Item)=('1536') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70445' zijn. (string(@Table)=('HL70445') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Identity Reliability Code' zijn. (string(@LongName)=('Identity Reliability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33"
                 priority="5220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1537') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1537' zijn. (string(@Item)=('1537') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Last Update Date/Time' zijn. (string(@LongName)=('Last Update Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="5218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="5217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34"
                 priority="5215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1538') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1538' zijn. (string(@Item)=('1538') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Last Update Facility' zijn. (string(@LongName)=('Last Update Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="5213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="5212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="5211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35"
                 priority="5209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1539') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1539' zijn. (string(@Item)=('1539') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70446' zijn. (string(@Table)=('HL70446') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Species Code' zijn. (string(@LongName)=('Species Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="5207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="5206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="5205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="5203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="5202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="5201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36"
                 priority="5199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1540') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1540' zijn. (string(@Item)=('1540') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70447' zijn. (string(@Table)=('HL70447') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Breed Code' zijn. (string(@LongName)=('Breed Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="5197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="5196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="5195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="5193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="5192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="5191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.37"
                 priority="5189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1541') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1541' zijn. (string(@Item)=('1541') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Strain' zijn. (string(@LongName)=('Strain') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38"
                 priority="5188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1542') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1542' zijn. (string(@Item)=('1542') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70429' zijn. (string(@Table)=('HL70429') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Production Class Code' zijn. (string(@LongName)=('Production Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="5186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="5185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="5184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="5182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="5181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="5180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39"
                 priority="5178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1840') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Item MOET '1840' zijn. (string(@Item)=('1840') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @Table MOET 'HL70171' zijn. (string(@Table)=('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment): de waarde van @LongName MOET 'Tribal Citizenship' zijn. (string(@LongName)=('Tribal Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.101-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="5176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="5175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="5174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="5172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="5171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="5170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="5168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="5167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="5166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1"
                 priority="5165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x]. (count(hl7v2:PD1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x]. (count(hl7v2:PD1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x]. (count(hl7v2:PD1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x]. (count(hl7v2:PD1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x]. (count(hl7v2:PD1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x]. (count(hl7v2:PD1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x]. (count(hl7v2:PD1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x]. (count(hl7v2:PD1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x]. (count(hl7v2:PD1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x]. (count(hl7v2:PD1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x]. (count(hl7v2:PD1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x]. (count(hl7v2:PD1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x]. (count(hl7v2:PD1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x]. (count(hl7v2:PD1.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x]. (count(hl7v2:PD1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.1"
                 priority="5164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '755' zijn. (string(@Item)=('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70223' zijn. (string(@Table)=('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Dependency' zijn. (string(@LongName)=('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.2"
                 priority="5163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '742' zijn. (string(@Item)=('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70220' zijn. (string(@Table)=('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Arrangement' zijn. (string(@LongName)=('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3"
                 priority="5162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '756' zijn. (string(@Item)=('756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Facility' zijn. (string(@LongName)=('Patient Primary Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="5160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="5159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="5158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="5157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="5156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="5154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="5148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="5146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="5140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="5138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4"
                 priority="5137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '757' zijn. (string(@Item)=('757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. (string(@LongName)=('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="5135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="5134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="5127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="5126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="5125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="5124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="5123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="5122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="5121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="5115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="5113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="5112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="5110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="5108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="5102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="5100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="5090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="5078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="5076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="5071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="5066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="5065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="5052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.5"
                 priority="5039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '745' zijn. (string(@Item)=('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70231' zijn. (string(@Table)=('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Student Indicator' zijn. (string(@LongName)=('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.6"
                 priority="5038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '753' zijn. (string(@Item)=('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70295' zijn. (string(@Table)=('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Handicap' zijn. (string(@LongName)=('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.7"
                 priority="5037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.8"
                 priority="5036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.9"
                 priority="5035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '761' zijn. (string(@Item)=('761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Separate Bill' zijn. (string(@LongName)=('Separate Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10"
                 priority="5033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '762' zijn. (string(@Item)=('762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Duplicate Patient' zijn. (string(@LongName)=('Duplicate Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="5031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="5030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="5029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="5027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="5021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="5019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="5013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="5012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="5011"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="4998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11"
                 priority="4985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '743' zijn. (string(@Item)=('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code' zijn. (string(@LongName)=('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="4983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="4982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="4981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="4979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="4978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="4977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.12"
                 priority="4975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '744' zijn. (string(@Item)=('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator' zijn. (string(@LongName)=('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.13"
                 priority="4973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1566') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1566' zijn. (string(@Item)=('1566') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Protection Indicator Effective Date' zijn. (string(@LongName)=('Protection Indicator Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14"
                 priority="4972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1567') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1567' zijn. (string(@Item)=('1567') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Place of Worship' zijn. (string(@LongName)=('Place of Worship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="4970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="4969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="4968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="4967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="4966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="4964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="4962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="4961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="4960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="4958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="4956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="4954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="4953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="4952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="4950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="4948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15"
                 priority="4947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1568') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1568' zijn. (string(@Item)=('1568') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="4945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="4944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="4943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="4941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="4940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="4939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.16"
                 priority="4937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1569' zijn. (string(@Item)=('1569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70441' zijn. (string(@Table)=('HL70441') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status' zijn. (string(@LongName)=('Immunization Registry Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.17"
                 priority="4936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1570' zijn. (string(@Item)=('1570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Immunization Registry Status Effective Date' zijn. (string(@LongName)=('Immunization Registry Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.18"
                 priority="4935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1571' zijn. (string(@Item)=('1571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Publicity Code Effective Date' zijn. (string(@LongName)=('Publicity Code Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.19"
                 priority="4934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1572' zijn. (string(@Item)=('1572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70140' zijn. (string(@Table)=('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Branch' zijn. (string(@LongName)=('Military Branch') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.20"
                 priority="4933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '486' zijn. (string(@Item)=('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70141' zijn. (string(@Table)=('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Rank/Grade' zijn. (string(@LongName)=('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.21"
                 priority="4932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Item MOET '1573' zijn. (string(@Item)=('1573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @Table MOET 'HL70142' zijn. (string(@Table)=('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van @LongName MOET 'Military Status' zijn. (string(@LongName)=('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e299-false-d339738e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR"
                 priority="4931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 is required [min 1x]. (count(hl7v2:PV1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 komt te vaak voor [max 1x]. (count(hl7v2:PV1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV2 komt te vaak voor [max 1x]. (count(hl7v2:PV2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1"
                 priority="4930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.1 komt te vaak voor [max 1x]. (count(hl7v2:PV1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.2 is required [min 1x]. (count(hl7v2:PV1.2)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.2 komt te vaak voor [max 1x]. (count(hl7v2:PV1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.3 komt te vaak voor [max 1x]. (count(hl7v2:PV1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.4 komt te vaak voor [max 1x]. (count(hl7v2:PV1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.5 komt te vaak voor [max 1x]. (count(hl7v2:PV1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.6 komt te vaak voor [max 1x]. (count(hl7v2:PV1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.10 komt te vaak voor [max 1x]. (count(hl7v2:PV1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.11 komt te vaak voor [max 1x]. (count(hl7v2:PV1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.12 komt te vaak voor [max 1x]. (count(hl7v2:PV1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.13 komt te vaak voor [max 1x]. (count(hl7v2:PV1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.14 komt te vaak voor [max 1x]. (count(hl7v2:PV1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.16 komt te vaak voor [max 1x]. (count(hl7v2:PV1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.18 komt te vaak voor [max 1x]. (count(hl7v2:PV1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.19 komt te vaak voor [max 1x]. (count(hl7v2:PV1.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.21 komt te vaak voor [max 1x]. (count(hl7v2:PV1.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.22 komt te vaak voor [max 1x]. (count(hl7v2:PV1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.23 komt te vaak voor [max 1x]. (count(hl7v2:PV1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.28 komt te vaak voor [max 1x]. (count(hl7v2:PV1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.29 komt te vaak voor [max 1x]. (count(hl7v2:PV1.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.30 komt te vaak voor [max 1x]. (count(hl7v2:PV1.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.31 komt te vaak voor [max 1x]. (count(hl7v2:PV1.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.32 komt te vaak voor [max 1x]. (count(hl7v2:PV1.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.33 komt te vaak voor [max 1x]. (count(hl7v2:PV1.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.34 komt te vaak voor [max 1x]. (count(hl7v2:PV1.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.35 komt te vaak voor [max 1x]. (count(hl7v2:PV1.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.36 komt te vaak voor [max 1x]. (count(hl7v2:PV1.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.37 komt te vaak voor [max 1x]. (count(hl7v2:PV1.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.38 komt te vaak voor [max 1x]. (count(hl7v2:PV1.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.39 komt te vaak voor [max 1x]. (count(hl7v2:PV1.39)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.40 komt te vaak voor [max 1x]. (count(hl7v2:PV1.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.41 komt te vaak voor [max 1x]. (count(hl7v2:PV1.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.42 komt te vaak voor [max 1x]. (count(hl7v2:PV1.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.43 komt te vaak voor [max 1x]. (count(hl7v2:PV1.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.44 komt te vaak voor [max 1x]. (count(hl7v2:PV1.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.46 komt te vaak voor [max 1x]. (count(hl7v2:PV1.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.47 komt te vaak voor [max 1x]. (count(hl7v2:PV1.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.48 komt te vaak voor [max 1x]. (count(hl7v2:PV1.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.49 komt te vaak voor [max 1x]. (count(hl7v2:PV1.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.50 komt te vaak voor [max 1x]. (count(hl7v2:PV1.50)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.51 komt te vaak voor [max 1x]. (count(hl7v2:PV1.51)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.1"
                 priority="4929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('131') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '131' zijn. (string(@Item)=('131') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Set ID - PV1' zijn. (string(@LongName)=('Set ID - PV1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.2"
                 priority="4928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('132') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '132' zijn. (string(@Item)=('132') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70004' zijn. (string(@Table)=('HL70004') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Patient Class' zijn. (string(@LongName)=('Patient Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3"
                 priority="4927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '133' zijn. (string(@Item)=('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Assigned Patient Location' zijn. (string(@LongName)=('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="4925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="4924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="4923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="4922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="4916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="4915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="4914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="4913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="4912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="4911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="4904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.4"
                 priority="4898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('134') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '134' zijn. (string(@Item)=('134') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70007' zijn. (string(@Table)=('HL70007') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Admission Type' zijn. (string(@LongName)=('Admission Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5"
                 priority="4897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('135') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '135' zijn. (string(@Item)=('135') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Preadmit Number' zijn. (string(@LongName)=('Preadmit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="4895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="4894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="4893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="4891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="4885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="4883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="4877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="4876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="4875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="4862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6"
                 priority="4849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('136') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '136' zijn. (string(@Item)=('136') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Prior Patient Location' zijn. (string(@LongName)=('Prior Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="4847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="4846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="4845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="4844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="4838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="4837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="4836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="4835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="4834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="4833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4828"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="4826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7"
                 priority="4820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('137') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '137' zijn. (string(@Item)=('137') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Attending Doctor' zijn. (string(@LongName)=('Attending Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="4818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="4817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="4810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="4809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="4808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="4807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="4806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="4805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="4804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="4798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="4796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="4795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="4793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="4791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="4785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="4783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="4773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="4761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="4759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="4754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="4749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="4748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="4735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8"
                 priority="4722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('138') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '138' zijn. (string(@Item)=('138') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Referring Doctor' zijn. (string(@LongName)=('Referring Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="4720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="4719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="4712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="4711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="4710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="4709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="4708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="4707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="4706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="4700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="4698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="4697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="4695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="4693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="4687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="4685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="4675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="4663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="4661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="4656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="4651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="4650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4647"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="4637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9"
                 priority="4624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('139') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '139' zijn. (string(@Item)=('139') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Consulting Doctor' zijn. (string(@LongName)=('Consulting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="4622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="4621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="4614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="4613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="4612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="4611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="4610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="4609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="4608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="4602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="4600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="4599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="4597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="4595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="4589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="4587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="4577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="4565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="4563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="4558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="4553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="4552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="4539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.10"
                 priority="4526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('140') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '140' zijn. (string(@Item)=('140') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70069' zijn. (string(@Table)=('HL70069') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Hospital Service' zijn. (string(@LongName)=('Hospital Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11"
                 priority="4525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('141') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '141' zijn. (string(@Item)=('141') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Temporary Location' zijn. (string(@LongName)=('Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="4523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="4522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="4521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="4520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="4514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="4513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="4512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="4511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="4510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="4509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="4502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4499"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.12"
                 priority="4496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('142') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '142' zijn. (string(@Item)=('142') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70087' zijn. (string(@Table)=('HL70087') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Preadmit Test Indicator' zijn. (string(@LongName)=('Preadmit Test Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.13"
                 priority="4495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('143') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '143' zijn. (string(@Item)=('143') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70092' zijn. (string(@Table)=('HL70092') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Re-admission Indicator' zijn. (string(@LongName)=('Re-admission Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.14"
                 priority="4494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('144') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '144' zijn. (string(@Item)=('144') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70023' zijn. (string(@Table)=('HL70023') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Admit Source' zijn. (string(@LongName)=('Admit Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.15"
                 priority="4493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '145' zijn. (string(@Item)=('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70009' zijn. (string(@Table)=('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Ambulatory Status' zijn. (string(@LongName)=('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.16"
                 priority="4492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '146' zijn. (string(@Item)=('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70099' zijn. (string(@Table)=('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'VIP Indicator' zijn. (string(@LongName)=('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17"
                 priority="4491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('147') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '147' zijn. (string(@Item)=('147') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Admitting Doctor' zijn. (string(@LongName)=('Admitting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="4489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="4488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="4481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="4480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="4479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="4478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="4477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="4476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="4475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="4469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="4467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="4466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="4464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="4462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="4456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="4454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="4444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="4432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="4430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="4425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="4420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="4419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="4406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4395"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.18"
                 priority="4393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '148' zijn. (string(@Item)=('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70018' zijn. (string(@Table)=('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Patient Type' zijn. (string(@LongName)=('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19"
                 priority="4392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('149') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '149' zijn. (string(@Item)=('149') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Visit Number' zijn. (string(@LongName)=('Visit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="4390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="4389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="4388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="4386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="4380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="4378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="4372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="4371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="4370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="4357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20"
                 priority="4344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('150') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '150' zijn. (string(@Item)=('150') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'FC' zijn. (string(@Type)=('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Financial Class' zijn. (string(@LongName)=('Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="4342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Table MOET 'HL70064' zijn. (string(@Table)=('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Financial Class Code' zijn. (string(@LongName)=('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="4341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="4339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="4338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.21"
                 priority="4336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('151') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '151' zijn. (string(@Item)=('151') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70032' zijn. (string(@Table)=('HL70032') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Charge Price Indicator' zijn. (string(@LongName)=('Charge Price Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.22"
                 priority="4335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('152') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '152' zijn. (string(@Item)=('152') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70045' zijn. (string(@Table)=('HL70045') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Courtesy Code' zijn. (string(@LongName)=('Courtesy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.23"
                 priority="4334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('153') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '153' zijn. (string(@Item)=('153') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70046' zijn. (string(@Table)=('HL70046') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Credit Rating' zijn. (string(@LongName)=('Credit Rating') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.24"
                 priority="4333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('154') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '154' zijn. (string(@Item)=('154') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70044' zijn. (string(@Table)=('HL70044') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Contract Code' zijn. (string(@LongName)=('Contract Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.25"
                 priority="4332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('155') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '155' zijn. (string(@Item)=('155') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Contract Effective Date' zijn. (string(@LongName)=('Contract Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.26"
                 priority="4331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('156') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '156' zijn. (string(@Item)=('156') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Contract Amount' zijn. (string(@LongName)=('Contract Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.27"
                 priority="4330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('157') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '157' zijn. (string(@Item)=('157') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Contract Period' zijn. (string(@LongName)=('Contract Period') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.28"
                 priority="4329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('158') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '158' zijn. (string(@Item)=('158') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70073' zijn. (string(@Table)=('HL70073') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Interest Code' zijn. (string(@LongName)=('Interest Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.29"
                 priority="4328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('159') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '159' zijn. (string(@Item)=('159') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70110' zijn. (string(@Table)=('HL70110') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Transfer to Bad Debt Code' zijn. (string(@LongName)=('Transfer to Bad Debt Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.30"
                 priority="4327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('160') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '160' zijn. (string(@Item)=('160') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Transfer to Bad Debt Date' zijn. (string(@LongName)=('Transfer to Bad Debt Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.31"
                 priority="4326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('161') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '161' zijn. (string(@Item)=('161') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70021' zijn. (string(@Table)=('HL70021') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Bad Debt Agency Code' zijn. (string(@LongName)=('Bad Debt Agency Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.32"
                 priority="4325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('162') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '162' zijn. (string(@Item)=('162') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Bad Debt Transfer Amount' zijn. (string(@LongName)=('Bad Debt Transfer Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.33"
                 priority="4324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('163') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '163' zijn. (string(@Item)=('163') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Bad Debt Recovery Amount' zijn. (string(@LongName)=('Bad Debt Recovery Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.34"
                 priority="4323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('164') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '164' zijn. (string(@Item)=('164') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70111' zijn. (string(@Table)=('HL70111') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Delete Account Indicator' zijn. (string(@LongName)=('Delete Account Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.35"
                 priority="4322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '165' zijn. (string(@Item)=('165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Delete Account Date' zijn. (string(@LongName)=('Delete Account Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.36"
                 priority="4321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '166' zijn. (string(@Item)=('166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Discharge Disposition' zijn. (string(@LongName)=('Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37"
                 priority="4320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x]. (count(hl7v2:DLD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x]. (count(hl7v2:DLD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '167' zijn. (string(@Item)=('167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'DLD' zijn. (string(@Type)=('DLD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Discharged to Location' zijn. (string(@LongName)=('Discharged to Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="4318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Table MOET 'HL70113' zijn. (string(@Table)=('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Discharge Location' zijn. (string(@LongName)=('Discharge Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="4317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="4315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="4314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38"
                 priority="4312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '168' zijn. (string(@Item)=('168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70114' zijn. (string(@Table)=('HL70114') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Diet Type' zijn. (string(@LongName)=('Diet Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="4310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="4309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="4308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="4306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="4305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="4304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.39"
                 priority="4302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('169') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '169' zijn. (string(@Item)=('169') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70115' zijn. (string(@Table)=('HL70115') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Servicing Facility' zijn. (string(@LongName)=('Servicing Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.40"
                 priority="4301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('170') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '170' zijn. (string(@Item)=('170') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70116' zijn. (string(@Table)=('HL70116') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Bed Status' zijn. (string(@LongName)=('Bed Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.41"
                 priority="4300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '171' zijn. (string(@Item)=('171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70117' zijn. (string(@Table)=('HL70117') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Account Status' zijn. (string(@LongName)=('Account Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42"
                 priority="4299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('172') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '172' zijn. (string(@Item)=('172') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Pending Location' zijn. (string(@LongName)=('Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="4297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="4296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="4295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="4294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="4288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="4287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="4286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="4285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="4284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="4283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="4276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43"
                 priority="4270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('173') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '173' zijn. (string(@Item)=('173') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Prior Temporary Location' zijn. (string(@LongName)=('Prior Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="4268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="4267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="4266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="4265"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="4259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="4258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="4257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="4256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="4255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="4254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="4247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44"
                 priority="4241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('174') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '174' zijn. (string(@Item)=('174') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Admit Date/Time' zijn. (string(@LongName)=('Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="4239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="4238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45"
                 priority="4236"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('175') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '175' zijn. (string(@Item)=('175') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Discharge Date/Time' zijn. (string(@LongName)=('Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="4234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="4233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.46"
                 priority="4231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('176') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '176' zijn. (string(@Item)=('176') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Current Patient Balance' zijn. (string(@LongName)=('Current Patient Balance') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.47"
                 priority="4230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('177') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '177' zijn. (string(@Item)=('177') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Total Charges' zijn. (string(@LongName)=('Total Charges') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.48"
                 priority="4229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('178') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '178' zijn. (string(@Item)=('178') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Total Adjustments' zijn. (string(@LongName)=('Total Adjustments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.49"
                 priority="4228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('179') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '179' zijn. (string(@Item)=('179') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Total Payments' zijn. (string(@LongName)=('Total Payments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50"
                 priority="4227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('180') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '180' zijn. (string(@Item)=('180') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Alternate Visit ID' zijn. (string(@LongName)=('Alternate Visit ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="4225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="4224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="4223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="4221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4217"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="4215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="4213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="4207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="4206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="4205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="4192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4190"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.51"
                 priority="4179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '1226' zijn. (string(@Item)=('1226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70326' zijn. (string(@Table)=('HL70326') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Visit Indicator' zijn. (string(@LongName)=('Visit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52"
                 priority="4178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1274') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Item MOET '1274' zijn. (string(@Item)=('1274') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @Table MOET 'HL70010' zijn. (string(@Table)=('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van @LongName MOET 'Other Healthcare Provider' zijn. (string(@LongName)=('Other Healthcare Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="4176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="4175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="4168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="4167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="4166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="4165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="4164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="4163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="4162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="4156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="4154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="4153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="4151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="4149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="4143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="4141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="4131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="4119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="4117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="4112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="4107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="4106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="4093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2"
                 priority="4080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x]. (count(hl7v2:PV2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x]. (count(hl7v2:PV2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x]. (count(hl7v2:PV2.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x]. (count(hl7v2:PV2.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x]. (count(hl7v2:PV2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x]. (count(hl7v2:PV2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x]. (count(hl7v2:PV2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x]. (count(hl7v2:PV2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x]. (count(hl7v2:PV2.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x]. (count(hl7v2:PV2.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x]. (count(hl7v2:PV2.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x]. (count(hl7v2:PV2.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x]. (count(hl7v2:PV2.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x]. (count(hl7v2:PV2.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x]. (count(hl7v2:PV2.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x]. (count(hl7v2:PV2.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x]. (count(hl7v2:PV2.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x]. (count(hl7v2:PV2.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x]. (count(hl7v2:PV2.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x]. (count(hl7v2:PV2.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x]. (count(hl7v2:PV2.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x]. (count(hl7v2:PV2.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x]. (count(hl7v2:PV2.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x]. (count(hl7v2:PV2.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x]. (count(hl7v2:PV2.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x]. (count(hl7v2:PV2.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x]. (count(hl7v2:PV2.31)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x]. (count(hl7v2:PV2.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x]. (count(hl7v2:PV2.33)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x]. (count(hl7v2:PV2.34)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x]. (count(hl7v2:PV2.35)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x]. (count(hl7v2:PV2.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x]. (count(hl7v2:PV2.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x]. (count(hl7v2:PV2.38)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x]. (count(hl7v2:PV2.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x]. (count(hl7v2:PV2.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x]. (count(hl7v2:PV2.43)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x]. (count(hl7v2:PV2.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x]. (count(hl7v2:PV2.46)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x]. (count(hl7v2:PV2.47)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x]. (count(hl7v2:PV2.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1"
                 priority="4079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('181') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '181' zijn. (string(@Item)=('181') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Prior Pending Location' zijn. (string(@LongName)=('Prior Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="4077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="4076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="4075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="4074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="4068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="4067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="4066"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="4065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="4064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="4063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="4056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2"
                 priority="4050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('182') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '182' zijn. (string(@Item)=('182') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70129' zijn. (string(@Table)=('HL70129') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Accommodation Code' zijn. (string(@LongName)=('Accommodation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="4048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="4047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="4046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="4044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="4043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="4042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3"
                 priority="4040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('183') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '183' zijn. (string(@Item)=('183') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admit Reason' zijn. (string(@LongName)=('Admit Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="4038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="4037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="4036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="4034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="4033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="4032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4"
                 priority="4030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('184') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '184' zijn. (string(@Item)=('184') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Transfer Reason' zijn. (string(@LongName)=('Transfer Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="4028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="4027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="4026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="4024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="4023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="4022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.5"
                 priority="4020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('185') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '185' zijn. (string(@Item)=('185') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables' zijn. (string(@LongName)=('Patient Valuables') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.6"
                 priority="4019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('186') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '186' zijn. (string(@Item)=('186') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Valuables Location' zijn. (string(@LongName)=('Patient Valuables Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.7"
                 priority="4018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('187') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '187' zijn. (string(@Item)=('187') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70130' zijn. (string(@Table)=('HL70130') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit User Code' zijn. (string(@LongName)=('Visit User Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8"
                 priority="4017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('188') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '188' zijn. (string(@Item)=('188') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Admit Date/Time' zijn. (string(@LongName)=('Expected Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="4015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="4014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9"
                 priority="4012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('189') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '189' zijn. (string(@Item)=('189') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Date/Time' zijn. (string(@LongName)=('Expected Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="4010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="4009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.10"
                 priority="4007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('711') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '711' zijn. (string(@Item)=('711') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Estimated Length of Inpatient Stay' zijn. (string(@LongName)=('Estimated Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.11"
                 priority="4006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('712') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '712' zijn. (string(@Item)=('712') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Actual Length of Inpatient Stay' zijn. (string(@LongName)=('Actual Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.12"
                 priority="4005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('713') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '713' zijn. (string(@Item)=('713') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Description' zijn. (string(@LongName)=('Visit Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13"
                 priority="4004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('714') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '714' zijn. (string(@Item)=('714') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Referral Source Code' zijn. (string(@LongName)=('Referral Source Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="4002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="4001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3998"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="3994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="3993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="3992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="3991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="3990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="3989"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="3988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3985"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="3982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="3980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="3979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="3977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="3975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3971"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="3969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="3967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="3957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="3945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="3943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="3938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="3933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="3932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="3919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3916"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.14"
                 priority="3906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('715') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '715' zijn. (string(@Item)=('715') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Service Date' zijn. (string(@LongName)=('Previous Service Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.15"
                 priority="3905"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('716') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '716' zijn. (string(@Item)=('716') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Employment Illness Related Indicator' zijn. (string(@LongName)=('Employment Illness Related Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.16"
                 priority="3903"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('717') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '717' zijn. (string(@Item)=('717') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70213' zijn. (string(@Table)=('HL70213') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Code' zijn. (string(@LongName)=('Purge Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.17"
                 priority="3902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('718') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '718' zijn. (string(@Item)=('718') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Purge Status Date' zijn. (string(@LongName)=('Purge Status Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.18"
                 priority="3901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('719') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '719' zijn. (string(@Item)=('719') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70214' zijn. (string(@Table)=('HL70214') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Special Program Code' zijn. (string(@LongName)=('Special Program Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.19"
                 priority="3900"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('720') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '720' zijn. (string(@Item)=('720') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Retention Indicator' zijn. (string(@LongName)=('Retention Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.20"
                 priority="3898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('721') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '721' zijn. (string(@Item)=('721') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Number of Insurance Plans' zijn. (string(@LongName)=('Expected Number of Insurance Plans') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.21"
                 priority="3897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('722') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '722' zijn. (string(@Item)=('722') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70215' zijn. (string(@Table)=('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Publicity Code' zijn. (string(@LongName)=('Visit Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.22"
                 priority="3896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('723') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '723' zijn. (string(@Item)=('723') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Protection Indicator' zijn. (string(@LongName)=('Visit Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23"
                 priority="3894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('724') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '724' zijn. (string(@Item)=('724') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Clinic Organization Name' zijn. (string(@LongName)=('Clinic Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="3892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="3891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="3890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="3889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="3888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="3886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="3884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="3883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="3882"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="3880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="3878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="3876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="3875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="3874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="3872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="3870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.24"
                 priority="3869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('725') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '725' zijn. (string(@Item)=('725') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70216' zijn. (string(@Table)=('HL70216') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Code' zijn. (string(@LongName)=('Patient Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.25"
                 priority="3868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('726') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '726' zijn. (string(@Item)=('726') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70217' zijn. (string(@Table)=('HL70217') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Visit Priority Code' zijn. (string(@LongName)=('Visit Priority Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.26"
                 priority="3867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('727') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '727' zijn. (string(@Item)=('727') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Previous Treatment Date' zijn. (string(@LongName)=('Previous Treatment Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.27"
                 priority="3866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('728') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '728' zijn. (string(@Item)=('728') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70112' zijn. (string(@Table)=('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Discharge Disposition' zijn. (string(@LongName)=('Expected Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.28"
                 priority="3865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('729') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '729' zijn. (string(@Item)=('729') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Signature on File Date' zijn. (string(@LongName)=('Signature on File Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.29"
                 priority="3864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('730') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '730' zijn. (string(@Item)=('730') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'First Similar Illness Date' zijn. (string(@LongName)=('First Similar Illness Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30"
                 priority="3863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('731') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '731' zijn. (string(@Item)=('731') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70218' zijn. (string(@Table)=('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Charge Adjustment Code' zijn. (string(@LongName)=('Patient Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="3861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="3860"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="3859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="3857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="3856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="3855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.31"
                 priority="3853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('732') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '732' zijn. (string(@Item)=('732') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70219' zijn. (string(@Table)=('HL70219') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recurring Service Code' zijn. (string(@LongName)=('Recurring Service Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.32"
                 priority="3852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('733') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '733' zijn. (string(@Item)=('733') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Billing Media Code' zijn. (string(@LongName)=('Billing Media Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33"
                 priority="3850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('734') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '734' zijn. (string(@Item)=('734') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Surgery Date and Time' zijn. (string(@LongName)=('Expected Surgery Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="3848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="3847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.34"
                 priority="3845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('735') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '735' zijn. (string(@Item)=('735') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Partnership Code' zijn. (string(@LongName)=('Military Partnership Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.35"
                 priority="3843"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('736') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '736' zijn. (string(@Item)=('736') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Military Non-Availability Code' zijn. (string(@LongName)=('Military Non-Availability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.36"
                 priority="3841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('737') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '737' zijn. (string(@Item)=('737') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Newborn Baby Indicator' zijn. (string(@LongName)=('Newborn Baby Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.37"
                 priority="3839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('738') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '738' zijn. (string(@Item)=('738') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Baby Detained Indicator' zijn. (string(@LongName)=('Baby Detained Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38"
                 priority="3837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1543') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1543' zijn. (string(@Item)=('1543') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70430' zijn. (string(@Table)=('HL70430') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Mode of Arrival Code' zijn. (string(@LongName)=('Mode of Arrival Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="3835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="3834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="3833"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="3831"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="3830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="3829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39"
                 priority="3827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1544') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1544' zijn. (string(@Item)=('1544') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70431' zijn. (string(@Table)=('HL70431') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Recreational Drug Use Code' zijn. (string(@LongName)=('Recreational Drug Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="3825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="3824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="3823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="3821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="3820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="3819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40"
                 priority="3817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1545') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1545' zijn. (string(@Item)=('1545') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70432' zijn. (string(@Table)=('HL70432') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Admission Level of Care Code' zijn. (string(@LongName)=('Admission Level of Care Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="3815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="3814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="3813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="3811"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="3810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="3809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41"
                 priority="3807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1546') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1546' zijn. (string(@Item)=('1546') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70433' zijn. (string(@Table)=('HL70433') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Precaution Code' zijn. (string(@LongName)=('Precaution Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="3805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="3804"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="3803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="3801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="3800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="3799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42"
                 priority="3797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1547') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1547' zijn. (string(@Item)=('1547') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70434' zijn. (string(@Table)=('HL70434') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Condition Code' zijn. (string(@LongName)=('Patient Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="3795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="3794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="3793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="3791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="3790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="3789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.43"
                 priority="3787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '759' zijn. (string(@Item)=('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70315' zijn. (string(@Table)=('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Living Will Code' zijn. (string(@LongName)=('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.44"
                 priority="3786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '760' zijn. (string(@Item)=('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70316' zijn. (string(@Table)=('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Organ Donor Code' zijn. (string(@LongName)=('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45"
                 priority="3785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1548') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1548' zijn. (string(@Item)=('1548') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70435' zijn. (string(@Table)=('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Advance Directive Code' zijn. (string(@LongName)=('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="3783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="3782"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="3781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="3779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="3778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="3777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.46"
                 priority="3775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1549') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1549' zijn. (string(@Item)=('1549') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Patient Status Effective Date' zijn. (string(@LongName)=('Patient Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47"
                 priority="3774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1550') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1550' zijn. (string(@Item)=('1550') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected LOA Return Date/Time' zijn. (string(@LongName)=('Expected LOA Return Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="3772"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="3771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48"
                 priority="3769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1841') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1841' zijn. (string(@Item)=('1841') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. (string(@LongName)=('Expected Pre-admission Testing Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="3767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="3766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.49"
                 priority="3764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1842') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Item MOET '1842' zijn. (string(@Item)=('1842') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @Table MOET 'HL70534' zijn. (string(@Table)=('HL70534') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van @LongName MOET 'Notify Clergy Code' zijn. (string(@LongName)=('Notify Clergy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1"
                 priority="3763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.1 is required [min 1x]. (count(hl7v2:AL1.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.1 komt te vaak voor [max 1x]. (count(hl7v2:AL1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.2 komt te vaak voor [max 1x]. (count(hl7v2:AL1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.3 is required [min 1x]. (count(hl7v2:AL1.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.3 komt te vaak voor [max 1x]. (count(hl7v2:AL1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.4 komt te vaak voor [max 1x]. (count(hl7v2:AL1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.6 komt te vaak voor [max 1x]. (count(hl7v2:AL1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.1"
                 priority="3762"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('203') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '203' zijn. (string(@Item)=('203') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - AL1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Set ID - AL1' zijn. (string(@LongName)=('Set ID - AL1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2"
                 priority="3761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('204') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '204' zijn. (string(@Item)=('204') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70127') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Table MOET 'HL70127' zijn. (string(@Table)=('HL70127') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergen Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Allergen Type Code' zijn. (string(@LongName)=('Allergen Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.1"
                 priority="3759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.2"
                 priority="3758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.3"
                 priority="3757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.4"
                 priority="3755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.5"
                 priority="3754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.6"
                 priority="3753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3"
                 priority="3751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('205') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '205' zijn. (string(@Item)=('205') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergen Code/Mnemonic/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Allergen Code/Mnemonic/Description' zijn. (string(@LongName)=('Allergen Code/Mnemonic/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.1"
                 priority="3749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.2"
                 priority="3748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.3"
                 priority="3747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.4"
                 priority="3745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.5"
                 priority="3744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.6"
                 priority="3743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4"
                 priority="3741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('206') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '206' zijn. (string(@Item)=('206') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70128') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Table MOET 'HL70128' zijn. (string(@Table)=('HL70128') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergy Severity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Allergy Severity Code' zijn. (string(@LongName)=('Allergy Severity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.1"
                 priority="3739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.2"
                 priority="3738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.3"
                 priority="3737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.4"
                 priority="3735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.5"
                 priority="3734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.6"
                 priority="3733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.5"
                 priority="3731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('207') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '207' zijn. (string(@Item)=('207') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Allergy Reaction Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Allergy Reaction Code' zijn. (string(@LongName)=('Allergy Reaction Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.6"
                 priority="3730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('208') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Item MOET '208' zijn. (string(@Item)=('208') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identification Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van @LongName MOET 'Identification Date' zijn. (string(@LongName)=('Identification Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e309-false-d369595e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR"
                 priority="3729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x]. (count(hl7v2:ORC)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR is required [min 1x]. (count(hl7v2:OBR)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x]. (count(hl7v2:OBR)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION_PRIOR)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION_PRIOR is required [min 1x]. (count(hl7v2:OML_O21.OBSERVATION_PRIOR)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC"
                 priority="3728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.1 is required [min 1x]. (count(hl7v2:ORC.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.1 komt te vaak voor [max 1x]. (count(hl7v2:ORC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.2 komt te vaak voor [max 1x]. (count(hl7v2:ORC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.3 komt te vaak voor [max 1x]. (count(hl7v2:ORC.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.4 komt te vaak voor [max 1x]. (count(hl7v2:ORC.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.5 komt te vaak voor [max 1x]. (count(hl7v2:ORC.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.6 komt te vaak voor [max 1x]. (count(hl7v2:ORC.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.8 komt te vaak voor [max 1x]. (count(hl7v2:ORC.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.9 komt te vaak voor [max 1x]. (count(hl7v2:ORC.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.13 komt te vaak voor [max 1x]. (count(hl7v2:ORC.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.15 komt te vaak voor [max 1x]. (count(hl7v2:ORC.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.16 komt te vaak voor [max 1x]. (count(hl7v2:ORC.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.17 komt te vaak voor [max 1x]. (count(hl7v2:ORC.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.18 komt te vaak voor [max 1x]. (count(hl7v2:ORC.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.20 komt te vaak voor [max 1x]. (count(hl7v2:ORC.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.25 komt te vaak voor [max 1x]. (count(hl7v2:ORC.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.26 komt te vaak voor [max 1x]. (count(hl7v2:ORC.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.27 komt te vaak voor [max 1x]. (count(hl7v2:ORC.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.28 komt te vaak voor [max 1x]. (count(hl7v2:ORC.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.29 komt te vaak voor [max 1x]. (count(hl7v2:ORC.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): element hl7v2:ORC.30 komt te vaak voor [max 1x]. (count(hl7v2:ORC.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.1"
                 priority="3727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('215') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '215' zijn. (string(@Item)=('215') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70119' zijn. (string(@Table)=('HL70119') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Control' zijn. (string(@LongName)=('Order Control') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2"
                 priority="3725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="3723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="3722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="3721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="3720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3"
                 priority="3718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="3716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="3715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="3714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="3713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4"
                 priority="3711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('218') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '218' zijn. (string(@Item)=('218') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Placer Group Number' zijn. (string(@LongName)=('Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="3709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="3708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="3707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="3706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.5"
                 priority="3704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('219') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '219' zijn. (string(@Item)=('219') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70038' zijn. (string(@Table)=('HL70038') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Status' zijn. (string(@LongName)=('Order Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.6"
                 priority="3702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('220') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '220' zijn. (string(@Item)=('220') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70121' zijn. (string(@Table)=('HL70121') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Response Flag' zijn. (string(@LongName)=('Response Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7"
                 priority="3700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="3698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="3696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="3695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3689"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="3685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="3683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="3682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="3681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="3680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="3678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="3677"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="3675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="3673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="3672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="3670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="3669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="3668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="3667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="3666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="3664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="3662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="3660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="3658"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="3657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="3656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="3655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="3654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="3653"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="3652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="3651"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="3649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="3648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="3646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="3644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="3643"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="3642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="3640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="3639"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="3638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="3636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8"
                 priority="3635"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('222') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '222' zijn. (string(@Item)=('222') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="3633"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="3631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="3630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="3629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="3628"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="3626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="3624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="3623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="3622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="3621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9"
                 priority="3619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('223') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '223' zijn. (string(@Item)=('223') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Date/Time of Transaction' zijn. (string(@LongName)=('Date/Time of Transaction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="3617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="3616"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10"
                 priority="3614"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('224') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '224' zijn. (string(@Item)=('224') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Entered By' zijn. (string(@LongName)=('Entered By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="3612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="3611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3608"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="3604"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="3603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="3602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="3601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="3600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="3599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="3598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="3592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="3590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="3589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="3587"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="3585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="3579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="3577"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="3567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="3555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="3553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="3548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3546"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="3543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="3542"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3538"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3534"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3530"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="3529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11"
                 priority="3516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('225') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '225' zijn. (string(@Item)=('225') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Verified By' zijn. (string(@LongName)=('Verified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="3514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="3513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="3506"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="3505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="3504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="3503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="3502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="3501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="3500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="3494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="3492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="3491"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="3489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="3487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3483"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="3481"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="3479"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="3469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3467"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="3457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="3455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="3450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="3445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="3444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="3431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3427"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12"
                 priority="3418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="3416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="3415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="3408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="3407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="3406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="3405"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="3404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="3403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="3402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="3396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="3394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="3393"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="3391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="3389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3385"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="3383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="3381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3378"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="3371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3369"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3361"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="3359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="3357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3354"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="3352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="3347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="3346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="3333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3330"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13"
                 priority="3320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '227' zijn. (string(@Item)=('227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Enterer''s Location' zijn. (string(@LongName)=('Enterer''s Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="3318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="3317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="3316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="3315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="3313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="3312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="3311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="3309"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="3308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="3307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="3306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="3305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="3304"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="3302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="3301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="3300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="3299"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="3297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="3295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="3294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="3293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14"
                 priority="3291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('228') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '228' zijn. (string(@Item)=('228') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Call Back Phone Number' zijn. (string(@LongName)=('Call Back Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="3289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="3288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="3286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="3284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="3283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="3282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="3281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="3280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="3279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="3278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="3277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="3276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15"
                 priority="3275"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('229') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '229' zijn. (string(@Item)=('229') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Effective Date/Time' zijn. (string(@LongName)=('Order Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="3273"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="3272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16"
                 priority="3270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '230' zijn. (string(@Item)=('230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Control Code Reason' zijn. (string(@LongName)=('Order Control Code Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="3268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="3267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="3266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="3264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="3263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="3262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17"
                 priority="3260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '231' zijn. (string(@Item)=('231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Entering Organization' zijn. (string(@LongName)=('Entering Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="3258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="3257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="3256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="3254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="3253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="3252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18"
                 priority="3250"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('232') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '232' zijn. (string(@Item)=('232') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Entering Device' zijn. (string(@LongName)=('Entering Device') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="3248"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="3247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="3246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="3244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="3243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="3242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19"
                 priority="3240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('233') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '233' zijn. (string(@Item)=('233') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Action By' zijn. (string(@LongName)=('Action By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="3238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="3237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="3230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="3229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="3228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="3227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="3226"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="3225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="3224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="3218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="3216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="3215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="3213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="3211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3209"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="3205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="3203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="3193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="3181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="3179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="3174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="3169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="3168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3166"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="3155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3148"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20"
                 priority="3142"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1310' zijn. (string(@Item)=('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70339' zijn. (string(@Table)=('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Advanced Beneficiary Notice Code' zijn. (string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="3140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="3139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="3138"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="3136"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="3135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="3134"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21"
                 priority="3132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1311') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1311' zijn. (string(@Item)=('1311') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XON' zijn. (string(@Type)=('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Ordering Facility Name' zijn. (string(@LongName)=('Ordering Facility Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="3130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name' zijn. (string(@LongName)=('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="3129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70204' zijn. (string(@Table)=('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Name Type Code' zijn. (string(@LongName)=('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="3128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="3127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="3126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="3124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="3122"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="3121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="3120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="3118"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="3116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="3114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="3113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="3112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="3110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="3108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van @LongName MOET 'Organization Identifier' zijn. (string(@LongName)=('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22"
                 priority="3107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1312') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1312' zijn. (string(@Item)=('1312') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Ordering Facility Address' zijn. (string(@LongName)=('Ordering Facility Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="3105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="3103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="3102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="3101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="3100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="3099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="3098"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="3097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="3096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="3094"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="3092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="3091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="3090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="3089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="3087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="3085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="3080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="3075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="3073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="3072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="3070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="3068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="3067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23"
                 priority="3065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1313') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1313' zijn. (string(@Item)=('1313') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Ordering Facility Phone Number' zijn. (string(@LongName)=('Ordering Facility Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="3063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="3062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="3060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="3058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="3057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="3056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="3055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="3054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="3053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="3052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="3051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="3050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24"
                 priority="3049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1314') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1314' zijn. (string(@Item)=('1314') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'XAD' zijn. (string(@Type)=('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Ordering Provider Address' zijn. (string(@LongName)=('Ordering Provider Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="3047"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'SAD' zijn. (string(@Type)=('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Street Address' zijn. (string(@LongName)=('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="3045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street or Mailing Address' zijn. (string(@LongName)=('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="3044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Street Name' zijn. (string(@LongName)=('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="3043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van @LongName MOET 'Dwelling Number' zijn. (string(@LongName)=('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="3042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Designation' zijn. (string(@LongName)=('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="3041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'City' zijn. (string(@LongName)=('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="3040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'State or Province' zijn. (string(@LongName)=('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="3039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Zip or Postal Code' zijn. (string(@LongName)=('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="3038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70399' zijn. (string(@Table)=('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Country' zijn. (string(@LongName)=('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="3036"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70190' zijn. (string(@Table)=('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Type' zijn. (string(@LongName)=('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="3034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Other Geographic Designation' zijn. (string(@LongName)=('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="3033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70289' zijn. (string(@Table)=('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'County/Parish Code' zijn. (string(@LongName)=('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="3032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70288' zijn. (string(@Table)=('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Census Tract' zijn. (string(@LongName)=('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="3031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Representation Code' zijn. (string(@LongName)=('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="3029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Address Validity Range' zijn. (string(@LongName)=('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="3027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3024"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="3022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="3017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="3015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="3014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="3012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="3010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="3009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25"
                 priority="3007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1473' zijn. (string(@Item)=('1473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Status Modifier' zijn. (string(@LongName)=('Order Status Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="3005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="3004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="3003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="3001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="3000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="2999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="2997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="2996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="2995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26"
                 priority="2994"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1641') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1641' zijn. (string(@Item)=('1641') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70552' zijn. (string(@Table)=('HL70552') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. (string(@LongName)=('Advanced Beneficiary Notice Override Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="2992"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="2991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="2990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="2988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="2987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="2986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="2984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="2983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="2982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27"
                 priority="2981"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1642') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1642' zijn. (string(@Item)=('1642') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Filler''s Expected Availability Date/Time' zijn. (string(@LongName)=('Filler''s Expected Availability Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="2979"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="2978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28"
                 priority="2976"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('615') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '615' zijn. (string(@Item)=('615') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70177' zijn. (string(@Table)=('HL70177') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Confidentiality Code' zijn. (string(@LongName)=('Confidentiality Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="2974"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="2973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="2972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="2970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="2969"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="2968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="2966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="2965"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="2964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29"
                 priority="2963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1643') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1643' zijn. (string(@Item)=('1643') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70482' zijn. (string(@Table)=('HL70482') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Order Type' zijn. (string(@LongName)=('Order Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="2961"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="2960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="2959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="2957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="2956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="2955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="2953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="2952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="2951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30"
                 priority="2950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Item MOET '1644' zijn. (string(@Item)=('1644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Type MOET 'CNE' zijn. (string(@Type)=('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @Table MOET 'HL70483' zijn. (string(@Table)=('HL70483') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab2Lab_aanvraag_vorig): de waarde van @LongName MOET 'Enterer Authorization Mode' zijn. (string(@LongName)=('Enterer Authorization Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.9-2015-07-23T161037.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="2948"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="2947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="2946"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="2944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="2943"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="2942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="2940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="2939"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="2938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR"
                 priority="2937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.1 komt te vaak voor [max 1x]. (count(hl7v2:OBR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.2 komt te vaak voor [max 1x]. (count(hl7v2:OBR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.3 komt te vaak voor [max 1x]. (count(hl7v2:OBR.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 is required [min 1x]. (count(hl7v2:OBR.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 komt te vaak voor [max 1x]. (count(hl7v2:OBR.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.5 komt te vaak voor [max 1x]. (count(hl7v2:OBR.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.6 komt te vaak voor [max 1x]. (count(hl7v2:OBR.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.7 komt te vaak voor [max 1x]. (count(hl7v2:OBR.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.8 komt te vaak voor [max 1x]. (count(hl7v2:OBR.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.9 komt te vaak voor [max 1x]. (count(hl7v2:OBR.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.11 komt te vaak voor [max 1x]. (count(hl7v2:OBR.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.12 komt te vaak voor [max 1x]. (count(hl7v2:OBR.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.13 komt te vaak voor [max 1x]. (count(hl7v2:OBR.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.14 komt te vaak voor [max 1x]. (count(hl7v2:OBR.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.15 komt te vaak voor [max 1x]. (count(hl7v2:OBR.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.18 komt te vaak voor [max 1x]. (count(hl7v2:OBR.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.19 komt te vaak voor [max 1x]. (count(hl7v2:OBR.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.20 komt te vaak voor [max 1x]. (count(hl7v2:OBR.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.21 komt te vaak voor [max 1x]. (count(hl7v2:OBR.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.22 komt te vaak voor [max 1x]. (count(hl7v2:OBR.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.23 komt te vaak voor [max 1x]. (count(hl7v2:OBR.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.24 komt te vaak voor [max 1x]. (count(hl7v2:OBR.24)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.25 komt te vaak voor [max 1x]. (count(hl7v2:OBR.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.26 komt te vaak voor [max 1x]. (count(hl7v2:OBR.26)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.29 komt te vaak voor [max 1x]. (count(hl7v2:OBR.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.30 komt te vaak voor [max 1x]. (count(hl7v2:OBR.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.32 komt te vaak voor [max 1x]. (count(hl7v2:OBR.32)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.36 komt te vaak voor [max 1x]. (count(hl7v2:OBR.36)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.37 komt te vaak voor [max 1x]. (count(hl7v2:OBR.37)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.40 komt te vaak voor [max 1x]. (count(hl7v2:OBR.40)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.41 komt te vaak voor [max 1x]. (count(hl7v2:OBR.41)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.42 komt te vaak voor [max 1x]. (count(hl7v2:OBR.42)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.44 komt te vaak voor [max 1x]. (count(hl7v2:OBR.44)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.48 komt te vaak voor [max 1x]. (count(hl7v2:OBR.48)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.49 komt te vaak voor [max 1x]. (count(hl7v2:OBR.49)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.1"
                 priority="2936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('237') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '237' zijn. (string(@Item)=('237') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - OBR' zijn. (string(@LongName)=('Set ID - OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2"
                 priority="2935"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '216' zijn. (string(@Item)=('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Order Number' zijn. (string(@LongName)=('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="2933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="2932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="2931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="2930"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3"
                 priority="2928"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="2926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="2925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="2924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="2923"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4"
                 priority="2921"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '238' zijn. (string(@Item)=('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Universal Service Identifier' zijn. (string(@LongName)=('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="2919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="2918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="2917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="2915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="2914"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="2913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.5"
                 priority="2911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('239') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '239' zijn. (string(@Item)=('239') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority _ OBR' zijn. (string(@LongName)=('Priority _ OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6"
                 priority="2909"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('240') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '240' zijn. (string(@Item)=('240') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Requested Date/Time' zijn. (string(@LongName)=('Requested Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="2907"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="2906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7"
                 priority="2904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('241') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '241' zijn. (string(@Item)=('241') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation Date/Time' zijn. (string(@LongName)=('Observation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="2902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="2901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8"
                 priority="2899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('242') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '242' zijn. (string(@Item)=('242') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Observation End Date/Time' zijn. (string(@LongName)=('Observation End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="2897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="2896"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9"
                 priority="2894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('243') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '243' zijn. (string(@Item)=('243') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collection Volume' zijn. (string(@LongName)=('Collection Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="2892"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="2891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2889"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2884"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10"
                 priority="2881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('244') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '244' zijn. (string(@Item)=('244') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collector Identifier' zijn. (string(@LongName)=('Collector Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="2879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="2878"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2874"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="2871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="2870"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="2869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="2868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="2867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="2866"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="2865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2862"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="2859"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="2857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="2856"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="2854"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="2852"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2849"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="2846"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="2844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2841"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2837"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="2834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="2822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="2820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="2815"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="2810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="2809"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2806"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2802"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2798"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="2796"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2794"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2790"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2786"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2784"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.11"
                 priority="2783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('245') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '245' zijn. (string(@Item)=('245') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70065' zijn. (string(@Table)=('HL70065') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Action Code' zijn. (string(@LongName)=('Specimen Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12"
                 priority="2781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('246') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '246' zijn. (string(@Item)=('246') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Danger Code' zijn. (string(@LongName)=('Danger Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="2779"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="2778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="2777"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="2775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="2774"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="2773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.13"
                 priority="2771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('247') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '247' zijn. (string(@Item)=('247') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relevant Clinical Information' zijn. (string(@LongName)=('Relevant Clinical Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14"
                 priority="2770"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '248' zijn. (string(@Item)=('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Received Date/Time' zijn. (string(@LongName)=('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="2768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="2767"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15"
                 priority="2765"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '249' zijn. (string(@Item)=('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SPS' zijn. (string(@Type)=('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Specimen Source' zijn. (string(@LongName)=('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="2763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Source Name or Code' zijn. (string(@LongName)=('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="2761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="2760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="2759"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="2757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="2756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="2755"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="2753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="2752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="2751"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="2750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70371' zijn. (string(@Table)=('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Additives' zijn. (string(@LongName)=('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="2748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="2747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="2746"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="2744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="2743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="2742"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="2740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="2739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="2738"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="2737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Collection Method' zijn. (string(@LongName)=('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="2736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="2735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="2733"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70163' zijn. (string(@Table)=('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Body Site' zijn. (string(@LongName)=('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="2731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="2730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="2729"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="2727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="2726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="2725"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="2723"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="2722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="2721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="2720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70495' zijn. (string(@Table)=('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Site Modifier' zijn. (string(@LongName)=('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="2718"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="2717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="2716"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="2714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="2713"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="2712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="2710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="2709"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="2708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="2707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Collection Method Modifier Code' zijn. (string(@LongName)=('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="2705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="2704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="2703"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="2701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="2700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="2699"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="2697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="2696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="2695"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="2694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @Table MOET 'HL70369' zijn. (string(@Table)=('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van @LongName MOET 'Specimen Role' zijn. (string(@LongName)=('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="2692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="2691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="2690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="2688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="2687"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="2686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="2684"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="2683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="2682"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16"
                 priority="2681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '226' zijn. (string(@Item)=('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Ordering Provider' zijn. (string(@LongName)=('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="2679"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="2678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2674"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="2671"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="2670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="2669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="2668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="2667"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="2666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="2665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2663"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="2659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="2657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="2656"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="2654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="2652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="2646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="2644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2637"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="2634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2630"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2624"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="2622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="2620"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="2615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2612"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="2610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="2609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2602"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2598"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="2596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2594"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2592"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2590"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2585"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17"
                 priority="2583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('250') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '250' zijn. (string(@Item)=('250') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XTN' zijn. (string(@Type)=('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Order Callback Phone Number' zijn. (string(@LongName)=('Order Callback Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="2581"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telephone Number' zijn. (string(@LongName)=('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="2580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70201' zijn. (string(@Table)=('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Use Code' zijn. (string(@LongName)=('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="2578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Table MOET 'HL70202' zijn. (string(@Table)=('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Telecommunication Equipment Type' zijn. (string(@LongName)=('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="2576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Email Address' zijn. (string(@LongName)=('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="2575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Country Code' zijn. (string(@LongName)=('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="2574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Area/City Code' zijn. (string(@LongName)=('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="2573"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Local Number' zijn. (string(@LongName)=('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="2572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension' zijn. (string(@LongName)=('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="2571"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Any Text' zijn. (string(@LongName)=('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="2570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Extension Prefix' zijn. (string(@LongName)=('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="2569"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Speed Dial Code' zijn. (string(@LongName)=('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="2568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van @LongName MOET 'Unformatted Telephone number' zijn. (string(@LongName)=('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.18"
                 priority="2567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('251') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '251' zijn. (string(@Item)=('251') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Field 1' zijn. (string(@LongName)=('Placer Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.19"
                 priority="2566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('252') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '252' zijn. (string(@Item)=('252') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Field 2' zijn. (string(@LongName)=('Placer Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.20"
                 priority="2565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('253') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '253' zijn. (string(@Item)=('253') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Field 1' zijn. (string(@LongName)=('Filler Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.21"
                 priority="2564"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('254') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '254' zijn. (string(@Item)=('254') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Field 2' zijn. (string(@LongName)=('Filler Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22"
                 priority="2563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('255') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '255' zijn. (string(@Item)=('255') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. (string(@LongName)=('Results Rpt/Status Chng - Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="2561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="2560"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23"
                 priority="2558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x]. (count(hl7v2:MOC.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x]. (count(hl7v2:MOC.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('256') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '256' zijn. (string(@Item)=('256') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'MOC' zijn. (string(@Type)=('MOC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Charge to Practice' zijn. (string(@LongName)=('Charge to Practice') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="2556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Monetary Amount' zijn. (string(@LongName)=('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="2554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="2553"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="2551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van @LongName MOET 'Charge Code' zijn. (string(@LongName)=('Charge Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="2549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="2548"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="2547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="2545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="2544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="2543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.24"
                 priority="2541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('257') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '257' zijn. (string(@Item)=('257') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70074' zijn. (string(@Table)=('HL70074') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Diagnostic Serv Sect ID' zijn. (string(@LongName)=('Diagnostic Serv Sect ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.25"
                 priority="2539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('258') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '258' zijn. (string(@Item)=('258') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70123' zijn. (string(@Table)=('HL70123') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Status' zijn. (string(@LongName)=('Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26"
                 priority="2537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x]. (count(hl7v2:PRL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x]. (count(hl7v2:PRL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x]. (count(hl7v2:PRL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('259') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '259' zijn. (string(@Item)=('259') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'PRL' zijn. (string(@Type)=('PRL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Parent Result' zijn. (string(@LongName)=('Parent Result') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="2535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Identifier' zijn. (string(@LongName)=('Parent Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="2533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="2532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="2531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="2529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="2528"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="2527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="2525"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Sub-identifier' zijn. (string(@LongName)=('Parent Observation Sub-identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="2524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van @LongName MOET 'Parent Observation Value Descriptor' zijn. (string(@LongName)=('Parent Observation Value Descriptor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="2523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="2522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27"
                 priority="2520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '221' zijn. (string(@Item)=('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TQ' zijn. (string(@Type)=('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity/Timing' zijn. (string(@LongName)=('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="2518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2512"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2508"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="2505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'RI' zijn. (string(@Type)=('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Interval' zijn. (string(@LongName)=('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2503"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van @LongName MOET 'Explicit Time Interval' zijn. (string(@LongName)=('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="2501"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Duration' zijn. (string(@LongName)=('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="2500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Start Date/Time' zijn. (string(@LongName)=('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="2495"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'End Date/Time' zijn. (string(@LongName)=('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2493"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="2490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="2489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Condition' zijn. (string(@LongName)=('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="2488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="2487"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="2484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Table MOET 'HL70472' zijn. (string(@Table)=('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="2482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'OSD' zijn. (string(@Type)=('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Order Sequencing' zijn. (string(@LongName)=('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70524' zijn. (string(@Table)=('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Entity Identifier' zijn. (string(@LongName)=('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Namespace ID' zijn. (string(@LongName)=('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2476"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Entity Identifier' zijn. (string(@LongName)=('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Namespace ID' zijn. (string(@LongName)=('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2474"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Sequence Condition Value' zijn. (string(@LongName)=('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Maximum Number of Repeats' zijn. (string(@LongName)=('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID' zijn. (string(@LongName)=('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2471"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Placer Order Number: Universal ID Type' zijn. (string(@LongName)=('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2469"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID' zijn. (string(@LongName)=('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van @LongName MOET 'Filler Order Number: Universal ID Type' zijn. (string(@LongName)=('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="2466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Occurrence Duration' zijn. (string(@LongName)=('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2464"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2462"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2459"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="2456"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van @LongName MOET 'Total Occurrences' zijn. (string(@LongName)=('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28"
                 priority="2455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('260') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '260' zijn. (string(@Item)=('260') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Copies To' zijn. (string(@LongName)=('Result Copies To') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="2453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="2452"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2448"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="2445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="2444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="2443"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="2442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="2441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="2440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="2439"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2435"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="2433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="2431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="2430"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="2428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="2426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="2420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="2418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2414"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2410"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="2408"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2403"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2401"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="2396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="2394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="2389"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="2384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="2383"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2381"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2376"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2373"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2371"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="2370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2366"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2364"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2358"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29"
                 priority="2357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('261') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '261' zijn. (string(@Item)=('261') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'EIP' zijn. (string(@Type)=('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Parent' zijn. (string(@LongName)=('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="2355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Placer Assigned Identifier' zijn. (string(@LongName)=('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2350"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="2348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van @LongName MOET 'Filler Assigned Identifier' zijn. (string(@LongName)=('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2345"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.30"
                 priority="2341"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('262') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '262' zijn. (string(@Item)=('262') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70124' zijn. (string(@Table)=('HL70124') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transportation Mode' zijn. (string(@LongName)=('Transportation Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31"
                 priority="2339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('263') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '263' zijn. (string(@Item)=('263') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Reason for Study' zijn. (string(@LongName)=('Reason for Study') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="2337"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="2336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="2335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="2333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="2332"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="2331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32"
                 priority="2329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('264') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '264' zijn. (string(@Item)=('264') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Principal Result Interpreter' zijn. (string(@LongName)=('Principal Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="2327"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2325"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2321"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2317"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="2313"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2311"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="2308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="2303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="2302"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="2301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="2300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="2294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="2293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="2292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="2291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33"
                 priority="2290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('265') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '265' zijn. (string(@Item)=('265') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Assistant Result Interpreter' zijn. (string(@LongName)=('Assistant Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="2288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2286"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2282"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2280"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2277"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="2274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="2269"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2267"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="2264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="2263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="2262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="2261"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2257"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="2255"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="2254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="2253"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="2252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34"
                 priority="2251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('266') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '266' zijn. (string(@Item)=('266') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Technician' zijn. (string(@LongName)=('Technician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="2249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2245"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2243"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2241"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2238"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="2235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2233"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="2230"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="2225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="2224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="2223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="2222"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="2216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="2215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="2214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="2213"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35"
                 priority="2212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('267') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '267' zijn. (string(@Item)=('267') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NDL' zijn. (string(@Type)=('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transcriptionist' zijn. (string(@LongName)=('Transcriptionist') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="2210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'CNN' zijn. (string(@Type)=('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Name' zijn. (string(@LongName)=('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2204"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD' zijn. (string(@LongName)=('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2200"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Namespace ID' zijn. (string(@LongName)=('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID' zijn. (string(@LongName)=('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van @LongName MOET 'Assigning Authority - Universal ID Type' zijn. (string(@LongName)=('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="2196"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Start Date/time' zijn. (string(@LongName)=('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2194"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="2191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'End Date/time' zijn. (string(@LongName)=('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="2186"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="2185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="2184"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="2183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2180"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="2177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="2176"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Patient Location Type' zijn. (string(@LongName)=('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="2175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="2174"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36"
                 priority="2173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('268') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '268' zijn. (string(@Item)=('268') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Scheduled Date/Time' zijn. (string(@LongName)=('Scheduled Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="2171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="2170"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.37"
                 priority="2168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1028') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1028' zijn. (string(@Item)=('1028') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Number of Sample Containers *' zijn. (string(@LongName)=('Number of Sample Containers *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38"
                 priority="2167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1029') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1029' zijn. (string(@Item)=('1029') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Logistics of Collected Sample' zijn. (string(@LongName)=('Transport Logistics of Collected Sample') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="2165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="2164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="2163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="2161"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="2160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="2159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39"
                 priority="2157"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1030') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1030' zijn. (string(@Item)=('1030') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Collector''s Comment *' zijn. (string(@LongName)=('Collector''s Comment *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="2155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="2154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="2153"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="2151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="2150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="2149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40"
                 priority="2147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1031') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1031' zijn. (string(@Item)=('1031') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Arrangement Responsibility' zijn. (string(@LongName)=('Transport Arrangement Responsibility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="2145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="2144"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="2143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="2141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="2140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="2139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.41"
                 priority="2137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1032') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1032' zijn. (string(@Item)=('1032') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70224' zijn. (string(@Table)=('HL70224') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Transport Arranged' zijn. (string(@LongName)=('Transport Arranged') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.42"
                 priority="2135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1033') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1033' zijn. (string(@Item)=('1033') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70225' zijn. (string(@Table)=('HL70225') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Escort Required' zijn. (string(@LongName)=('Escort Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43"
                 priority="2133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1034') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1034' zijn. (string(@Item)=('1034') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Planned Patient Transport Comment' zijn. (string(@LongName)=('Planned Patient Transport Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="2131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="2130"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="2129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="2127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="2126"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="2125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44"
                 priority="2123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '393' zijn. (string(@Item)=('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70088' zijn. (string(@Table)=('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Procedure Code' zijn. (string(@LongName)=('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="2121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="2120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="2119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="2117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="2116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="2115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45"
                 priority="2113"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1316' zijn. (string(@Item)=('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70340' zijn. (string(@Table)=('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Procedure Code Modifier' zijn. (string(@LongName)=('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="2111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="2110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="2109"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="2107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="2106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="2105"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46"
                 priority="2103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1474' zijn. (string(@Item)=('1474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Placer Supplemental Service Information' zijn. (string(@LongName)=('Placer Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="2101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="2100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="2099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="2097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="2096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="2095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47"
                 priority="2093"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1475' zijn. (string(@Item)=('1475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70411' zijn. (string(@Table)=('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Filler Supplemental Service Information' zijn. (string(@LongName)=('Filler Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="2091"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="2090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="2089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="2087"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="2086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="2085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48"
                 priority="2083"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1646' zijn. (string(@Item)=('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70476' zijn. (string(@Table)=('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. (string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="2081"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="2080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="2079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="2077"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="2076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="2075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="2073"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="2072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="2071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.49"
                 priority="2070"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1647' zijn. (string(@Item)=('1647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70507' zijn. (string(@Table)=('HL70507') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Result Handling' zijn. (string(@LongName)=('Result Handling') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE"
                 priority="2069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.1"
                 priority="2068"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.2"
                 priority="2067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3"
                 priority="2065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="2064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="2063"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4"
                 priority="2061"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="2059"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="2058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="2057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="2055"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="2054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="2053"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e317-false-d410308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR"
                 priority="2051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 is required [min 1x]. (count(hl7v2:TQ1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1"
                 priority="2050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="2049"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1627') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1627' zijn. (string(@Item)=('1627') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Set ID - TQ1' zijn. (string(@LongName)=('Set ID - TQ1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="2048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1628') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1628' zijn. (string(@Item)=('1628') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="2046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="2045"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2041"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2037"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="2035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x]. (count(hl7v2:RPT.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x]. (count(hl7v2:RPT.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x]. (count(hl7v2:RPT.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x]. (count(hl7v2:RPT.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x]. (count(hl7v2:RPT.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x]. (count(hl7v2:RPT.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x]. (count(hl7v2:RPT.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x]. (count(hl7v2:RPT.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x]. (count(hl7v2:RPT.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x]. (count(hl7v2:RPT.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x]. (count(hl7v2:RPT.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1629') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1629' zijn. (string(@Item)=('1629') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'RPT' zijn. (string(@Type)=('RPT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Repeat Pattern' zijn. (string(@LongName)=('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="2033"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70335' zijn. (string(@Table)=('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Repeat Pattern Code' zijn. (string(@LongName)=('Repeat Pattern Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="2031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="2030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="2029"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="2027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="2026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="2025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="2023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="2022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="2021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="2020"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70527' zijn. (string(@Table)=('HL70527') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Calendar Alignment' zijn. (string(@LongName)=('Calendar Alignment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="2018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range Begin Value' zijn. (string(@LongName)=('Phase Range Begin Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="2017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Phase Range End Value' zijn. (string(@LongName)=('Phase Range End Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="2016"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Quantity' zijn. (string(@LongName)=('Period Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="2015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Period Units' zijn. (string(@LongName)=('Period Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="2014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70136' zijn. (string(@Table)=('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Institution Specified Time' zijn. (string(@LongName)=('Institution Specified Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="2012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Table MOET 'HL70528' zijn. (string(@Table)=('HL70528') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event' zijn. (string(@LongName)=('Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="2010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Quantity' zijn. (string(@LongName)=('Event Offset Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="2009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'Event Offset Units' zijn. (string(@LongName)=('Event Offset Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="2008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @Type MOET 'GTS' zijn. (string(@Type)=('GTS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van @LongName MOET 'General Timing Specification' zijn. (string(@LongName)=('General Timing Specification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="2007"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1630') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1630' zijn. (string(@Item)=('1630') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TM' zijn. (string(@Type)=('TM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Explicit Time' zijn. (string(@LongName)=('Explicit Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="2006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1631') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1631' zijn. (string(@Item)=('1631') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Relative Time and Units' zijn. (string(@LongName)=('Relative Time and Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="2004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="2003"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1999"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1997"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1996"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1995"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="1993"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1632') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1632' zijn. (string(@Item)=('1632') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Service Duration' zijn. (string(@LongName)=('Service Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="1991"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="1990"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1988"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1987"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1986"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1984"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1983"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1982"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="1980"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1633') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1633' zijn. (string(@Item)=('1633') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Start date/time' zijn. (string(@LongName)=('Start date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="1978"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="1977"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="1975"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1634') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1634' zijn. (string(@Item)=('1634') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'End date/time' zijn. (string(@LongName)=('End date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="1973"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="1972"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="1970"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1635') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1635' zijn. (string(@Item)=('1635') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70485' zijn. (string(@Table)=('HL70485') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Priority' zijn. (string(@LongName)=('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="1968"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="1967"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="1966"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="1964"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="1963"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="1962"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="1960"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="1959"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="1958"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="1957"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1636') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1636' zijn. (string(@Item)=('1636') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Condition text' zijn. (string(@LongName)=('Condition text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="1956"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="1955"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1954"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="1953"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1637') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1637' zijn. (string(@Item)=('1637') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'TX' zijn. (string(@Type)=('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Text instruction' zijn. (string(@LongName)=('Text instruction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="1952"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="1951"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1950"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="1949"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1638') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1638' zijn. (string(@Item)=('1638') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Table MOET 'HL70427' zijn. (string(@Table)=('HL70427') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Conjunction' zijn. (string(@LongName)=('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="1947"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1639') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1639' zijn. (string(@Item)=('1639') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Occurrence duration' zijn. (string(@LongName)=('Occurrence duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="1945"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="1944"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1942"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1941"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1940"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1938"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1937"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1936"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="1934"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1640') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Item MOET '1640' zijn. (string(@Item)=('1640') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van @LongName MOET 'Total occurrence''s' zijn. (string(@LongName)=('Total occurrence''s') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2"
                 priority="1933"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="1932"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1648') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1648' zijn. (string(@Item)=('1648') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Set ID - TQ2' zijn. (string(@LongName)=('Set ID - TQ2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="1931"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1649') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1649' zijn. (string(@Item)=('1649') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70503' zijn. (string(@Table)=('HL70503') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence/Results Flag' zijn. (string(@LongName)=('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="1929"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1650') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1650' zijn. (string(@Item)=('1650') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Number' zijn. (string(@LongName)=('Related Placer Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="1927"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="1926"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="1925"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="1924"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="1922"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1651') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1651' zijn. (string(@Item)=('1651') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Filler Number' zijn. (string(@LongName)=('Related Filler Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="1920"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="1919"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="1918"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="1917"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="1915"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1652') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1652' zijn. (string(@Item)=('1652') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Related Placer Group Number' zijn. (string(@LongName)=('Related Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="1913"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="1912"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="1911"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="1910"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="1908"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1653') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1653' zijn. (string(@Item)=('1653') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70504' zijn. (string(@Table)=('HL70504') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Code' zijn. (string(@LongName)=('Sequence Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="1906"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1654') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1654' zijn. (string(@Item)=('1654') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70505' zijn. (string(@Table)=('HL70505') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Entry/Exit Indicator' zijn. (string(@LongName)=('Cyclic Entry/Exit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="1904"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1655') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1655' zijn. (string(@Item)=('1655') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'CQ' zijn. (string(@Type)=('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Sequence Condition Time Interval' zijn. (string(@LongName)=('Sequence Condition Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="1902"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="1901"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1899"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1898"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1897"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1895"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1894"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1893"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="1891"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1656') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1656' zijn. (string(@Item)=('1656') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. (string(@LongName)=('Cyclic Group Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="1890"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1657') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Item MOET '1657' zijn. (string(@Item)=('1657') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @Table MOET 'HL70506' zijn. (string(@Table)=('HL70506') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van @LongName MOET 'Special Service Request Relationship' zijn. (string(@LongName)=('Special Service Request Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE d19e324-false-d414244e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR"
                 priority="1888"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX"
                 priority="1887"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.8 komt te vaak voor [max 1x]. (count(hl7v2:OBX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1886"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '569' zijn. (string(@Item)=('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Set ID - OBX' zijn. (string(@LongName)=('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1885"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '570' zijn. (string(@Item)=('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70125' zijn. (string(@Table)=('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Value Type' zijn. (string(@LongName)=('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1883"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '571' zijn. (string(@Item)=('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Identifier' zijn. (string(@LongName)=('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1881"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1880"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1879"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1877"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1876"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1875"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1873"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '572' zijn. (string(@Item)=('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Sub-ID' zijn. (string(@LongName)=('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1872"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '573' zijn. (string(@Item)=('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'varies' zijn. (string(@Type)=('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Value' zijn. (string(@LongName)=('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1871"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '574' zijn. (string(@Item)=('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Units' zijn. (string(@LongName)=('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1869"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1868"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1867"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1865"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1864"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1863"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1861"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '575' zijn. (string(@Item)=('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'References Range' zijn. (string(@LongName)=('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1860"
                 mode="M8">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theCodeSystemVersion" select="@codeSystemVersion"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]])"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion] or completeCodeSystem[@codeSystem=$theCodeSystem][not(@codeSystemVersion) or @codeSystemVersion=$theCodeSystemVersion]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '576' zijn. (string(@Item)=('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70078' zijn. (string(@Table)=('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Abnormal Flags' zijn. (string(@LongName)=('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1858"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '577' zijn. (string(@Item)=('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Probability' zijn. (string(@LongName)=('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1857"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '578' zijn. (string(@Item)=('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70080' zijn. (string(@Table)=('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Nature of Abnormal Test' zijn. (string(@LongName)=('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1855"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '579' zijn. (string(@Item)=('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Table MOET 'HL70085' zijn. (string(@Table)=('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Result Status' zijn. (string(@LongName)=('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1853"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '580' zijn. (string(@Item)=('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Effective Date of Reference Range' zijn. (string(@LongName)=('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1851"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1850"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1848"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '581' zijn. (string(@Item)=('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'User Defined Access Checks' zijn. (string(@LongName)=('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1847"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '582' zijn. (string(@Item)=('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Observation' zijn. (string(@LongName)=('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1845"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1844"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1842"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '583' zijn. (string(@Item)=('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Producer''s ID' zijn. (string(@LongName)=('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1840"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1839"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1838"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1836"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1835"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1834"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1832"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '584' zijn. (string(@Item)=('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Responsible Observer' zijn. (string(@LongName)=('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1830"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1829"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1827"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1826"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1825"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1824"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1823"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1822"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1821"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1820"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1819"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1818"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1817"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1816"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1814"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1813"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1812"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1810"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1808"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1807"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1805"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1803"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1801"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1800"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1799"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1797"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1795"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1793"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1792"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1791"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1789"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1788"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1787"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1785"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1783"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1781"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1780"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1778"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1776"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1775"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1773"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1771"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1769"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1768"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1766"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1764"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1763"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1761"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1760"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1758"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1757"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1756"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1754"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1753"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1752"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1750"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1749"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1748"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1747"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1745"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1744"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1743"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1741"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1740"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1739"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1737"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1736"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1735"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1734"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '936' zijn. (string(@Item)=('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Observation Method' zijn. (string(@LongName)=('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1732"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1731"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1730"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1728"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1727"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1726"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1724"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1479' zijn. (string(@Item)=('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Equipment Instance Identifier' zijn. (string(@LongName)=('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1722"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1721"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1720"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1719"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1717"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Item MOET '1480' zijn. (string(@Item)=('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van @LongName MOET 'Date/Time of the Analysis' zijn. (string(@LongName)=('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1715"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1714"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE"
                 priority="1712"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1711"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '96' zijn. (string(@Item)=('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Set ID - NTE' zijn. (string(@LongName)=('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1710"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '97' zijn. (string(@Item)=('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70105' zijn. (string(@Table)=('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Source of Comment' zijn. (string(@LongName)=('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1708"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '98' zijn. (string(@Item)=('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'FT' zijn. (string(@Type)=('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment' zijn. (string(@LongName)=('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1707"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1706"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1705"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1704"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Item MOET '1318' zijn. (string(@Item)=('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @Table MOET 'HL70364' zijn. (string(@Table)=('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van @LongName MOET 'Comment Type' zijn. (string(@LongName)=('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1702"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1701"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1700"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1698"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1697"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1696"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1"
                 priority="1694"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.1 komt te vaak voor [max 1x]. (count(hl7v2:FT1.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.2 komt te vaak voor [max 1x]. (count(hl7v2:FT1.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.3 komt te vaak voor [max 1x]. (count(hl7v2:FT1.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.4)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.4 is required [min 1x]. (count(hl7v2:FT1.4)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.4 komt te vaak voor [max 1x]. (count(hl7v2:FT1.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.5 komt te vaak voor [max 1x]. (count(hl7v2:FT1.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.6)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.6 is required [min 1x]. (count(hl7v2:FT1.6)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.6 komt te vaak voor [max 1x]. (count(hl7v2:FT1.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.7)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.7 is required [min 1x]. (count(hl7v2:FT1.7)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.7 komt te vaak voor [max 1x]. (count(hl7v2:FT1.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.8 komt te vaak voor [max 1x]. (count(hl7v2:FT1.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.9 komt te vaak voor [max 1x]. (count(hl7v2:FT1.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.10 komt te vaak voor [max 1x]. (count(hl7v2:FT1.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.11 komt te vaak voor [max 1x]. (count(hl7v2:FT1.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.12 komt te vaak voor [max 1x]. (count(hl7v2:FT1.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.13 komt te vaak voor [max 1x]. (count(hl7v2:FT1.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.14 komt te vaak voor [max 1x]. (count(hl7v2:FT1.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.15 komt te vaak voor [max 1x]. (count(hl7v2:FT1.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.16 komt te vaak voor [max 1x]. (count(hl7v2:FT1.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.17 komt te vaak voor [max 1x]. (count(hl7v2:FT1.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.18 komt te vaak voor [max 1x]. (count(hl7v2:FT1.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.22 komt te vaak voor [max 1x]. (count(hl7v2:FT1.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.23 komt te vaak voor [max 1x]. (count(hl7v2:FT1.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.25)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.25 komt te vaak voor [max 1x]. (count(hl7v2:FT1.25)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.27)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.27 komt te vaak voor [max 1x]. (count(hl7v2:FT1.27)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.28)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.28 komt te vaak voor [max 1x]. (count(hl7v2:FT1.28)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.29)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.29 komt te vaak voor [max 1x]. (count(hl7v2:FT1.29)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.30)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.30 komt te vaak voor [max 1x]. (count(hl7v2:FT1.30)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.1"
                 priority="1693"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('355') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '355' zijn. (string(@Item)=('355') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Set ID - FT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Set ID - FT1' zijn. (string(@LongName)=('Set ID - FT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.2"
                 priority="1692"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('356') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '356' zijn. (string(@Item)=('356') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction ID' zijn. (string(@LongName)=('Transaction ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.3"
                 priority="1691"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('357') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '357' zijn. (string(@Item)=('357') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Batch ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Batch ID' zijn. (string(@LongName)=('Transaction Batch ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4"
                 priority="1690"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('358') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '358' zijn. (string(@Item)=('358') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Date' zijn. (string(@LongName)=('Transaction Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1"
                 priority="1688"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1686"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1685"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2"
                 priority="1683"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1681"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1680"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5"
                 priority="1678"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('359') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '359' zijn. (string(@Item)=('359') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Posting Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Posting Date' zijn. (string(@LongName)=('Transaction Posting Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5/hl7v2:TS.1"
                 priority="1676"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5/hl7v2:TS.2"
                 priority="1675"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.6"
                 priority="1673"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('360') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '360' zijn. (string(@Item)=('360') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70017') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70017' zijn. (string(@Table)=('HL70017') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Type' zijn. (string(@LongName)=('Transaction Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7"
                 priority="1672"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('361') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '361' zijn. (string(@Item)=('361') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70132') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70132' zijn. (string(@Table)=('HL70132') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Code' zijn. (string(@LongName)=('Transaction Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.1"
                 priority="1670"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.2"
                 priority="1669"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.3"
                 priority="1668"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.4"
                 priority="1666"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.5"
                 priority="1665"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.6"
                 priority="1664"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.8"
                 priority="1662"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('362') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '362' zijn. (string(@Item)=('362') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Description' zijn. (string(@LongName)=('Transaction Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.9"
                 priority="1661"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('363') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '363' zijn. (string(@Item)=('363') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Description - Alt') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Description - Alt' zijn. (string(@LongName)=('Transaction Description - Alt') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.10"
                 priority="1660"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('364') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '364' zijn. (string(@Item)=('364') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Quantity' zijn. (string(@LongName)=('Transaction Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11"
                 priority="1659"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('365') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '365' zijn. (string(@Item)=('365') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Amount - Extended') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Amount - Extended' zijn. (string(@LongName)=('Transaction Amount - Extended') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1"
                 priority="1657"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1655"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1654"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.2"
                 priority="1652"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.3"
                 priority="1650"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.4"
                 priority="1649"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5"
                 priority="1648"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1646"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1645"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1644"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1642"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1641"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1640"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.6"
                 priority="1638"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12"
                 priority="1636"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('366') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '366' zijn. (string(@Item)=('366') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Amount - Unit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Amount - Unit' zijn. (string(@LongName)=('Transaction Amount - Unit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1"
                 priority="1634"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1632"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1631"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.2"
                 priority="1629"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.3"
                 priority="1627"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.4"
                 priority="1626"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5"
                 priority="1625"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1623"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1622"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1621"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1619"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1618"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1617"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.6"
                 priority="1615"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13"
                 priority="1613"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('367') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '367' zijn. (string(@Item)=('367') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70049') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70049' zijn. (string(@Table)=('HL70049') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Department Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Department Code' zijn. (string(@LongName)=('Department Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.1"
                 priority="1611"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.2"
                 priority="1610"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.3"
                 priority="1609"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.4"
                 priority="1607"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.5"
                 priority="1606"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.6"
                 priority="1605"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14"
                 priority="1603"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '368' zijn. (string(@Item)=('368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70072' zijn. (string(@Table)=('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Insurance Plan ID' zijn. (string(@LongName)=('Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.1"
                 priority="1601"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.2"
                 priority="1600"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.3"
                 priority="1599"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.4"
                 priority="1597"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.5"
                 priority="1596"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.6"
                 priority="1595"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15"
                 priority="1593"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('369') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '369' zijn. (string(@Item)=('369') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Insurance Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Insurance Amount' zijn. (string(@LongName)=('Insurance Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1"
                 priority="1591"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1589"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1588"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.2"
                 priority="1586"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.3"
                 priority="1584"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.4"
                 priority="1583"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5"
                 priority="1582"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1580"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1579"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1578"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1576"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1575"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1574"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.6"
                 priority="1572"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16"
                 priority="1570"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '133' zijn. (string(@Item)=('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'PL' zijn. (string(@Type)=('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Assigned Patient Location' zijn. (string(@LongName)=('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.1"
                 priority="1568"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70302' zijn. (string(@Table)=('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Point of Care' zijn. (string(@LongName)=('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.2"
                 priority="1567"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70303' zijn. (string(@Table)=('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Room' zijn. (string(@LongName)=('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.3"
                 priority="1566"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70304' zijn. (string(@Table)=('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Bed' zijn. (string(@LongName)=('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4"
                 priority="1565"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Facility' zijn. (string(@LongName)=('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.1"
                 priority="1563"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.2"
                 priority="1562"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.3"
                 priority="1561"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.5"
                 priority="1559"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70306' zijn. (string(@Table)=('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Status' zijn. (string(@LongName)=('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.6"
                 priority="1558"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70305' zijn. (string(@Table)=('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Person Location Type' zijn. (string(@LongName)=('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.7"
                 priority="1557"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70307' zijn. (string(@Table)=('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Building' zijn. (string(@LongName)=('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.8"
                 priority="1556"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Table MOET 'HL70308' zijn. (string(@Table)=('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Floor' zijn. (string(@LongName)=('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.9"
                 priority="1555"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Location Description' zijn. (string(@LongName)=('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10"
                 priority="1554"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Comprehensive Location Identifier' zijn. (string(@LongName)=('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.1"
                 priority="1552"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.2"
                 priority="1551"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.3"
                 priority="1550"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.4"
                 priority="1549"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11"
                 priority="1547"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van @LongName MOET 'Assigning Authority for Location' zijn. (string(@LongName)=('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.1"
                 priority="1545"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.2"
                 priority="1544"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.3"
                 priority="1543"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.17"
                 priority="1541"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('370') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '370' zijn. (string(@Item)=('370') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70024') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70024' zijn. (string(@Table)=('HL70024') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Fee Schedule') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Fee Schedule' zijn. (string(@LongName)=('Fee Schedule') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.18"
                 priority="1540"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '148' zijn. (string(@Item)=('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70018' zijn. (string(@Table)=('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Patient Type' zijn. (string(@LongName)=('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19"
                 priority="1539"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('371') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '371' zijn. (string(@Item)=('371') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70051') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70051' zijn. (string(@Table)=('HL70051') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Diagnosis Code - FT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Diagnosis Code - FT1' zijn. (string(@LongName)=('Diagnosis Code - FT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.1"
                 priority="1537"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.2"
                 priority="1536"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.3"
                 priority="1535"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.4"
                 priority="1533"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.5"
                 priority="1532"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.6"
                 priority="1531"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20"
                 priority="1529"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('372') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '372' zijn. (string(@Item)=('372') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70084') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70084' zijn. (string(@Table)=('HL70084') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Performed By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Performed By Code' zijn. (string(@LongName)=('Performed By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.1"
                 priority="1527"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2"
                 priority="1526"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1524"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1523"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1522"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1521"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1520"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.3"
                 priority="1519"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.4"
                 priority="1518"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.5"
                 priority="1517"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.6"
                 priority="1516"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.7"
                 priority="1515"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.8"
                 priority="1514"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9"
                 priority="1513"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1511"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1510"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1509"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.10"
                 priority="1507"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.11"
                 priority="1505"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.12"
                 priority="1504"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.13"
                 priority="1502"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14"
                 priority="1500"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1498"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1497"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1496"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.15"
                 priority="1494"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16"
                 priority="1492"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1490"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1489"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1488"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1486"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1485"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1484"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17"
                 priority="1482"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1480"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1478"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1477"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1475"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1473"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1472"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.18"
                 priority="1470"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19"
                 priority="1468"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1466"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1465"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20"
                 priority="1463"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1461"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1460"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.21"
                 priority="1458"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22"
                 priority="1457"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1455"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1454"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1453"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1451"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1450"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1449"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1447"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1446"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1445"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23"
                 priority="1444"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1442"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1441"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1440"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1438"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1437"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1436"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1434"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1433"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1432"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21"
                 priority="1431"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('373') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '373' zijn. (string(@Item)=('373') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Ordered By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Ordered By Code' zijn. (string(@LongName)=('Ordered By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.1"
                 priority="1429"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2"
                 priority="1428"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1426"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1425"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1424"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1423"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1422"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.3"
                 priority="1421"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.4"
                 priority="1420"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.5"
                 priority="1419"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.6"
                 priority="1418"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.7"
                 priority="1417"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.8"
                 priority="1416"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9"
                 priority="1415"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1413"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1412"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1411"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.10"
                 priority="1409"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.11"
                 priority="1407"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.12"
                 priority="1406"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.13"
                 priority="1404"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14"
                 priority="1402"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1400"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1399"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1398"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.15"
                 priority="1396"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16"
                 priority="1394"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1392"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1391"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1390"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1388"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1387"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1386"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17"
                 priority="1384"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1382"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1380"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1379"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1377"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1375"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1374"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.18"
                 priority="1372"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19"
                 priority="1370"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1368"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1367"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20"
                 priority="1365"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1363"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1362"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.21"
                 priority="1360"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22"
                 priority="1359"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1357"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1356"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1355"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1353"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1352"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1351"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1349"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1348"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1347"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23"
                 priority="1346"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1344"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1343"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1342"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1340"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1339"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1338"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1336"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1335"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1334"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22"
                 priority="1333"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('374') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '374' zijn. (string(@Item)=('374') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CP' zijn. (string(@Type)=('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Unit Cost') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Unit Cost' zijn. (string(@LongName)=('Unit Cost') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1"
                 priority="1331"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'MO' zijn. (string(@Type)=('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price' zijn. (string(@LongName)=('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1329"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Quantity' zijn. (string(@LongName)=('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1328"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van @LongName MOET 'Denomination' zijn. (string(@LongName)=('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.2"
                 priority="1326"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70205' zijn. (string(@Table)=('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Price Type' zijn. (string(@LongName)=('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.3"
                 priority="1324"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.4"
                 priority="1323"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'NM' zijn. (string(@Type)=('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'To Value' zijn. (string(@LongName)=('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5"
                 priority="1322"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Units' zijn. (string(@LongName)=('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1320"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1319"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1318"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1316"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1315"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1314"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.6"
                 priority="1312"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @Table MOET 'HL70298' zijn. (string(@Table)=('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van @LongName MOET 'Range Type' zijn. (string(@LongName)=('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23"
                 priority="1310"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '217' zijn. (string(@Item)=('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Filler Order Number' zijn. (string(@LongName)=('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.1"
                 priority="1308"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.2"
                 priority="1307"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.3"
                 priority="1306"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.4"
                 priority="1305"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24"
                 priority="1303"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('765') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '765' zijn. (string(@Item)=('765') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'XCN' zijn. (string(@Type)=('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entered By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Entered By Code' zijn. (string(@LongName)=('Entered By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.1"
                 priority="1301"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2"
                 priority="1300"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'FN' zijn. (string(@Type)=('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Family Name' zijn. (string(@LongName)=('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1298"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname' zijn. (string(@LongName)=('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1297"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname Prefix' zijn. (string(@LongName)=('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1296"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Own Surname' zijn. (string(@LongName)=('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1295"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname Prefix From Partner/Spouse' zijn. (string(@LongName)=('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1294"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van @LongName MOET 'Surname From Partner/Spouse' zijn. (string(@LongName)=('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.3"
                 priority="1293"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Given Name' zijn. (string(@LongName)=('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.4"
                 priority="1292"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. (string(@LongName)=('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.5"
                 priority="1291"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Suffix (e.g., JR or III)' zijn. (string(@LongName)=('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.6"
                 priority="1290"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Prefix (e.g., DR)' zijn. (string(@LongName)=('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.7"
                 priority="1289"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70360' zijn. (string(@Table)=('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Degree (e.g., MD)' zijn. (string(@LongName)=('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.8"
                 priority="1288"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70297' zijn. (string(@Table)=('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Source Table' zijn. (string(@LongName)=('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9"
                 priority="1287"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1285"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1284"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1283"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.10"
                 priority="1281"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70200' zijn. (string(@Table)=('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Type Code' zijn. (string(@LongName)=('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.11"
                 priority="1279"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Check Digit' zijn. (string(@LongName)=('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.12"
                 priority="1278"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.13"
                 priority="1276"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14"
                 priority="1274"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1272"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1271"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1270"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.15"
                 priority="1268"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70465' zijn. (string(@Table)=('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Representation Code' zijn. (string(@LongName)=('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16"
                 priority="1266"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70448' zijn. (string(@Table)=('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Context' zijn. (string(@LongName)=('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1264"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1263"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1262"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1260"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1259"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1258"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17"
                 priority="1256"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'DR' zijn. (string(@Type)=('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Validity Range' zijn. (string(@LongName)=('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1254"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range Start Date/Time' zijn. (string(@LongName)=('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1252"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1251"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1249"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van @LongName MOET 'Range End Date/Time' zijn. (string(@LongName)=('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1247"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1246"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.18"
                 priority="1244"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Table MOET 'HL70444' zijn. (string(@Table)=('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Name Assembly Order' zijn. (string(@LongName)=('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19"
                 priority="1242"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1240"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1239"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20"
                 priority="1237"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1235"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1234"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.21"
                 priority="1232"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Professional Suffix' zijn. (string(@LongName)=('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22"
                 priority="1231"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1229"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1228"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1227"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1225"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1224"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1223"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1221"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1220"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1219"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23"
                 priority="1218"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1216"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1215"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1214"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1212"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1211"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1210"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1208"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1207"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1206"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25"
                 priority="1205"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '393' zijn. (string(@Item)=('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70088' zijn. (string(@Table)=('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Procedure Code' zijn. (string(@LongName)=('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.1"
                 priority="1203"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.2"
                 priority="1202"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.3"
                 priority="1201"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.4"
                 priority="1199"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.5"
                 priority="1198"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.6"
                 priority="1197"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26"
                 priority="1195"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1316' zijn. (string(@Item)=('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70340' zijn. (string(@Table)=('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Procedure Code Modifier' zijn. (string(@LongName)=('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.1"
                 priority="1193"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.2"
                 priority="1192"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.3"
                 priority="1191"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.4"
                 priority="1189"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.5"
                 priority="1188"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.6"
                 priority="1187"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27"
                 priority="1185"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1310' zijn. (string(@Item)=('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70339' zijn. (string(@Table)=('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Advanced Beneficiary Notice Code' zijn. (string(@LongName)=('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.1"
                 priority="1183"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.2"
                 priority="1182"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.3"
                 priority="1181"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.4"
                 priority="1179"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.5"
                 priority="1178"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.6"
                 priority="1177"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28"
                 priority="1175"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1646' zijn. (string(@Item)=('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70476' zijn. (string(@Table)=('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. (string(@LongName)=('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.1"
                 priority="1173"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.2"
                 priority="1172"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.3"
                 priority="1171"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.4"
                 priority="1169"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.5"
                 priority="1168"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.6"
                 priority="1167"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.7"
                 priority="1165"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.8"
                 priority="1164"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.9"
                 priority="1163"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29"
                 priority="1162"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1845') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1845' zijn. (string(@Item)=('1845') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CNE' zijn. (string(@Type)=('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70549') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Table MOET 'HL70549' zijn. (string(@Table)=('HL70549') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('NDC Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'NDC Code' zijn. (string(@LongName)=('NDC Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.1"
                 priority="1160"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.2"
                 priority="1159"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.3"
                 priority="1158"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.4"
                 priority="1156"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.5"
                 priority="1155"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.6"
                 priority="1154"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.7"
                 priority="1152"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.8"
                 priority="1151"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.9"
                 priority="1150"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30"
                 priority="1149"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1846') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1846' zijn. (string(@Item)=('1846') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Payment Reference ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Payment Reference ID' zijn. (string(@LongName)=('Payment Reference ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.1"
                 priority="1147"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.2"
                 priority="1146"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.3"
                 priority="1145"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4"
                 priority="1143"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.1"
                 priority="1141"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.2"
                 priority="1140"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.3"
                 priority="1139"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.5"
                 priority="1137"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6"
                 priority="1135"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.1"
                 priority="1133"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.2"
                 priority="1132"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.3"
                 priority="1131"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.7"
                 priority="1129"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.8"
                 priority="1128"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9"
                 priority="1127"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="1125"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="1124"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="1123"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="1121"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="1120"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="1119"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="1117"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="1116"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="1115"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10"
                 priority="1114"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="1112"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="1111"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="1110"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="1108"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="1107"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="1106"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="1104"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="1103"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="1102"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.31"
                 priority="1101"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1847') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Item MOET '1847' zijn. (string(@Item)=('1847') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @Type MOET 'SI' zijn. (string(@Type)=('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Transaction Reference Key') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van @LongName MOET 'Transaction Reference Key' zijn. (string(@LongName)=('Transaction Reference Key') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI"
                 priority="1100"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&gt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 is required [min 1x]. (count(hl7v2:CTI.1)&gt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 komt te vaak voor [max 1x]. (count(hl7v2:CTI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.2 komt te vaak voor [max 1x]. (count(hl7v2:CTI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.3 komt te vaak voor [max 1x]. (count(hl7v2:CTI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1"
                 priority="1099"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1011') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1011' zijn. (string(@Item)=('1011') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'EI' zijn. (string(@Type)=('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Sponsor Study ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Sponsor Study ID' zijn. (string(@LongName)=('Sponsor Study ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.1"
                 priority="1097"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Entity Identifier' zijn. (string(@LongName)=('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.2"
                 priority="1096"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.3"
                 priority="1095"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.4"
                 priority="1094"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2"
                 priority="1092"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1022') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1022' zijn. (string(@Item)=('1022') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Phase Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Study Phase Identifier' zijn. (string(@LongName)=('Study Phase Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.1"
                 priority="1090"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.2"
                 priority="1089"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.3"
                 priority="1088"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.4"
                 priority="1086"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.5"
                 priority="1085"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.6"
                 priority="1084"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3"
                 priority="1082"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1055') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Item MOET '1055' zijn. (string(@Item)=('1055') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @Type MOET 'CE' zijn. (string(@Type)=('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Study Scheduled Time Point') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van @LongName MOET 'Study Scheduled Time Point' zijn. (string(@LongName)=('Study Scheduled Time Point') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.1"
                 priority="1080"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.2"
                 priority="1079"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.3"
                 priority="1078"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.4"
                 priority="1076"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.5"
                 priority="1075"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.6"
                 priority="1074"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG"
                 priority="1072"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.1 komt te vaak voor [max 1x]. (count(hl7v2:BLG.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.2 komt te vaak voor [max 1x]. (count(hl7v2:BLG.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.3 komt te vaak voor [max 1x]. (count(hl7v2:BLG.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.4 komt te vaak voor [max 1x]. (count(hl7v2:BLG.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1"
                 priority="1071"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CCD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): element hl7v2:CCD.1 komt te vaak voor [max 1x]. (count(hl7v2:CCD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CCD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): element hl7v2:CCD.2 komt te vaak voor [max 1x]. (count(hl7v2:CCD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('234') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Item MOET '234' zijn. (string(@Item)=('234') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CCD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Type MOET 'CCD' zijn. (string(@Type)=('CCD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70100') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Table MOET 'HL70100' zijn. (string(@Table)=('HL70100') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('When to Charge') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @LongName MOET 'When to Charge' zijn. (string(@LongName)=('When to Charge') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.1"
                 priority="1069"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70100') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van @Table MOET 'HL70100' zijn. (string(@Table)=('HL70100') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Invocation Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van @LongName MOET 'Invocation Event' zijn. (string(@LongName)=('Invocation Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2"
                 priority="1067"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van @Type MOET 'TS' zijn. (string(@Type)=('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van @LongName MOET 'Date/time' zijn. (string(@LongName)=('Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2/hl7v2:TS.1"
                 priority="1065"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'DTM' zijn. (string(@Type)=('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Time' zijn. (string(@LongName)=('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2/hl7v2:TS.2"
                 priority="1064"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @Table MOET 'HL70529' zijn. (string(@Table)=('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van @LongName MOET 'Degree of Precision' zijn. (string(@LongName)=('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.2"
                 priority="1062"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('235') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Item MOET '235' zijn. (string(@Item)=('235') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70122') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Table MOET 'HL70122' zijn. (string(@Table)=('HL70122') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @LongName MOET 'Charge Type' zijn. (string(@LongName)=('Charge Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3"
                 priority="1060"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('236') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Item MOET '236' zijn. (string(@Item)=('236') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Type MOET 'CX' zijn. (string(@Type)=('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Account ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @LongName MOET 'Account ID' zijn. (string(@LongName)=('Account ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.1"
                 priority="1058"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'ID Number' zijn. (string(@LongName)=('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.2"
                 priority="1057"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit' zijn. (string(@LongName)=('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.3"
                 priority="1056"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70061' zijn. (string(@Table)=('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Check Digit Scheme' zijn. (string(@LongName)=('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4"
                 priority="1054"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70363' zijn. (string(@Table)=('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Authority' zijn. (string(@LongName)=('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="1052"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="1051"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="1050"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.5"
                 priority="1048"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Table MOET 'HL70203' zijn. (string(@Table)=('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Identifier Type Code' zijn. (string(@LongName)=('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6"
                 priority="1046"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'HD' zijn. (string(@Type)=('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Facility' zijn. (string(@LongName)=('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="1044"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'IS' zijn. (string(@Type)=('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70300' zijn. (string(@Table)=('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Namespace ID' zijn. (string(@LongName)=('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="1043"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID' zijn. (string(@LongName)=('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="1042"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @Table MOET 'HL70301' zijn. (string(@Table)=('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van @LongName MOET 'Universal ID Type' zijn. (string(@LongName)=('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.7"
                 priority="1040"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Effective Date' zijn. (string(@LongName)=('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.8"
                 priority="1039"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'DT' zijn. (string(@Type)=('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Expiration Date' zijn. (string(@LongName)=('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9"
                 priority="1038"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Jurisdiction' zijn. (string(@LongName)=('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="1036"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="1035"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="1034"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="1032"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="1031"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="1030"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="1028"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="1027"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="1026"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10"
                 priority="1025"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van @LongName MOET 'Assigning Agency or Department' zijn. (string(@LongName)=('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="1023"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="1022"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="1021"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="1019"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="1018"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="1017"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="1015"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="1014"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="1013"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4"
                 priority="1012"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9)&lt;=1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9)&lt;=1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item)=('1645') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Item MOET '1645' zijn. (string(@Item)=('1645') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Type MOET 'CWE' zijn. (string(@Type)=('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70475') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @Table MOET 'HL70475' zijn. (string(@Table)=('HL70475') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Charge Type Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van @LongName MOET 'Charge Type Reason' zijn. (string(@LongName)=('Charge Type Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.1"
                 priority="1010"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Identifier' zijn. (string(@LongName)=('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.2"
                 priority="1009"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Text' zijn. (string(@LongName)=('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.3"
                 priority="1008"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Coding System' zijn. (string(@LongName)=('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.4"
                 priority="1006"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Identifier' zijn. (string(@LongName)=('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.5"
                 priority="1005"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Text' zijn. (string(@LongName)=('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.6"
                 priority="1004"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength)=('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van @MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. (string(@MaxLength)=('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ID' zijn. (string(@Type)=('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table)=('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Table MOET 'HL70396' zijn. (string(@Table)=('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Name of Alternate Coding System' zijn. (string(@LongName)=('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.7"
                 priority="1002"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Coding System Version ID' zijn. (string(@LongName)=('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.8"
                 priority="1001"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Alternate Coding System Version ID' zijn. (string(@LongName)=('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.9"
                 priority="1000"
                 mode="M8">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type)=('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @Type MOET 'ST' zijn. (string(@Type)=('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName)=('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van @LongName MOET 'Original Text' zijn. (string(@LongName)=('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labresultaten/lu-html-20180207T222349/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502-closedLab2Lab Aanvraagbericht (OML^O21)-->
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
</xsl:stylesheet>
